@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Ast node structures
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -81,6 +81,7 @@ void AstNode::init() {
     // Attributes
     m_didWidth = false;
     m_doingWidth = false;
+    m_protect = true;
     m_user1u = VNUser(0);
     m_user1Cnt = 0;
     m_user2u = VNUser(0);
@@ -93,6 +94,15 @@ void AstNode::init() {
     m_user5Cnt = 0;
 }
 
+AstNode* AstNode::abovep() const {
+    // m_headtailp only valid at beginning or end of list
+    // Avoid supporting at other locations as would require walking
+    // list which is likely to cause performance issues.
+    UASSERT_OBJ(!m_nextp || firstAbovep(), this, "abovep() not allowed when in midlist");
+    const AstNode* firstp = firstAbovep() ? this : m_headtailp;
+    return firstp->backp();
+}
+
 string AstNode::encodeName(const string& namein) {
     // Encode signal name raw from parser, then not called again on same signal
     string out;
@@ -113,7 +123,8 @@ string AstNode::encodeName(const string& namein) {
             // a user identifier nor a temp we create in Verilator.
             // We also do *NOT* use __DOT__ etc, as we search for those
             // in some replacements, and don't want to mangle the user's names.
-            char hex[10]; sprintf(hex, "__0%02X", pos[0]);
+            unsigned val = pos[0] & 0xff;  // Mask to avoid sign extension
+            char hex[10]; sprintf(hex, "__0%02X", val);
             out += hex;
         }
     }
@@ -132,6 +143,13 @@ string AstNode::encodeNumber(vlsint64_t num) {
     }
 }
 
+string AstNode::nameProtect() const {
+    return VIdProtect::protectIf(name(), protect());
+}
+string AstNode::origNameProtect() const {
+    return VIdProtect::protectIf(origName(), protect());
+}
+
 string AstNode::shortName() const {
     string pretty = name();
     string::size_type pos;
@@ -248,20 +266,21 @@ inline void AstNode::debugTreeChange(const char* prefix, int lineno, bool next)
 
 AstNode* AstNode::addNext(AstNode* nodep, AstNode* newp) {
     // Add to m_nextp, returns this
-    UDEBUGONLY(if (!newp) nodep->v3fatalSrc("Null item passed to addNext"););
+    UDEBUGONLY(UASSERT_OBJ(newp, nodep, "Null item passed to addNext"););
     nodep->debugTreeChange("-addNextThs: ", __LINE__, false);
     newp->debugTreeChange("-addNextNew: ", __LINE__, true);
     if (!nodep) {  // verilog.y and lots of other places assume this
-        return (newp);
+        return newp;
     } else {
         // Find end of old list
         AstNode* oldtailp = nodep;
         if (oldtailp->m_nextp) {
             if (oldtailp->m_headtailp) {
                 oldtailp = oldtailp->m_headtailp;  // This=beginning of list, jump to end
-                UDEBUGONLY(if (oldtailp->m_nextp) nodep->v3fatalSrc("Node had next, but headtail says it shouldn't"););
+                UDEBUGONLY(UASSERT_OBJ(!oldtailp->m_nextp, nodep,
+                                       "Node had next, but headtail says it shouldn't"););
             } else {
-                // Though inefficent, we are occasionally passed a addNext in the middle of a list.
+                // Though inefficient, we are occasionally passed a addNext in the middle of a list.
                 while (oldtailp->m_nextp != NULL) oldtailp = oldtailp->m_nextp;
             }
         }
@@ -337,9 +356,9 @@ void AstNode::addNextHere(AstNode* newp) {
 
 void AstNode::setOp1p(AstNode* newp) {
     UASSERT(newp, "Null item passed to setOp1p");
-    UDEBUGONLY(if (m_op1p) this->v3fatalSrc("Adding to non-empty, non-list op1"););
-    UDEBUGONLY(if (newp->m_backp) newp->v3fatalSrc("Adding already linked node"););
-    UDEBUGONLY(if (newp->m_nextp) newp->v3fatalSrc("Adding list to non-list op1"););
+    UDEBUGONLY(UASSERT_OBJ(!m_op1p, this, "Adding to non-empty, non-list op1"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_backp, newp, "Adding already linked node"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_nextp, newp, "Adding list to non-list op1"););
     this->debugTreeChange("-setOp1pThs: ", __LINE__, false);
     newp->debugTreeChange("-setOp1pNew: ", __LINE__, true);
     m_op1p = newp;
@@ -350,9 +369,9 @@ void AstNode::setOp1p(AstNode* newp) {
 
 void AstNode::setOp2p(AstNode* newp) {
     UASSERT(newp, "Null item passed to setOp2p");
-    UDEBUGONLY(if (m_op2p) this->v3fatalSrc("Adding to non-empty, non-list op2"););
-    UDEBUGONLY(if (newp->m_backp) newp->v3fatalSrc("Adding already linked node"););
-    UDEBUGONLY(if (newp->m_nextp) newp->v3fatalSrc("Adding list to non-list op2"););
+    UDEBUGONLY(UASSERT_OBJ(!m_op2p, this, "Adding to non-empty, non-list op2"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_backp, newp, "Adding already linked node"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_nextp, newp, "Adding list to non-list op2"););
     this->debugTreeChange("-setOp2pThs: ", __LINE__, false);
     newp->debugTreeChange("-setOp2pNew: ", __LINE__, true);
     m_op2p = newp;
@@ -363,9 +382,9 @@ void AstNode::setOp2p(AstNode* newp) {
 
 void AstNode::setOp3p(AstNode* newp) {
     UASSERT(newp, "Null item passed to setOp3p");
-    UDEBUGONLY(if (m_op3p) this->v3fatalSrc("Adding to non-empty, non-list op3"););
-    UDEBUGONLY(if (newp->m_backp) newp->v3fatalSrc("Adding already linked node"););
-    UDEBUGONLY(if (newp->m_nextp) newp->v3fatalSrc("Adding list to non-list op3"););
+    UDEBUGONLY(UASSERT_OBJ(!m_op3p, this, "Adding to non-empty, non-list op3"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_backp, newp, "Adding already linked node"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_nextp, newp, "Adding list to non-list op3"););
     this->debugTreeChange("-setOp3pThs: ", __LINE__, false);
     newp->debugTreeChange("-setOp3pNew: ", __LINE__, true);
     m_op3p = newp;
@@ -376,9 +395,9 @@ void AstNode::setOp3p(AstNode* newp) {
 
 void AstNode::setOp4p(AstNode* newp) {
     UASSERT(newp, "Null item passed to setOp4p");
-    UDEBUGONLY(if (m_op4p) this->v3fatalSrc("Adding to non-empty, non-list op4"););
-    UDEBUGONLY(if (newp->m_backp) newp->v3fatalSrc("Adding already linked node"););
-    UDEBUGONLY(if (newp->m_nextp) newp->v3fatalSrc("Adding list to non-list op4"););
+    UDEBUGONLY(UASSERT_OBJ(!m_op4p, this, "Adding to non-empty, non-list op4"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_backp, newp, "Adding already linked node"););
+    UDEBUGONLY(UASSERT_OBJ(!newp->m_nextp, newp, "Adding list to non-list op4"););
     this->debugTreeChange("-setOp4pThs: ", __LINE__, false);
     newp->debugTreeChange("-setOp4pNew: ", __LINE__, true);
     m_op4p = newp;
@@ -580,9 +599,11 @@ void AstNode::relinkOneLink(AstNode*& pointpr,  // Ref to pointer that gets set
         // Insert the whole old list following the new node's list.
         // Thus a unlink without next, followed by relink, gives the same list.
         AstNode* newlistlastp = newp->m_headtailp;
-        if (newlistlastp->m_nextp && newlistlastp!=newp) newp->v3fatalSrc("Headtailp tail isn't at the tail");
+        UASSERT_OBJ(!(newlistlastp->m_nextp && newlistlastp!=newp), newp,
+                    "Headtailp tail isn't at the tail");
         AstNode* oldlistlastp = pointpr->m_headtailp;
-        if (oldlistlastp->m_nextp && oldlistlastp!=pointpr) newp->v3fatalSrc("Old headtailp tail isn't at the tail");
+        UASSERT_OBJ(!(oldlistlastp->m_nextp && oldlistlastp!=pointpr), newp,
+                    "Old headtailp tail isn't at the tail");
         // Next links
         newlistlastp->m_nextp = pointpr;
         pointpr->m_backp = newlistlastp;
@@ -772,14 +793,15 @@ void AstNode::iterateAndNext(AstNVisitor& v) {
     // there's no lower level reason yet though the back must exist.
     AstNode* nodep = this;
 #ifdef VL_DEBUG  // Otherwise too hot of a function for debug
-    if (VL_UNLIKELY(nodep && !nodep->m_backp)) nodep->v3fatalSrc("iterateAndNext node has no back");
+    UASSERT_OBJ(!(nodep && !nodep->m_backp), nodep,
+                "iterateAndNext node has no back");
 #endif
     if (nodep) ASTNODE_PREFETCH(nodep->m_nextp);
     while (nodep) {   // effectively: if (!this) return;  // Callers rely on this
         if (nodep->m_nextp) ASTNODE_PREFETCH(nodep->m_nextp->m_nextp);
         AstNode* niterp = nodep;  // This address may get stomped via m_iterpp if the node is edited
         // Desirable check, but many places where multiple iterations are OK
-        //if (VL_UNLIKELY(niterp->m_iterpp)) niterp->v3fatalSrc("IterateAndNext under iterateAndNext may miss edits");
+        // UASSERT_OBJ(!niterp->m_iterpp, niterp, "IterateAndNext under iterateAndNext may miss edits");
         // Optimization note: Doing PREFETCH_RW on m_iterpp is a net even
         // cppcheck-suppress nullPointer
         niterp->m_iterpp = &niterp;
@@ -843,10 +865,10 @@ AstNode* AstNode::iterateSubtreeReturnEdits(AstNVisitor& v) {
         // track, then delete it on completion
         AstBegin* tempp = new AstBegin(nodep->fileline(), "[EditWrapper]", nodep);
         {
-            tempp->stmtsp()->accept(v); VL_DANGLING(nodep);  // nodep to null as may be replaced
+            VL_DO_DANGLING(tempp->stmtsp()->accept(v), nodep);  // nodep to null as may be replaced
         }
         nodep = tempp->stmtsp()->unlinkFrBackWithNext();
-        tempp->deleteTree(); VL_DANGLING(tempp);
+        VL_DO_DANGLING(tempp->deleteTree(), tempp);
     } else {
         // Use back to determine who's pointing at us (IE assume new node
         // grafts into same place as old one)
@@ -856,9 +878,9 @@ AstNode* AstNode::iterateSubtreeReturnEdits(AstNVisitor& v) {
         else if (this->m_backp->m_op3p == this) nextnodepp = &(this->m_backp->m_op3p);
         else if (this->m_backp->m_op4p == this) nextnodepp = &(this->m_backp->m_op4p);
         else if (this->m_backp->m_nextp == this) nextnodepp = &(this->m_backp->m_nextp);
-        if (!nextnodepp) this->v3fatalSrc("Node's back doesn't point to forward to node itself");
+        UASSERT_OBJ(nextnodepp, this, "Node's back doesn't point to forward to node itself");
         {
-            nodep->accept(v); VL_DANGLING(nodep);  // nodep to null as may be replaced
+            VL_DO_DANGLING(nodep->accept(v), nodep);  // nodep to null as may be replaced
         }
         nodep = *nextnodepp;  // Grab new node from point where old was connected
     }
@@ -934,13 +956,11 @@ V3Hash::V3Hash(const string& name) {
 
 void AstNode::checkTreeIter(AstNode* backp) {
     // private: Check a tree and children
-    if (backp != this->backp()) {
-        this->v3fatalSrc("Back node inconsistent");
-    }
+    UASSERT_OBJ(backp == this->backp(), this, "Back node inconsistent");
     if (VN_IS(this, NodeTermop) || VN_IS(this, NodeVarRef)) {
         // Termops have a short-circuited iterateChildren, so check usage
-        if (op1p()||op2p()||op3p()||op4p())
-            this->v3fatalSrc("Terminal operation with non-terminals");
+        UASSERT_OBJ(!(op1p()||op2p()||op3p()||op4p()), this,
+                    "Terminal operation with non-terminals");
     }
     if (m_op1p) m_op1p->checkTreeIterList(this);
     if (m_op2p) m_op2p->checkTreeIterList(this);
@@ -955,12 +975,13 @@ void AstNode::checkTreeIterList(AstNode* backp) {
     AstNode* tailp = this;
     for (AstNode* nodep=headp; nodep; nodep=nodep->nextp()) {
         nodep->checkTreeIter(backp);
-        if (headp!=this && nextp()) this->v3fatalSrc("Headtailp should be null in middle of lists");
+        UASSERT_OBJ(headp==this || !nextp(), this,
+                    "Headtailp should be null in middle of lists");
         tailp = nodep;
         backp = nodep;
     }
-    if (headp->m_headtailp != tailp) headp->v3fatalSrc("Tail in headtailp is inconsistent");
-    if (tailp->m_headtailp != headp) tailp->v3fatalSrc("Head in headtailp is inconsistent");
+    UASSERT_OBJ(headp->m_headtailp == tailp, headp, "Tail in headtailp is inconsistent");
+    UASSERT_OBJ(tailp->m_headtailp == headp, tailp, "Head in headtailp is inconsistent");
 }
 
 void AstNode::checkTree() {
@@ -973,23 +994,28 @@ void AstNode::checkTree() {
     }
 }
 
-void AstNode::dumpGdb() {  // For GDB only
-    dumpGdbHeader();
-    cout<<"  "; dump(cout); cout<<endl;
+// cppcheck-suppress unusedFunction  // Debug only
+void AstNode::dumpGdb() {  // For GDB only  // LCOV_EXCL_LINE
+    dumpGdbHeader();  // LCOV_EXCL_LINE
+    cout<<"  "; dump(cout); cout<<endl;  // LCOV_EXCL_LINE
 }
-void AstNode::dumpGdbHeader() const {  // For GDB only
-    dumpPtrs(cout);
-    cout<<"  Fileline = "<<fileline()<<endl;
+// cppcheck-suppress unusedFunction  // Debug only
+void AstNode::dumpGdbHeader() const {  // For GDB only  // LCOV_EXCL_LINE
+    dumpPtrs(cout);  // LCOV_EXCL_LINE
+    cout<<"  Fileline = "<<fileline()<<endl;  // LCOV_EXCL_LINE
 }
-void AstNode::dumpTreeGdb() {  // For GDB only
-    dumpGdbHeader();
-    dumpTree(cout);
+// cppcheck-suppress unusedFunction  // Debug only
+void AstNode::dumpTreeGdb() {  // For GDB only  // LCOV_EXCL_LINE
+    dumpGdbHeader();  // LCOV_EXCL_LINE
+    dumpTree(cout);  // LCOV_EXCL_LINE
 }
-void AstNode::dumpTreeFileGdb(const char* filenamep) {  // For GDB only
-    string filename = filenamep ? filenamep : v3Global.debugFilename("debug.tree", 98);
-    v3Global.rootp()->dumpTreeFile(filename);
+// cppcheck-suppress unusedFunction  // Debug only
+void AstNode::dumpTreeFileGdb(const char* filenamep) {  // For GDB only  // LCOV_EXCL_LINE
+    string filename = filenamep ? filenamep : v3Global.debugFilename("debug.tree", 98);  // LCOV_EXCL_LINE
+    v3Global.rootp()->dumpTreeFile(filename);  // LCOV_EXCL_LINE
 }
 
+// cppcheck-suppress unusedFunction  // Debug only
 void AstNode::checkIter() const {
     if (m_iterpp) {
         dumpPtrs(cout);
@@ -1020,31 +1046,36 @@ void AstNode::dumpPtrs(std::ostream& os) const {
     os<<endl;
 }
 
-void AstNode::dumpTree(std::ostream& os, const string& indent, int maxDepth) {
+void AstNode::dumpTree(std::ostream& os, const string& indent, int maxDepth) const {
+    static int s_debugFileline = v3Global.opt.debugSrcLevel("fileline");  // --debugi-fileline 9
     os<<indent<<" "<<this<<endl;
     if (debug()>8) { os<<indent<<"     "; dumpPtrs(os); }
+    if (s_debugFileline >= 9) {
+        os<<fileline()->warnContextSecondary();
+    }
     if (maxDepth==1) {
         if (op1p()||op2p()||op3p()||op4p()) { os<<indent<<"1: ...(maxDepth)"<<endl; }
     } else {
-        for (AstNode* nodep=op1p(); nodep; nodep=nodep->nextp()) {
+        for (const AstNode* nodep=op1p(); nodep; nodep=nodep->nextp()) {
             nodep->dumpTree(os, indent+"1:", maxDepth-1); }
-        for (AstNode* nodep=op2p(); nodep; nodep=nodep->nextp()) {
+        for (const AstNode* nodep=op2p(); nodep; nodep=nodep->nextp()) {
             nodep->dumpTree(os, indent+"2:", maxDepth-1); }
-        for (AstNode* nodep=op3p(); nodep; nodep=nodep->nextp()) {
+        for (const AstNode* nodep=op3p(); nodep; nodep=nodep->nextp()) {
             nodep->dumpTree(os, indent+"3:", maxDepth-1); }
-        for (AstNode* nodep=op4p(); nodep; nodep=nodep->nextp()) {
+        for (const AstNode* nodep=op4p(); nodep; nodep=nodep->nextp()) {
             nodep->dumpTree(os, indent+"4:", maxDepth-1); }
     }
 }
 
-void AstNode::dumpTreeAndNext(std::ostream& os, const string& indent, int maxDepth) {
+void AstNode::dumpTreeAndNext(std::ostream& os, const string& indent, int maxDepth) const {
     // Audited to make sure this is never NULL
-    for (AstNode* nodep=this; nodep; nodep=nodep->nextp()) {
+    for (const AstNode* nodep = this; nodep; nodep = nodep->nextp()) {
         nodep->dumpTree(os, indent, maxDepth);
     }
 }
 
 void AstNode::dumpTreeFile(const string& filename, bool append, bool doDump) {
+    // Not const function as calls checkTree
     if (doDump) {
         {   // Write log & close
             UINFO(2,"Dumping "<<filename<<endl);
@@ -1076,9 +1107,49 @@ void AstNode::v3errorEndFatal(std::ostringstream& str) const {
     v3errorEnd(str); assert(0); VL_UNREACHABLE
 }
 
+string AstNode::locationStr() const {
+    string str = "... In instance ";
+    const AstNode* backp = this;
+    int itmax = 10000;  // Max iterations before giving up on location search
+    while (backp) {
+        if (--itmax < 0) {
+            // Likely some circular back link, and V3Ast is trying to report a low-level error
+            UINFO(1, "Ran out of iterations finding locationStr on " << backp << endl);
+            return "";
+        }
+        const AstScope* scopep;
+        if ((scopep = VN_CAST_CONST(backp, Scope))) {
+            // The design is flattened and there are no useful scopes
+            // This is probably because of inlining
+            if (scopep->isTop()) break;
+
+            str += scopep->prettyName();
+            return str;
+        }
+        backp = backp->backp();
+    }
+    backp = this;
+    while (backp) {
+        const AstModule* modp;
+        const AstNodeVarRef* nvrp;
+        if ((modp = VN_CAST_CONST(backp, Module)) && !modp->hierName().empty()) {
+            str += modp->hierName();
+            return str;
+        } else if ((nvrp = VN_CAST_CONST(backp, NodeVarRef))) {
+            string prettyName = nvrp->prettyName();
+            // VarRefs have not been flattened yet and do not contain location information
+            if (prettyName != nvrp->name()) {
+                str += prettyName;
+                return str;
+            }
+        }
+        backp = backp->backp();
+    }
+    return "";
+}
 void AstNode::v3errorEnd(std::ostringstream& str) const {
     if (!m_fileline) {
-        V3Error::v3errorEnd(str);
+        V3Error::v3errorEnd(str, locationStr());
     } else {
         std::ostringstream nsstr;
         nsstr<<str.str();
@@ -1088,31 +1159,28 @@ void AstNode::v3errorEnd(std::ostringstream& str) const {
             const_cast<AstNode*>(this)->dump(nsstr);
             nsstr<<endl;
         }
-        m_fileline->v3errorEnd(nsstr);
+        m_fileline->v3errorEnd(nsstr, locationStr());
     }
 }
 
-string AstNode::warnMore() const {
-    return fileline()->warnMore();
-}
-
 //======================================================================
 // Data type conversion
 
 void AstNode::dtypeChgSigned(bool flag) {
-    if (!dtypep()) this->v3fatalSrc("No dtype when changing to (un)signed");
+    UASSERT_OBJ(dtypep(), this, "No dtype when changing to (un)signed");
     dtypeChgWidthSigned(dtypep()->width(), dtypep()->widthMin(),
-                        flag ? AstNumeric::SIGNED : AstNumeric::UNSIGNED);
+                        AstNumeric::fromBool(flag));
 }
 void AstNode::dtypeChgWidth(int width, int widthMin) {
-    if (!dtypep()) this->v3fatalSrc("No dtype when changing width");  // Use ChgWidthSigned(...UNSIGNED) otherwise
+    UASSERT_OBJ(dtypep(), this,
+                "No dtype when changing width");  // Use ChgWidthSigned(...UNSIGNED) otherwise
     dtypeChgWidthSigned(width, widthMin, dtypep()->numeric());
 }
 
 void AstNode::dtypeChgWidthSigned(int width, int widthMin, AstNumeric numeric) {
     if (!dtypep()) {
         // We allow dtypep() to be null, as before/during widthing dtypes are not resolved
-        dtypeSetLogicSized(width, widthMin, numeric);
+        dtypeSetLogicUnsized(width, widthMin, numeric);
     } else {
         if (width==dtypep()->width()
             && widthMin==dtypep()->widthMin()
@@ -1122,7 +1190,7 @@ void AstNode::dtypeChgWidthSigned(int width, int widthMin, AstNumeric numeric) {
         // work OK but this assumption may break in the future.
         // Note we can't just clone and do a widthForce, as if it's a BasicDType
         // the msb() indications etc will be incorrect.
-        dtypeSetLogicSized(width, widthMin, numeric);
+        dtypeSetLogicUnsized(width, widthMin, numeric);
     }
 }
 
@@ -1149,6 +1217,10 @@ AstBasicDType* AstNode::findInsertSameDType(AstBasicDType* nodep) {
     return v3Global.rootp()->typeTablep()
         ->findInsertSameDType(nodep);
 }
+AstNodeDType* AstNode::findVoidDType() const {
+    return v3Global.rootp()->typeTablep()
+        ->findVoidDType(fileline());
+}
 
 //######################################################################
 // AstNVisitor
