@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Add temporaries, such as for delayed nodes
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -51,7 +51,7 @@
 //      ASSIGNW (BITSEL(ARRAYSEL(VARREF(x), __Vdlyvdim_x), __Vdlyvlsb_x), __Vdlyvval_x)
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -99,10 +99,10 @@ private:
     AstAssignDly*       m_nextDlyp;     // Next delayed assignment in a list of assignments
     bool                m_inDly;        // True in delayed assignments
     bool                m_inLoop;       // True in for loops
-    bool                m_inInitial;    // True in intial blocks
+    bool                m_inInitial;    // True in initial blocks
     typedef std::map<std::pair<AstNodeModule*,string>,AstVar*> VarMap;
     VarMap              m_modVarMap;    // Table of new var names created under module
-    V3Double0           m_statSharedSet;// Statistic tracking
+    VDouble0            m_statSharedSet;  // Statistic tracking
     typedef std::map<AstVarScope*,int> ScopeVecMap;
     ScopeVecMap m_scopeVecMap;  // Next var number for each scope
 
@@ -114,13 +114,13 @@ private:
         nodep->user5( nodep->user5() | flags );
         if ((nodep->user5() & VU_DLY) && (nodep->user5() & VU_NONDLY)) {
             nodep->v3warn(BLKANDNBLK, "Unsupported: Blocked and non-blocking assignments to same variable: "
-                          <<nodep->varp()->prettyName());
+                          <<nodep->varp()->prettyNameQ());
         }
     }
     AstVarScope* createVarSc(AstVarScope* oldvarscp, const string& name,
                              int width/*0==fromoldvar*/, AstNodeDType* newdtypep) {
         // Because we've already scoped it, we may need to add both the AstVar and the AstVarScope
-        if (!oldvarscp->scopep()) oldvarscp->v3fatalSrc("Var unscoped");
+        UASSERT_OBJ(oldvarscp->scopep(), oldvarscp, "Var unscoped");
         AstVar* varp;
         AstNodeModule* addmodp = oldvarscp->scopep()->modp();
         // We need a new AstVar, but only one for all scopes, to match the new AstVarScope
@@ -158,15 +158,18 @@ private:
     }
     void checkActivePost(AstVarRef* varrefp, AstActive* oldactivep) {
         // Check for MULTIDRIVEN, and if so make new sentree that joins old & new sentree
-        if (!oldactivep) varrefp->v3fatalSrc("<= old dly assignment not put under sensitivity block");
+        UASSERT_OBJ(oldactivep, varrefp, "<= old dly assignment not put under sensitivity block");
         if (oldactivep->sensesp() != m_activep->sensesp()) {
             if (!varrefp->varp()->fileline()->warnIsOff(V3ErrorCode::MULTIDRIVEN)
                 && !varrefp->varp()->user2()) {
                 varrefp->varp()->v3warn(
                     MULTIDRIVEN, "Signal has multiple driving blocks with different clocking: "
-                    <<varrefp->varp()->prettyName()<<endl
-                    <<varrefp->warnMore()<<"... Location of first driving block"<<endl
-                    <<oldactivep->warnMore()<<"... Location of other driving block");
+                    <<varrefp->varp()->prettyNameQ()<<endl
+                    <<varrefp->warnOther()<<"... Location of first driving block"<<endl
+                    <<varrefp->warnContextPrimary()<<endl
+                    <<oldactivep->warnOther()<<"... Location of other driving block"<<endl
+                    <<oldactivep->warnContextSecondary()
+                    );
                 varrefp->varp()->user2(true);
             }
             UINFO(4,"AssignDupDlyVar: "<<varrefp<<endl);
@@ -200,10 +203,9 @@ private:
         } else {
             arrayselp = VN_CAST(lhsp, ArraySel);
         }
-        if (!arrayselp) nodep->v3fatalSrc("No arraysel under bitsel?");
-        if (VN_IS(arrayselp->dtypep()->skipRefp(), UnpackArrayDType)) {
-            nodep->v3fatalSrc("ArraySel with unpacked arrays should have been removed in V3Slice");
-        }
+        UASSERT_OBJ(arrayselp, nodep, "No arraysel under bitsel?");
+        UASSERT_OBJ(!VN_IS(arrayselp->dtypep()->skipRefp(), UnpackArrayDType), nodep,
+                    "ArraySel with unpacked arrays should have been removed in V3Slice");
         UINFO(4,"AssignDlyArray: "<<nodep<<endl);
         //
         //=== Dimensions: __Vdlyvdim__
@@ -214,8 +216,8 @@ private:
             dimvalp.push_front(valp);
         }
         AstVarRef* varrefp = VN_CAST(dimselp, VarRef);
-        if (!varrefp) nodep->v3fatalSrc("No var underneath arraysels");
-        if (!varrefp->varScopep()) varrefp->v3fatalSrc("Var didn't get varscoped in V3Scope.cpp");
+        UASSERT_OBJ(varrefp, nodep, "No var underneath arraysels");
+        UASSERT_OBJ(varrefp->varScopep(), varrefp, "Var didn't get varscoped in V3Scope.cpp");
         varrefp->unlinkFrBack();
         AstVar* oldvarp = varrefp->varp();
         int modVecNum = m_scopeVecMap[varrefp->varScopep()]++;
@@ -330,7 +332,8 @@ private:
             // Optimize as above; if sharing Vdlyvset *ON SAME VARIABLE*,
             // we can share the IF statement too
             postLogicp = VN_CAST(finalp->user4p(), If);
-            if (!postLogicp) nodep->v3fatalSrc("Delayed assignment misoptimized; prev var found w/o associated IF");
+            UASSERT_OBJ(postLogicp, nodep,
+                        "Delayed assignment misoptimized; prev var found w/o associated IF");
         } else {
             postLogicp = new AstIf(nodep->fileline(),
                                    new AstVarRef(nodep->fileline(), setvscp, false),
@@ -345,22 +348,22 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         //VV*****  We reset all userp() on the netlist
         m_modVarMap.clear();
         iterateChildren(nodep);
     }
-    virtual void visit(AstScope* nodep) {
+    virtual void visit(AstScope* nodep) VL_OVERRIDE {
         UINFO(4," MOD   "<<nodep<<endl);
         AstNode::user3ClearTree();
         iterateChildren(nodep);
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         m_cfuncp = nodep;
         iterateChildren(nodep);
         m_cfuncp = NULL;
     }
-    virtual void visit(AstActive* nodep) {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {
         m_activep = nodep;
         bool oldinit = m_inInitial;
         m_inInitial = nodep->hasInitial();
@@ -368,7 +371,7 @@ private:
         iterateChildren(nodep);
         m_inInitial = oldinit;
     }
-    virtual void visit(AstAssignDly* nodep) {
+    virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         m_inDly = true;
         m_nextDlyp = VN_CAST(nodep->nextp(), AssignDly);  // Next assignment in same block, maybe NULL.
         if (m_cfuncp) nodep->v3error("Unsupported: Delayed assignment inside public function/task");
@@ -381,9 +384,9 @@ private:
             if (newlhsp) {
                 nodep->lhsp(newlhsp);
             } else {
-                nodep->unlinkFrBack()->deleteTree(); VL_DANGLING(nodep);
+                VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
             }
-            lhsp->deleteTree(); VL_DANGLING(lhsp);
+            VL_DO_DANGLING(lhsp->deleteTree(), lhsp);
         }
         else {
             iterateChildren(nodep);
@@ -392,17 +395,17 @@ private:
         m_nextDlyp = NULL;
     }
 
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (!nodep->user2Inc()) {  // Not done yet
             if (m_inDly && nodep->lvalue()) {
                 UINFO(4,"AssignDlyVar: "<<nodep<<endl);
                 markVarUsage(nodep->varScopep(), VU_DLY);
-                if (!m_activep) nodep->v3fatalSrc("<= not under sensitivity block");
+                UASSERT_OBJ(m_activep, nodep, "<= not under sensitivity block");
                 if (!m_activep->hasClocked()) {
                     nodep->v3error("Internal: Blocking <= assignment in non-clocked block, should have converted in V3Active");
                 }
                 AstVarScope* oldvscp = nodep->varScopep();
-                if (!oldvscp) nodep->v3fatalSrc("Var didn't get varscoped in V3Scope.cpp");
+                UASSERT_OBJ(oldvscp, nodep, "Var didn't get varscoped in V3Scope.cpp");
                 AstVarScope* dlyvscp = VN_CAST(oldvscp->user1p(), VarScope);
                 if (dlyvscp) {  // Multiple use of delayed variable
                     AstActive* oldactivep = VN_CAST(dlyvscp->user2p(), Active);
@@ -429,7 +432,7 @@ private:
                 }
                 AstVarRef* newrefp = new AstVarRef(nodep->fileline(), dlyvscp, true);
                 newrefp->user2(true);  // No reason to do it again
-                nodep->replaceWith(newrefp); nodep->deleteTree(); VL_DANGLING(nodep);
+                nodep->replaceWith(newrefp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
             }
             else if (!m_inDly && nodep->lvalue()) {
                 //UINFO(9,"NBA "<<nodep<<endl);
@@ -441,10 +444,10 @@ private:
         }
     }
 
-    virtual void visit(AstNodeFor* nodep) {
+    virtual void visit(AstNodeFor* nodep) VL_OVERRIDE {
         nodep->v3fatalSrc("For statements should have been converted to while statements in V3Begin");
     }
-    virtual void visit(AstWhile* nodep) {
+    virtual void visit(AstWhile* nodep) VL_OVERRIDE {
         bool oldloop = m_inLoop;
         m_inLoop = true;
         iterateChildren(nodep);
@@ -453,12 +456,12 @@ private:
 
     //--------------------
     // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit DelayedVisitor(AstNetlist* nodep) {
         m_inDly = false;
         m_activep = NULL;
