@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Emit C++ code for module tree
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3EMITC_H_
 #define _V3EMITC_H_ 1
 
@@ -33,8 +33,9 @@ class V3EmitC {
 public:
     static void emitc();
     static void emitcInlines();
-    static void emitcSyms();
+    static void emitcSyms(bool dpiHdrOnly = false);
     static void emitcTrace();
+    static void emitcFiles();
 };
 
-#endif // Guard
+#endif  // Guard
