@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Emit Verilog code for module tree
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3EMITV_H_
 #define _V3EMITV_H_ 1
 
@@ -36,6 +36,7 @@ public:
     static void verilogPrefixedTree(AstNode* nodep, std::ostream& os,
                                     const string& prefix, int flWidth,
                                     AstSenTree* domainp, bool user3mark);
+    static void emitvFiles();
 };
 
 #endif  // Guard
