@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Error handling
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "V3Error.h"
 #ifndef _V3ERROR_NO_GLOBAL_
 # include "V3Ast.h"
@@ -38,6 +38,7 @@ bool V3Error::s_warnFatal = true;
 int V3Error::s_tellManual = 0;
 std::ostringstream V3Error::s_errorStr;  // Error string being formed
 V3ErrorCode V3Error::s_errorCode = V3ErrorCode::EC_FATAL;
+bool V3Error::s_errorContexted = false;
 bool V3Error::s_errorSuppressed = false;
 bool V3Error::s_describedEachWarn[V3ErrorCode::_ENUM_MAX];
 bool V3Error::s_describedWarnings = false;
@@ -57,9 +58,9 @@ V3ErrorCode::V3ErrorCode(const char* msgp) {
     // Return error encoding for given string, or ERROR, which is a bad code
     for (int codei=V3ErrorCode::EC_MIN; codei<V3ErrorCode::_ENUM_MAX; codei++) {
         V3ErrorCode code = V3ErrorCode(codei);
-	if (0==strcasecmp(msgp,code.ascii())) {
-	    m_e = code; return;
-	}
+        if (0 == VL_STRCASECMP(msgp, code.ascii())) {
+            m_e = code; return;
+        }
     }
     m_e = V3ErrorCode::EC_ERROR;
 }
@@ -69,12 +70,11 @@ V3ErrorCode::V3ErrorCode(const char* msgp) {
 
 void V3Error::init() {
     for (int i=0; i<V3ErrorCode::_ENUM_MAX; i++) {
-	s_describedEachWarn[i] = false;
-	s_pretendError[i] = V3ErrorCode(i).pretendError();
+        s_describedEachWarn[i] = false;
+        s_pretendError[i] = V3ErrorCode(i).pretendError();
     }
-
-    if (string(V3ErrorCode(V3ErrorCode::_ENUM_MAX).ascii()) != " MAX") {
-	v3fatalSrc("Enum table in V3ErrorCode::EC_ascii() is munged");
+    if (VL_UNCOVERABLE(string(V3ErrorCode(V3ErrorCode::_ENUM_MAX).ascii()) != " MAX")) {
+        v3fatalSrc("Enum table in V3ErrorCode::EC_ascii() is munged");
     }
 }
 
@@ -99,7 +99,8 @@ void V3Error::incErrors() {
 void V3Error::abortIfWarnings() {
     bool exwarn = warnFatal() && warnCount();
     if (errorCount() && exwarn) {
-        v3fatal("Exiting due to "<<std::dec<<errorCount()<<" error(s), "<<warnCount()<<" warning(s)\n");
+        v3fatal("Exiting due to "<<std::dec<<errorCount()<<" error(s), "
+                <<warnCount()<<" warning(s)\n");
     } else if (errorCount()) {
         v3fatal("Exiting due to "<<std::dec<<errorCount()<<" error(s)\n");
     } else if (exwarn) {
@@ -115,13 +116,13 @@ bool V3Error::isError(V3ErrorCode code, bool supp) {
     else if (code==V3ErrorCode::EC_FATALSRC) return true;
     else if (code==V3ErrorCode::EC_ERROR) return true;
     else if (code<V3ErrorCode::EC_FIRST_WARN
-	     || s_pretendError[code]) return true;
+             || s_pretendError[code]) return true;
     else return false;
 }
 
 string V3Error::msgPrefix() {
-    V3ErrorCode code=s_errorCode;
-    bool supp=s_errorSuppressed;
+    V3ErrorCode code = s_errorCode;
+    bool supp = s_errorSuppressed;
     if (supp) return "-arning-suppressed: ";
     else if (code==V3ErrorCode::USERINFO) return "-Info: ";
     else if (code==V3ErrorCode::EC_INFO) return "-Info: ";
@@ -138,9 +139,9 @@ string V3Error::msgPrefix() {
 void V3Error::vlAbort() {
     if (V3Error::debugDefault()) {
         std::cerr<<msgPrefix()<<"Aborting since under --debug"<<endl;
-	abort();
+        abort();
     } else {
-	exit(10);
+        exit(1);
     }
 }
 
@@ -150,83 +151,102 @@ void V3Error::vlAbort() {
 void V3Error::suppressThisWarning() {
     if (s_errorCode>=V3ErrorCode::EC_MIN) {
 #ifndef _V3ERROR_NO_GLOBAL_
-	V3Stats::addStatSum(string("Warnings, Suppressed ")+s_errorCode.ascii(), 1);
+        V3Stats::addStatSum(string("Warnings, Suppressed ")+s_errorCode.ascii(), 1);
 #endif
-	s_errorSuppressed = true;
+        s_errorSuppressed = true;
     }
 }
 
 string V3Error::warnMore() {
-    return msgPrefix();
+    return string(msgPrefix().size(), ' ');
 }
 
-void V3Error::v3errorEnd(std::ostringstream& sstr) {
+void V3Error::v3errorEnd(std::ostringstream& sstr, const string& locationStr) {
 #if defined(__COVERITY__) || defined(__cppcheck__)
     if (s_errorCode==V3ErrorCode::EC_FATAL) __coverity_panic__(x);
 #endif
     // Skip suppressed messages
     if (s_errorSuppressed
-	// On debug, show only non default-off warning to prevent pages of warnings
-	&& (!debug() || s_errorCode.defaultsOff())) return;
+        // On debug, show only non default-off warning to prevent pages of warnings
+        && (!debug() || s_errorCode.defaultsOff())) return;
     string msg = msgPrefix()+sstr.str();
-    if (msg[msg.length()-1] != '\n') msg += '\n';
-    // Suppress duplicates
+    if (s_errorSuppressed) {  // If suppressed print only first line to reduce verbosity
+        string::size_type pos;
+        if ((pos = msg.find('\n')) != string::npos) {
+            msg.erase(pos, msg.length()-pos);
+            msg += "...";
+        }
+    }
+    // Trailing newline (generally not on messages) & remove dup newlines
+    {
+        msg += '\n';  // Trailing newlines generally not put on messages so add
+        string::size_type pos;
+        while ((pos = msg.find("\n\n")) != string::npos) {
+            msg.erase(pos+1, 1);
+        }
+    }
+    // Suppress duplicate messages
     if (s_messages.find(msg) != s_messages.end()) return;
     s_messages.insert(msg);
+    if (!locationStr.empty()) {
+        string locationMsg = warnMore()+locationStr+"\n";
+        size_t pos = msg.find("\n");
+        msg.insert(pos + 1, locationMsg);
+    }
     // Output
     std::cerr<<msg;
     if (!s_errorSuppressed && !(s_errorCode==V3ErrorCode::EC_INFO
-				|| s_errorCode==V3ErrorCode::USERINFO)) {
-	if (!s_describedEachWarn[s_errorCode]
-	    && !s_pretendError[s_errorCode]) {
-	    s_describedEachWarn[s_errorCode] = true;
-	    if (s_errorCode>=V3ErrorCode::EC_FIRST_WARN && !s_describedWarnings) {
-                std::cerr<<msgPrefix()<<"Use \"/* verilator lint_off "<<s_errorCode.ascii()
+                                || s_errorCode==V3ErrorCode::USERINFO)) {
+        if (!s_describedEachWarn[s_errorCode]
+            && !s_pretendError[s_errorCode]) {
+            s_describedEachWarn[s_errorCode] = true;
+            if (s_errorCode>=V3ErrorCode::EC_FIRST_WARN && !s_describedWarnings) {
+                std::cerr<<warnMore()<<"... Use \"/* verilator lint_off "<<s_errorCode.ascii()
                          <<" */\" and lint_on around source to disable this message."<<endl;
-		s_describedWarnings = true;
-	    }
-	    if (s_errorCode.dangerous()) {
-                std::cerr<<msgPrefix()<<"*** See the manual before disabling this,"<<endl;
-                std::cerr<<msgPrefix()<<"else you may end up with different sim results."<<endl;
-	    }
-	}
-	// If first warning is not the user's fault (internal/unsupported) then give the website
-	// Not later warnings, as a internal may be caused by an earlier problem
-	if (s_tellManual == 0) {
-	    if (s_errorCode.mentionManual()
-		|| sstr.str().find("Unsupported") != string::npos) {
-		s_tellManual = 1;
-	    } else {
-		s_tellManual = 2;
-	    }
-	}
-	if (isError(s_errorCode, s_errorSuppressed)) incErrors();
-	else incWarnings();
-	if (s_errorCode==V3ErrorCode::EC_FATAL
-	    || s_errorCode==V3ErrorCode::EC_FATALSRC) {
-	    static bool inFatal = false;
-	    if (!inFatal) {
-		inFatal = true;
-		if (s_tellManual==1) {
-                    std::cerr<<msgPrefix()<<"See the manual and http://www.veripool.org/verilator for more assistance."<<endl;
-		    s_tellManual = 2;
-		}
+                s_describedWarnings = true;
+            }
+            if (s_errorCode.dangerous()) {
+                std::cerr<<warnMore()<<"*** See the manual before disabling this,"<<endl;
+                std::cerr<<warnMore()<<"else you may end up with different sim results."<<endl;
+            }
+        }
+        // If first warning is not the user's fault (internal/unsupported) then give the website
+        // Not later warnings, as a internal may be caused by an earlier problem
+        if (s_tellManual == 0) {
+            if (s_errorCode.mentionManual()
+                || sstr.str().find("Unsupported") != string::npos) {
+                s_tellManual = 1;
+            } else {
+                s_tellManual = 2;
+            }
+        }
+        if (isError(s_errorCode, s_errorSuppressed)) incErrors();
+        else incWarnings();
+        if (s_errorCode==V3ErrorCode::EC_FATAL
+            || s_errorCode==V3ErrorCode::EC_FATALSRC) {
+            static bool inFatal = false;
+            if (!inFatal) {
+                inFatal = true;
+                if (s_tellManual==1) {
+                    std::cerr<<warnMore()<<"... See the manual and https://verilator.org for more assistance."<<endl;
+                    s_tellManual = 2;
+                }
 #ifndef _V3ERROR_NO_GLOBAL_
-		if (debug()) {
-		    v3Global.rootp()->dumpTreeFile(v3Global.debugFilename("final.tree",990));
-		    if (s_errorExitCb) s_errorExitCb();
-		    V3Stats::statsFinalAll(v3Global.rootp());
-		    V3Stats::statsReport();
-		}
+                if (debug()) {
+                    v3Global.rootp()->dumpTreeFile(v3Global.debugFilename("final.tree", 990));
+                    if (s_errorExitCb) s_errorExitCb();
+                    V3Stats::statsFinalAll(v3Global.rootp());
+                    V3Stats::statsReport();
+                }
 #endif
-	    }
+            }
 
-	    vlAbort();
-	}
-	else if (isError(s_errorCode, s_errorSuppressed)) {
-	    // We don't dump tree on any error because a Visitor may be in middle of
-	    // a tree cleanup and cause a false broken problem.
-	    if (s_errorExitCb) s_errorExitCb();
-	}
+            vlAbort();
+        }
+        else if (isError(s_errorCode, s_errorSuppressed)) {
+            // We don't dump tree on any error because a Visitor may be in middle of
+            // a tree cleanup and cause a false broken problem.
+            if (s_errorExitCb) s_errorExitCb();
+        }
     }
 }
