@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Error handling
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,13 +17,16 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3ERROR_H_
 #define _V3ERROR_H_ 1
 
 #include "config_build.h"
 #include "verilatedos.h"
 
+// Limited V3 headers here - this is a base class for Vlc etc
+#include "V3String.h"
+
 #include <bitset>
 #include <cassert>
 #include <deque>
@@ -49,7 +52,6 @@ public:
         I_DEF_NETTYPE_WIRE,  // `default_nettype is WIRE (false=NONE)
         // Error codes:
         E_DETECTARRAY,  // Error: Unsupported: Can't detect changes on arrayed variable
-        E_MULTITOP,     // Error: Multiple top level modules
         E_PORTSHORT,    // Error: Output port is connected to a constant, electrical short
         E_TASKNSVAR,    // Error: Task I/O not simple
         //
@@ -75,10 +77,11 @@ public:
         CONTASSREG,     // Continuous assignment on reg
         DEFPARAM,       // Style: Defparam
         DECLFILENAME,   // Declaration doesn't match filename
+        DEPRECATED,     // Feature will be deprecated
         ENDLABEL,       // End lable name mismatch
         GENCLK,         // Generated Clock
         IFDEPTH,        // If statements too deep
-        IGNOREDRETURN,  // Ignoring return value (funcation as task)
+        IGNOREDRETURN,  // Ignoring return value (function as task)
         IMPERFECTSCH,   // Imperfect schedule (disabled by default)
         IMPLICIT,       // Implicit wire
         IMPORTSTAR,     // Import::* in $unit
@@ -86,9 +89,11 @@ public:
         INCABSPATH,     // Include has absolute path
         INFINITELOOP,   // Infinite loop
         INITIALDLY,     // Initial delayed statement
+        INSECURE,       // Insecure options
         LITENDIAN,      // Little bit endian vector
         MODDUP,         // Duplicate module
         MULTIDRIVEN,    // Driven from multiple blocks
+        MULTITOP,       // Multiple top level modules
         PINMISSING,     // Cell pin not specified
         PINNOCONNECT,   // Cell pin not connected
         PINCONNECTEMPTY,// Cell pin connected by name with empty reference
@@ -96,6 +101,7 @@ public:
         REALCVT,        // Real conversion
         REDEFMACRO,     // Redefining existing define macro
         SELRANGE,       // Selection index out of range
+        SHORTREAL,      // Shortreal not supported
         STMTDLY,        // Delayed statement
         SYMRSVDWORD,    // Symbol is Reserved Word
         SYNCASYNCNET,   // Mixed sync + async reset
@@ -131,23 +137,23 @@ public:
             // Boolean
             " I_COVERAGE", " I_TRACING", " I_LINT", " I_DEF_NETTYPE_WIRE",
             // Errors
-            "DETECTARRAY", "MULTITOP", "PORTSHORT", "TASKNSVAR",
+            "DETECTARRAY", "PORTSHORT", "TASKNSVAR",
             // Warnings
             " EC_FIRST_WARN",
             "ALWCOMBORDER", "ASSIGNDLY", "ASSIGNIN",
             "BLKANDNBLK", "BLKLOOPINIT", "BLKSEQ", "BSSPACE",
             "CASEINCOMPLETE", "CASEOVERLAP", "CASEWITHX", "CASEX", "CDCRSTLOGIC", "CLKDATA",
             "CMPCONST", "COLONPLUS", "COMBDLY", "CONTASSREG",
-            "DEFPARAM", "DECLFILENAME",
+            "DEFPARAM", "DECLFILENAME", "DEPRECATED",
             "ENDLABEL", "GENCLK",
             "IFDEPTH", "IGNOREDRETURN",
             "IMPERFECTSCH", "IMPLICIT", "IMPORTSTAR", "IMPURE",
-            "INCABSPATH", "INFINITELOOP", "INITIALDLY",
+            "INCABSPATH", "INFINITELOOP", "INITIALDLY", "INSECURE",
             "LITENDIAN", "MODDUP",
-            "MULTIDRIVEN",
+            "MULTIDRIVEN", "MULTITOP",
             "PINMISSING", "PINNOCONNECT", "PINCONNECTEMPTY", "PROCASSWIRE",
             "REALCVT", "REDEFMACRO",
-            "SELRANGE", "STMTDLY", "SYMRSVDWORD", "SYNCASYNCNET",
+            "SELRANGE", "SHORTREAL", "STMTDLY", "SYMRSVDWORD", "SYNCASYNCNET",
             "TICKCOUNT",
             "UNDRIVEN", "UNOPT", "UNOPTFLAT", "UNOPTTHREADS",
             "UNPACKED", "UNSIGNED", "UNUSED",
@@ -199,11 +205,15 @@ public:
                                        || m_e==UNDRIVEN
                                        || m_e==UNUSED
                                        || m_e==VARHIDDEN ); }
-  };
-  inline bool operator==(V3ErrorCode lhs, V3ErrorCode rhs) { return (lhs.m_e == rhs.m_e); }
-  inline bool operator==(V3ErrorCode lhs, V3ErrorCode::en rhs) { return (lhs.m_e == rhs); }
-  inline bool operator==(V3ErrorCode::en lhs, V3ErrorCode rhs) { return (lhs == rhs.m_e); }
-  inline std::ostream& operator<<(std::ostream& os, V3ErrorCode rhs) { return os<<rhs.ascii(); }
+};
+inline bool operator==(const V3ErrorCode& lhs, const V3ErrorCode& rhs) {
+    return lhs.m_e == rhs.m_e;
+}
+inline bool operator==(const V3ErrorCode& lhs, V3ErrorCode::en rhs) { return lhs.m_e == rhs; }
+inline bool operator==(V3ErrorCode::en lhs, const V3ErrorCode& rhs) { return lhs == rhs.m_e; }
+inline std::ostream& operator<<(std::ostream& os, const V3ErrorCode& rhs) {
+    return os << rhs.ascii();
+}
 
 //######################################################################
 
@@ -225,6 +235,7 @@ class V3Error {
     static int          s_tellManual;           // Tell user to see manual, 0=not yet, 1=doit, 2=disable
     static std::ostringstream s_errorStr;       // Error string being formed
     static V3ErrorCode  s_errorCode;            // Error string being formed will abort
+    static bool         s_errorContexted;       // Error being formed got context
     static bool         s_errorSuppressed;      // Error being formed should be suppressed
     static MessagesSet  s_messages;             // What errors we've outputted
     static ErrorExitCb  s_errorExitCb;          // Callback when error occurs for dumping
@@ -246,6 +257,8 @@ class V3Error {
     static int errorCount() { return s_errCount; }
     static int warnCount() { return s_warnCount; }
     static int errorOrWarnCount() { return errorCount()+warnCount(); }
+    static bool errorContexted() { return s_errorContexted; }
+    static void errorContexted(bool flag) { s_errorContexted = flag; }
     // METHODS
     static void incErrors();
     static void incWarnings() { s_warnCount++; }
@@ -257,18 +270,21 @@ class V3Error {
     static bool isError(V3ErrorCode code, bool supp);
     static string lineStr(const char* filename, int lineno);
     static V3ErrorCode errorCode() { return s_errorCode; }
-    static void         errorExitCb(ErrorExitCb cb) { s_errorExitCb = cb; }
+    static void errorExitCb(ErrorExitCb cb) { s_errorExitCb = cb; }
 
     // When printing an error/warning, print prefix for multiline message
     static string warnMore();
+    /// When building an error, don't show context info
+    static string warnContextNone() { V3Error::errorContexted(true); return ""; }
 
     // Internals for v3error()/v3fatal() macros only
     // Error end takes the string stream to output, be careful to seek() as needed
     static void v3errorPrep(V3ErrorCode code) {
-        s_errorStr.str(""); s_errorCode = code; s_errorSuppressed = false; }
+        s_errorStr.str(""); s_errorCode = code;
+        s_errorContexted = false; s_errorSuppressed = false; }
     static std::ostringstream& v3errorStr() { return s_errorStr; }
     static void vlAbort();
-    static void v3errorEnd(std::ostringstream& sstr);  // static, but often overridden in classes.
+    static void v3errorEnd(std::ostringstream& sstr, const string& locationStr = "");  // static, but often overridden in classes.
 };
 
 // Global versions, so that if the class doesn't define a operator, we get the functions anyways.
@@ -279,8 +295,8 @@ inline void v3errorEndFatal(std::ostringstream& sstr) {
 
 // Theses allow errors using << operators: v3error("foo"<<"bar");
 // Careful, you can't put () around msg, as you would in most macro definitions
-// Note the commas are the comma operator, not separating arguments. These are needed to insure
-// evaluation order as otherwise we couldn't insure v3errorPrep is called first.
+// Note the commas are the comma operator, not separating arguments. These are needed to ensure
+// evaluation order as otherwise we couldn't ensure v3errorPrep is called first.
 #define v3warnCode(code,msg) \
     v3errorEnd((V3Error::v3errorPrep(code), (V3Error::v3errorStr()<<msg), V3Error::v3errorStr()));
 #define v3warnCodeFatal(code,msg) \
@@ -297,8 +313,11 @@ inline void v3errorEndFatal(std::ostringstream& sstr) {
     ::v3errorEndFatal((V3Error::v3errorPrep(V3ErrorCode::EC_FATAL), \
                        (V3Error::v3errorStr()<<msg), V3Error::v3errorStr()));
 
-#define UINFO(level,stmsg) {if(VL_UNLIKELY(debug()>=(level))) { cout<<"- "<<V3Error::lineStr(__FILE__,__LINE__)<<stmsg; }}
-#define UINFONL(level,stmsg) {if(VL_UNLIKELY(debug()>=(level))) { cout<<stmsg; } }
+#define UINFO(level, stmsg) \
+    { if (VL_UNCOVERABLE(debug() >= (level))) { \
+            cout << "- " << V3Error::lineStr(__FILE__, __LINE__) << stmsg; } }
+#define UINFONL(level, stmsg) \
+    { if (VL_UNCOVERABLE(debug() >= (level))) { cout << stmsg; } }
 
 #ifdef VL_DEBUG
 # define UDEBUGONLY(stmts) {stmts}
@@ -306,11 +325,17 @@ inline void v3errorEndFatal(std::ostringstream& sstr) {
 # define UDEBUGONLY(stmts) {if (0) {stmts}}
 #endif
 
-#define UASSERT(condition,stmsg) { if (VL_UNLIKELY(!(condition))) { v3fatalSrc(stmsg); }}
+// Assertion without object, generally UOBJASSERT preferred
+#define UASSERT(condition,stmsg) \
+    do { if (VL_UNCOVERABLE(!(condition))) { v3fatalSrc(stmsg); }} while(0)
+// Assertion with object
+#define UASSERT_OBJ(condition,obj,stmsg) \
+    do { if (VL_UNCOVERABLE(!(condition))) { (obj)->v3fatalSrc(stmsg); }} while(0)
 // For use in V3Ast static functions only
 #define UASSERT_STATIC(condition,stmsg) \
-    { if (VL_UNLIKELY(!(condition))) { \
-            std::cerr<<"Internal Error: "<<__FILE__<<":"<<std::dec<<__LINE__<<":"<<(stmsg)<<std::endl; abort(); } }
+    do { if (VL_UNCOVERABLE(!(condition))) { \
+            std::cerr<<"Internal Error: "<<__FILE__<<":"<<std::dec<<__LINE__ \
+                     <<":"<<(stmsg)<<std::endl; abort(); } } while(0)
 // Check self test values for expected value.  Safe from side-effects.
 // Type argument can be removed when go to C++11 (use auto).
 #define UASSERT_SELFTEST(Type,got,exp) \
@@ -318,12 +343,14 @@ inline void v3errorEndFatal(std::ostringstream& sstr) {
          UASSERT(g==e, "Self-test failed '" #got "==" #exp "'"" got=" \
                  <<g<<" expected="<<e); } while(0)
 
-#define V3ERROR_NA { v3error("Internal: Unexpected Call"); v3fatalSrc("Unexpected Call"); }
+#define V3ERROR_NA \
+    do { v3error("Internal: Unexpected Call"); v3fatalSrc("Unexpected Call"); } while(0)
 
 /// Declare a convenience debug() routine that may be added to any class in
 /// Verilator so that --debugi-<srcfile> will work to control UINFOs in
 /// that class:
-#define VL_DEBUG_FUNC static int debug() { \
+#define VL_DEBUG_FUNC \
+    static int debug() {       \
         static int level = -1; \
         if (VL_UNLIKELY(level < 0)) level = v3Global.opt.debugSrcLevel(__FILE__); \
         return level; \
@@ -331,25 +358,4 @@ inline void v3errorEndFatal(std::ostringstream& sstr) {
 
 //----------------------------------------------------------------------
 
-template <class T> std::string cvtToStr(const T& t) {
-    std::ostringstream os; os<<t; return os.str();
-}
-template <class T> std::string cvtToHex(const T* tp) {
-    std::ostringstream os; os<<static_cast<const void*>(tp); return os.str();
-}
-
-inline uint32_t cvtToHash(const void* vp) {
-    // We can shove a 64 bit pointer into a 32 bit bucket
-    // On 32-bit systems, lower is always 0, but who cares?
-    union { const void* up; struct {uint32_t upper; uint32_t lower;} l;} u;
-    u.l.upper = 0; u.l.lower = 0; u.up = vp;
-    return u.l.upper^u.l.lower;
-}
-
-inline string ucfirst(const string& text) {
-    string out = text;
-    out[0] = toupper(out[0]);
-    return out;
-}
-
 #endif  // Guard
