@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Common headers
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3GLOBAL_H_
 #define _V3GLOBAL_H_ 1
 
@@ -55,10 +55,16 @@ public:
     inline VWidthMinUsage(en _e) : m_e(_e) {}
     explicit inline VWidthMinUsage(int _e) : m_e(static_cast<en>(_e)) {}
     operator en() const { return m_e; }
-  };
-  inline bool operator==(VWidthMinUsage lhs, VWidthMinUsage rhs) { return (lhs.m_e == rhs.m_e); }
-  inline bool operator==(VWidthMinUsage lhs, VWidthMinUsage::en rhs) { return (lhs.m_e == rhs); }
-  inline bool operator==(VWidthMinUsage::en lhs, VWidthMinUsage rhs) { return (lhs == rhs.m_e); }
+};
+inline bool operator==(const VWidthMinUsage& lhs, const VWidthMinUsage& rhs) {
+    return lhs.m_e == rhs.m_e;
+}
+inline bool operator==(const VWidthMinUsage& lhs, VWidthMinUsage::en rhs) {
+    return lhs.m_e == rhs;
+}
+inline bool operator==(VWidthMinUsage::en lhs, const VWidthMinUsage& rhs) {
+    return lhs == rhs.m_e;
+}
 
 //######################################################################
 // V3Global - The top level class for the entire program
