@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Graph optimizations
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -224,7 +224,7 @@ void V3Graph::clear() {
     for (V3GraphVertex* vertexp = verticesBeginp(); vertexp; vertexp=vertexp->verticesNextp()) {
         for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; /*BELOW*/) {
             V3GraphEdge* nextp = edgep->outNextp();
-            delete edgep;
+            VL_DO_DANGLING(delete edgep, edgep);
             edgep = nextp;
         }
         vertexp->outUnlink();
@@ -232,7 +232,7 @@ void V3Graph::clear() {
     // Delete the old vertices
     for (V3GraphVertex* vertexp = verticesBeginp(); vertexp; /*BELOW*/) {
         V3GraphVertex* nextp = vertexp->verticesNextp();
-        delete vertexp;
+        VL_DO_DANGLING(delete vertexp, vertexp);
         vertexp = nextp;
     }
     verticesUnlink();
@@ -281,7 +281,7 @@ void V3Graph::loopsVertexCb(V3GraphVertex* vertexp) {
 }
 
 void V3Graph::dump(std::ostream& os) {
-    // This generates a file used by graphviz, http://www.graphviz.org
+    // This generates a file used by graphviz, https://www.graphviz.org
     os<<" Graph:\n";
     // Print vertices
     for (V3GraphVertex* vertexp = verticesBeginp(); vertexp; vertexp=vertexp->verticesNextp()) {
@@ -322,7 +322,7 @@ void V3Graph::dumpDotFilePrefixedAlways(const string& nameComment, bool colorAsS
 }
 
 void V3Graph::dumpDotFile(const string& filename, bool colorAsSubgraph) const {
-    // This generates a file used by graphviz, http://www.graphviz.org
+    // This generates a file used by graphviz, https://www.graphviz.org
     // "hardcoded" parameters:
     const vl_unique_ptr<std::ofstream> logp (V3File::new_ofstream(filename));
     if (logp->fail()) v3fatal("Can't write "<<filename);
