@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Graph optimizations
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3GRAPH_H_
 #define _V3GRAPH_H_ 1
 
@@ -65,15 +65,15 @@ public:
     const char* ascii() const {
         static const char* const names[] = { "FORWARD", "REVERSE" };
         return names[m_e];
-    };
+    }
     // METHODS unique to this class
     GraphWay invert() const { return m_e == FORWARD ? REVERSE : FORWARD; }
     bool forward() const { return m_e == FORWARD; }
     bool reverse() const { return m_e != FORWARD; }
 };
-inline bool operator==(GraphWay lhs, GraphWay rhs) { return (lhs.m_e == rhs.m_e); }
-inline bool operator==(GraphWay lhs, GraphWay::en rhs) { return (lhs.m_e == rhs); }
-inline bool operator==(GraphWay::en lhs, GraphWay rhs) { return (lhs == rhs.m_e); }
+inline bool operator==(const GraphWay& lhs, const GraphWay& rhs) { return lhs.m_e == rhs.m_e; }
+inline bool operator==(const GraphWay& lhs, GraphWay::en rhs) { return lhs.m_e == rhs; }
+inline bool operator==(GraphWay::en lhs, const GraphWay& rhs) { return lhs == rhs.m_e; }
 
 //============================================================================
 
@@ -104,6 +104,7 @@ public:
     // METHODS
     void clear();  // Empty it of all vertices/edges, as if making a new object
     void clearColors();
+    bool empty() const { return m_vertices.empty(); }
 
     V3GraphVertex* verticesBeginp() const { return m_vertices.begin(); }
 
@@ -118,11 +119,6 @@ public:
     /// (I.E. all loops will occur within each color, not between them.)
     void stronglyConnected(V3EdgeFuncP edgeFuncp);
 
-    /// Assign same color to all destination vertices that have same
-    /// subgraph feeding into them
-    /// (I.E. all "from" nodes are common within each color)
-    /// See V3ClkGater if this is needed again; it got specialized
-
     /// Assign a ordering number to all vertexes in a tree.
     /// All nodes with no inputs will get rank 1
     void rank(V3EdgeFuncP edgeFuncp);
@@ -149,7 +145,7 @@ public:
     /// Delete any nodes with only outputs
     void deleteCutableOnlyEdges();
 
-    /// Any cutable edged become non-cutable
+    /// Any cutable edges become non-cutable
     void makeEdgesNonCutable(V3EdgeFuncP edgeFuncp);
 
     /// Remove any redundant edges, weights become MAX of any other weight
@@ -275,7 +271,7 @@ class V3GraphEdge {
     // Wires/variables aren't edges.  Edges have only a single to/from vertex
 public:
     // ENUMS
-    enum Cuttable { NOT_CUTABLE = false, CUTABLE = true };  // For passing to V3GraphEdge
+    enum Cutable { NOT_CUTABLE = false, CUTABLE = true };  // For passing to V3GraphEdge
 protected:
     friend class V3Graph;       friend class V3GraphVertex;
     friend class GraphAcyc;     friend class GraphAcycEdge;
