@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Graph automata base class
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3GRAPHDFA_H_
 #define _V3GRAPHDFA_H_ 1
 #include "config_build.h"
@@ -89,7 +89,7 @@ class DfaVertex : public V3GraphVertex {
     bool m_accepting;  // Accepting state?
 public:
     // CONSTRUCTORS
-    DfaVertex(DfaGraph* graphp, bool start=false, bool accepting=false)
+    explicit DfaVertex(DfaGraph* graphp, bool start=false, bool accepting=false)
         : V3GraphVertex(graphp)
         , m_start(start), m_accepting(accepting) {}
     using V3GraphVertex::clone;  // We are overriding, not overloading clone(V3Graph*)
