@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: DAG Path Checking
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -73,7 +73,7 @@ GraphPathChecker::~GraphPathChecker() {
     for (V3GraphVertex* vxp = m_graphp->verticesBeginp();
          vxp; vxp = vxp->verticesNextp()) {
         GraphPCNode* nodep = static_cast<GraphPCNode*>(vxp->userp());
-        delete nodep; VL_DANGLING(nodep);
+        VL_DO_DANGLING(delete nodep, nodep);
         vxp->userp(NULL);
     }
 }
@@ -94,9 +94,8 @@ void GraphPathChecker::initHalfCriticalPaths(GraphWay way, bool checkOnly) {
 
         GraphPCNode* ourUserp = static_cast<GraphPCNode*>(vertexp->userp());
         if (checkOnly) {
-            if (ourUserp->m_cp[way] != critPathCost) {
-                vertexp->v3fatalSrc("Validation of critical paths failed");
-            }
+            UASSERT_OBJ(ourUserp->m_cp[way] == critPathCost,
+                        vertexp, "Validation of critical paths failed");
         } else {
             ourUserp->m_cp[way] = critPathCost;
         }
