@@ -3,11 +3,11 @@
 // DESCRIPTION: Verilator: Dependency graph iterator. Iterates over nodes
 //                         in any DAG, following dependency order.
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -18,7 +18,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3GRAPHSTREAM_H_
 #define _V3GRAPHSTREAM_H_
 
@@ -60,7 +60,7 @@ private:
         // Decrement blocking edges count, return true if the vertex is
         // newly unblocked
         bool unblock() {
-            if (m_numBlockingEdges <= 0) vertexp()->v3fatalSrc("Underflow of blocking edges");
+            UASSERT_OBJ(m_numBlockingEdges > 0, vertexp(), "Underflow of blocking edges");
             m_numBlockingEdges--;
             return (m_numBlockingEdges == 0);
         }
@@ -88,16 +88,16 @@ private:
 
     // MEMBERS
     VxHolderCmp m_vxHolderCmp;  // Vertext comparison functor
-    ReadyVertices m_readyVertices;  // List of ready verticies
-    WaitingVertices m_waitingVertices;  // List of wiating verticies
+    ReadyVertices m_readyVertices;  // List of ready vertices
+    WaitingVertices m_waitingVertices;  // List of waiting vertices
     typename ReadyVertices::iterator m_last;  // Previously returned element
     GraphWay m_way;  // FORWARD or REVERSE order of traversal
 
 public:
     // CONSTRUCTORS
-    GraphStream(const V3Graph* graphp,
-                GraphWay way = GraphWay::FORWARD,
-                const T_Compare& lessThan = T_Compare())
+    explicit GraphStream(const V3Graph* graphp,
+                         GraphWay way = GraphWay::FORWARD,
+                         const T_Compare& lessThan = T_Compare())
         // NOTE: Perhaps REVERSE way should also reverse the sense of the
         // lessThan function? For now the only usage of REVERSE is not
         // sensitive to its lessThan at all, so it doesn't matter.
@@ -208,9 +208,8 @@ private:
 
                 typename WaitingVertices::iterator it =
                     m_waitingVertices.find(toVertexp);
-                if (it == m_waitingVertices.end()) {
-                    toVertexp->v3fatalSrc("Found edge into vertex not in waiting list.");
-                }
+                UASSERT_OBJ(it != m_waitingVertices.end(), toVertexp,
+                            "Found edge into vertex not in waiting list.");
                 if (it->second.unblock()) {
                     m_readyVertices.insert(it->second);
                     m_waitingVertices.erase(it);
@@ -223,9 +222,8 @@ private:
 
                 typename WaitingVertices::iterator it =
                     m_waitingVertices.find(fromVertexp);
-                if (it == m_waitingVertices.end()) {
-                    fromVertexp->v3fatalSrc("Found edge into vertex not in waiting list.");
-                }
+                UASSERT_OBJ(it != m_waitingVertices.end(), fromVertexp,
+                            "Found edge into vertex not in waiting list.");
                 if (it->second.unblock()) {
                     m_readyVertices.insert(it->second);
                     m_waitingVertices.erase(it);
