@@ -3,11 +3,11 @@
 // DESCRIPTION: Verilator: Estimate instruction count to run the logic
 //                         we would generate for any given AST subtree.
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -18,7 +18,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -100,10 +100,9 @@ private:
             // (which at the V3Order stage represent verilog tasks, not to
             // the CFuncs that V3Order will generate.) So don't check for
             // collisions in CFuncs.
-            if (nodep->user5p()) {
-                nodep->v3fatalSrc("Node originally inserted below logic vertex "
-                                  <<static_cast<AstNode*>(nodep->user5p()));
-            }
+            UASSERT_OBJ(!nodep->user5p(), nodep,
+                        "Node originally inserted below logic vertex "
+                        <<static_cast<AstNode*>(nodep->user5p()));
             nodep->user5p(const_cast<void*>(reinterpret_cast<const void*>(m_startNodep)));
         }
 
@@ -125,7 +124,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNodeSel* nodep) {
+    virtual void visit(AstNodeSel* nodep) VL_OVERRIDE {
         // This covers both AstArraySel and AstWordSel
         //
         // If some vector is a bazillion dwords long, and we're selecting 1
@@ -136,7 +135,7 @@ private:
         VisitBase vb(this, nodep);
         iterateAndNextNull(nodep->bitp());
     }
-    virtual void visit(AstSel* nodep) {
+    virtual void visit(AstSel* nodep) VL_OVERRIDE {
         // Similar to AstNodeSel above, a small select into a large vector
         // is not expensive. Count the cost of the AstSel itself (scales with
         // its width) and the cost of the lsbp() and widthp() nodes, but not
@@ -145,13 +144,13 @@ private:
         iterateAndNextNull(nodep->lsbp());
         iterateAndNextNull(nodep->widthp());
     }
-    virtual void visit(AstSliceSel* nodep) {
+    virtual void visit(AstSliceSel* nodep) VL_OVERRIDE {
         nodep->v3fatalSrc("AstSliceSel unhandled");
     }
-    virtual void visit(AstMemberSel* nodep) {
+    virtual void visit(AstMemberSel* nodep) VL_OVERRIDE {
         nodep->v3fatalSrc("AstMemberSel unhandled");
     }
-    virtual void visit(AstConcat* nodep) {
+    virtual void visit(AstConcat* nodep) VL_OVERRIDE {
         // Nop.
         //
         // Ignore concat. The problem with counting concat is that when we
@@ -171,7 +170,7 @@ private:
         // the widths of the operands (ignored here).
         markCost(nodep);
     }
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         VisitBase vb(this, nodep);
         iterateAndNextNull(nodep->condp());
         uint32_t savedCount = m_instrCount;
@@ -180,13 +179,13 @@ private:
         m_instrCount = 0;
         iterateAndNextNull(nodep->ifsp());
         uint32_t ifCount = m_instrCount;
-        if (nodep->branchPred() == AstBranchPred::BP_UNLIKELY) ifCount = 0;
+        if (nodep->branchPred().unlikely()) ifCount = 0;
 
         UINFO(8, "elsesp:\n");
         m_instrCount = 0;
         iterateAndNextNull(nodep->elsesp());
         uint32_t elseCount = m_instrCount;
-        if (nodep->branchPred() == AstBranchPred::BP_LIKELY) elseCount = 0;
+        if (nodep->branchPred().likely()) elseCount = 0;
 
         if (ifCount >= elseCount) {
             m_instrCount = savedCount + ifCount;
@@ -196,7 +195,7 @@ private:
             if (nodep->ifsp()) nodep->ifsp()->user4(0);  // Don't dump it
         }
     }
-    virtual void visit(AstNodeCond* nodep) {
+    virtual void visit(AstNodeCond* nodep) VL_OVERRIDE {
         // Just like if/else above, the ternary operator only evaluates
         // one of the two expressions, so only count the max.
         VisitBase vb(this, nodep);
@@ -221,7 +220,7 @@ private:
             if (nodep->expr2p()) nodep->expr2p()->user4(0);  // Don't dump it
         }
     }
-    virtual void visit(AstActive* nodep) {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {
         // You'd think that the OrderLogicVertex's would be disjoint trees
         // of stuff in the AST, but it isn't so: V3Order makes an
         // OrderLogicVertex for each ACTIVE, and then also makes an
@@ -235,25 +234,20 @@ private:
         // are no actives-under-actives.  In any case, check that we're at
         // root:
         markCost(nodep);
-        if (nodep != m_startNodep) {
-            nodep->v3fatalSrc("Multiple actives, or not start node");
-        }
+        UASSERT_OBJ(nodep == m_startNodep, nodep, "Multiple actives, or not start node");
     }
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstCCall* nodep) VL_OVERRIDE {
         VisitBase vb(this, nodep);
         iterateChildren(nodep);
         m_tracingCall = true;
         iterate(nodep->funcp());
-        if (m_tracingCall) {
-            nodep->v3fatalSrc("visit(AstCFunc) should have cleared m_tracingCall.");
-        }
+        UASSERT_OBJ(!m_tracingCall, nodep, "visit(AstCFunc) should have cleared m_tracingCall.");
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         // Don't count a CFunc other than by tracing a call or counting it
         // from the root
-        if (!m_tracingCall && (nodep != m_startNodep)) {
-            nodep->v3fatalSrc("AstCFunc not under AstCCall, or not start node");
-        }
+        UASSERT_OBJ(m_tracingCall || nodep == m_startNodep, nodep,
+                    "AstCFunc not under AstCCall, or not start node");
         m_tracingCall = false;
         bool saved_inCFunc = m_inCFunc;
         m_inCFunc = true;
@@ -263,7 +257,7 @@ private:
         }
         m_inCFunc = saved_inCFunc;
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         VisitBase vb(this, nodep);
         iterateChildren(nodep);
     }
@@ -287,7 +281,7 @@ public:
     InstrCountDumpVisitor(AstNode* nodep, std::ostream* osp)
         : m_osp(osp), m_depth(0) {
         // No check for NULL output, so...
-        if (!osp) nodep->v3fatalSrc("Don't call if not dumping");
+        UASSERT_OBJ(osp, nodep, "Don't call if not dumping");
         if (nodep) iterate(nodep);
     }
     virtual ~InstrCountDumpVisitor() {}
@@ -295,7 +289,7 @@ public:
 private:
     // METHODS
     string indent() { return string(m_depth, ':')+" "; }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         ++m_depth;
         if (unsigned costPlus1 = nodep->user4()) {
             *m_osp <<"  "<<indent()
