@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Lifelicate variable assignment elimination
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -26,7 +26,7 @@
 //          We don't do the opposite yet though (remove assigns in if followed by outside if)
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -50,8 +50,8 @@ class LifeState {
 
     // STATE
 public:
-    V3Double0   m_statAssnDel;  // Statistic tracking
-    V3Double0   m_statAssnCon;  // Statistic tracking
+    VDouble0 m_statAssnDel;  // Statistic tracking
+    VDouble0 m_statAssnCon;  // Statistic tracking
     std::vector<AstNode*> m_unlinkps;
 
 public:
@@ -158,7 +158,7 @@ public:
                 // above our current iteration point.
                 if (debug()>4) oldassp->dumpTree(cout, "       REMOVE/SAMEBLK ");
                 entp->complexAssign();
-                m_statep->pushUnlinkDeletep(oldassp); VL_DANGLING(oldassp);
+                VL_DO_DANGLING(m_statep->pushUnlinkDeletep(oldassp), oldassp);
                 ++m_statep->m_statAssnDel;
             }
         }
@@ -195,7 +195,7 @@ public:
                     // We'll later constant propagate
                     UINFO(4,"     replaceconst: "<<varrefp<<endl);
                     varrefp->replaceWith(constp->cloneTree(false));
-                    varrefp->deleteTree(); VL_DANGLING(varrefp);
+                    VL_DO_DANGLING(varrefp->deleteTree(), varrefp);
                     ++m_statep->m_statAssnCon;
                     return;  // **DONE, no longer a var reference**
                 }
@@ -296,20 +296,21 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         // Consumption/generation of a variable,
         // it's used so can't elim assignment before this use.
-        if (!nodep->varScopep()) nodep->v3fatalSrc("NULL");
+        UASSERT_OBJ(nodep->varScopep(), nodep, "NULL");
         //
         AstVarScope* vscp = nodep->varScopep();
-        if (!vscp) nodep->v3fatalSrc("Scope not assigned");
+        UASSERT_OBJ(vscp, nodep, "Scope not assigned");
         if (nodep->lvalue()) {
+            m_sideEffect = true;  // $sscanf etc may have RHS vars that are lvalues
             m_lifep->complexAssign(vscp);
         } else {
-            m_lifep->varUsageReplace(vscp, nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(m_lifep->varUsageReplace(vscp, nodep), nodep);
         }
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         // Collect any used variables first, as lhs may also be on rhs
         // Similar code in V3Dead
         vluint64_t lastEdit = AstNode::editCountGbl();  // When it was last edited
@@ -323,19 +324,19 @@ private:
         // Has to be direct assignment without any EXTRACTing.
         if (VN_IS(nodep->lhsp(), VarRef) && !m_sideEffect && !m_noopt) {
             AstVarScope* vscp = VN_CAST(nodep->lhsp(), VarRef)->varScopep();
-            if (!vscp) nodep->v3fatalSrc("Scope lost on variable");
+            UASSERT_OBJ(vscp, nodep, "Scope lost on variable");
             m_lifep->simpleAssign(vscp, nodep);
         } else {
             iterateAndNextNull(nodep->lhsp());
         }
     }
-    virtual void visit(AstAssignDly* nodep) {
+    virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         // Don't treat as normal assign; V3Life doesn't understand time sense
         iterateChildren(nodep);
     }
 
     //---- Track control flow changes
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"   IF "<<nodep<<endl);
         // Condition is part of PREVIOUS block
         iterateAndNextNull(nodep->condp());
@@ -345,24 +346,23 @@ private:
         {
             m_lifep = ifLifep;
             iterateAndNextNull(nodep->ifsp());
-            m_lifep = prevLifep;
         }
         {
             m_lifep = elseLifep;
             iterateAndNextNull(nodep->elsesp());
-            m_lifep = prevLifep;
         }
+        m_lifep = prevLifep;
         UINFO(4,"   join "<<endl);
         // Find sets on both flows
         m_lifep->dualBranch(ifLifep, elseLifep);
         // For the next assignments, clear any variables that were read or written in the block
         ifLifep->lifeToAbove();
         elseLifep->lifeToAbove();
-        delete ifLifep;
-        delete elseLifep;
+        VL_DO_DANGLING(delete ifLifep, ifLifep);
+        VL_DO_DANGLING(delete elseLifep, elseLifep);
     }
 
-    virtual void visit(AstWhile* nodep) {
+    virtual void visit(AstWhile* nodep) VL_OVERRIDE {
         // While's are a problem, as we don't allow loops in the graph.  We
         // may go around the cond/body multiple times.  Thus a
         // lifelication just in the body is ok, but we can't delete an
@@ -377,22 +377,21 @@ private:
             m_lifep = condLifep;
             iterateAndNextNull(nodep->precondsp());
             iterateAndNextNull(nodep->condp());
-            m_lifep = prevLifep;
         }
         {
             m_lifep = bodyLifep;
             iterateAndNextNull(nodep->bodysp());
             iterateAndNextNull(nodep->incsp());
-            m_lifep = prevLifep;
         }
+        m_lifep = prevLifep;
         UINFO(4,"   joinfor"<<endl);
         // For the next assignments, clear any variables that were read or written in the block
         condLifep->lifeToAbove();
         bodyLifep->lifeToAbove();
-        delete condLifep;
-        delete bodyLifep;
+        VL_DO_DANGLING(delete condLifep, condLifep);
+        VL_DO_DANGLING(delete bodyLifep, bodyLifep);
     }
-    virtual void visit(AstJumpLabel* nodep) {
+    virtual void visit(AstJumpLabel* nodep) VL_OVERRIDE {
         // As with While's we can't predict if a JumpGo will kill us or not
         // It's worse though as an IF(..., JUMPGO) may change the control flow.
         // Just don't optimize blocks with labels; they're rare - so far.
@@ -409,9 +408,9 @@ private:
         UINFO(4,"   joinjump"<<endl);
         // For the next assignments, clear any variables that were read or written in the block
         bodyLifep->lifeToAbove();
-        delete bodyLifep;
+        VL_DO_DANGLING(delete bodyLifep, bodyLifep);
     }
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstCCall* nodep) VL_OVERRIDE {
         //UINFO(4,"  CCALL "<<nodep<<endl);
         iterateChildren(nodep);
         // Enter the function and trace it
@@ -420,8 +419,8 @@ private:
             iterate(nodep->funcp());
         }
     }
-    virtual void visit(AstCFunc* nodep) {
-        //UINFO(4,"  CCALL "<<nodep<<endl);
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
+        //UINFO(4,"  CFUNC "<<nodep<<endl);
         if (!m_tracingCall && !nodep->entryPoint()) return;
         m_tracingCall = false;
         if (nodep->dpiImport() && !nodep->pure()) {
@@ -429,17 +428,17 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstUCFunc* nodep) {
+    virtual void visit(AstUCFunc* nodep) VL_OVERRIDE {
         m_sideEffect = true;  // If appears on assign RHS, don't ever delete the assignment
         iterateChildren(nodep);
     }
-    virtual void visit(AstCMath* nodep) {
+    virtual void visit(AstCMath* nodep) VL_OVERRIDE {
         m_sideEffect = true;  // If appears on assign RHS, don't ever delete the assignment
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstVar*) {}  // Don't want varrefs under it
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Don't want varrefs under it
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
@@ -454,12 +453,13 @@ public:
         {
             m_lifep = new LifeBlock(NULL, m_statep);
             iterate(nodep);
-            if (m_lifep) { delete m_lifep; m_lifep = NULL; }
+            if (m_lifep) VL_DO_CLEAR(delete m_lifep, m_lifep = NULL);
         }
     }
     virtual ~LifeVisitor() {
-        if (m_lifep) { delete m_lifep; m_lifep = NULL; }
+        if (m_lifep) VL_DO_CLEAR(delete m_lifep, m_lifep = NULL);
     }
+    VL_UNCOPYABLE(LifeVisitor);
 };
 
 //######################################################################
@@ -472,28 +472,28 @@ private:
     LifeState* m_statep;        // Current state
 
     // VISITORS
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         if (nodep->entryPoint()) {
             // Usage model 1: Simulate all C code, doing lifetime analysis
             LifeVisitor visitor (nodep, m_statep);
         }
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstInitial* nodep) {
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstFinal* nodep) {
+    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstVar*) {}  // Accelerate
-    virtual void visit(AstNodeStmt*) {}  // Accelerate
-    virtual void visit(AstNodeMath*) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeStmt*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
