@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Convert BLOCKTEMPs to local variables
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -25,7 +25,7 @@
 //             if non-public, set before used, and in single CFUNC, make it local
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -77,14 +77,14 @@ private:
     // See above
 
     // METHODS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         VarFlags flags (nodep->varp());
         if (flags.m_done) {
             nodep->hiername("");  // Remove this->
             nodep->hierThis(true);
         }
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
@@ -107,8 +107,8 @@ private:
     AstUser4InUse       m_inuser4;
 
     // STATE
-    V3Double0   m_statLocVars;  // Statistic tracking
-    AstCFunc*   m_cfuncp;       // Current active function
+    VDouble0 m_statLocVars;  // Statistic tracking
+    AstCFunc* m_cfuncp;  // Current active function
     std::vector<AstVar*> m_varps;  // List of variables to consider for deletion
 
     // METHODS
@@ -151,11 +151,11 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         moveVars();
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         UINFO(4,"  CFUNC "<<nodep<<endl);
         m_cfuncp = nodep;
         searchFuncStmts(nodep->argsp());
@@ -173,7 +173,7 @@ private:
         for (; nodep; nodep=nodep->nextp()) {
             if (VN_IS(nodep, NodeAssign)) {
                 if (AstVarRef* varrefp = VN_CAST(VN_CAST(nodep, NodeAssign)->lhsp(), VarRef)) {
-                    if (!varrefp->lvalue()) varrefp->v3fatalSrc("LHS assignment not lvalue");
+                    UASSERT_OBJ(varrefp->lvalue(), varrefp, "LHS assignment not lvalue");
                     if (!varrefp->varp()->user4p()) {
                         UINFO(4,"      FuncAsn "<<varrefp<<endl);
                         varrefp->varp()->user4p(varrefp);
@@ -186,7 +186,7 @@ private:
         }
     }
 
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         if (!nodep->isSigPublic()
             && !nodep->isPrimaryIO()
             && !m_cfuncp) {  // Not already inside a function
@@ -195,7 +195,7 @@ private:
         }
         // No iterate; Don't want varrefs under it
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (!VarFlags(nodep->varp()).m_notOpt) {
             if (!m_cfuncp) {  // Not in function, can't optimize
                 clearOptimizable(nodep->varp(), "BVnofunc");
@@ -224,7 +224,7 @@ private:
         }
         // No iterate; Don't want varrefs under it
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
