@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Change names for __PVT__'s
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -22,13 +22,14 @@
 //      Cell/Var's
 //              Prepend __PVT__ to variable names
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
 #include "V3Global.h"
 #include "V3Name.h"
 #include "V3Ast.h"
+#include "V3File.h"
 #include "V3LanguageWords.h"
 
 #include <algorithm>
@@ -58,13 +59,15 @@ private:
             if (addPvt) {
                 string newname = string("__PVT__")+nodep->name();
                 nodep->name(newname);
+                nodep->editCountInc();
             } else {
                 string rsvd = m_words.isKeyword(nodep->name());
                 if (rsvd != "") {
                     nodep->v3warn(SYMRSVDWORD, "Symbol matches "+rsvd
-                                  +": '"<<nodep->prettyName()<<"'");
+                                  +": "<<nodep->prettyNameQ());
                     string newname = string("__SYM__")+nodep->name();
                     nodep->name(newname);
+                    nodep->editCountInc();
                 }
             }
             nodep->user1(1);
@@ -72,50 +75,53 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
     // Add __PVT__ to names of local signals
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         // Don't iterate... Don't need temps for RANGES under the Var.
         rename(nodep, (!m_modp->isTop()
                        && !nodep->isSigPublic()
                        && !nodep->isFuncLocal()  // Isn't exposed, and would mess up dpi import wrappers
                        && !nodep->isTemp()));  // Don't bother to rename internal signals
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         if (!nodep->user1()) {
             iterateChildren(nodep);
             rename(nodep, false);
         }
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->varp()) {
             iterate(nodep->varp());
             nodep->name(nodep->varp()->name());
         }
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         if (!nodep->user1()) {
             rename(nodep, !nodep->modp()->modPublic());
             iterateChildren(nodep);
         }
     }
-    virtual void visit(AstMemberDType* nodep) {
+    virtual void visit(AstMemberDType* nodep) VL_OVERRIDE {
         if (!nodep->user1()) {
             rename(nodep, false);
             iterateChildren(nodep);
         }
     }
-    virtual void visit(AstMemberSel* nodep) {
+    virtual void visit(AstMemberSel* nodep) VL_OVERRIDE {
         if (!nodep->user1()) {
             rename(nodep, false);
             iterateChildren(nodep);
         }
     }
-    virtual void visit(AstScope* nodep) {
+    virtual void visit(AstScope* nodep) VL_OVERRIDE {
         if (!nodep->user1SetOnce()) {
             if (nodep->aboveScopep()) iterate(nodep->aboveScopep());
             if (nodep->aboveCellp()) iterate(nodep->aboveCellp());
@@ -128,11 +134,11 @@ private:
     }
 
     //--------------------
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit NameVisitor(AstNetlist* nodep) {
         m_modp = NULL;
         iterate(nodep);
