@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Large 4-state numbers
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3NUMBER_H_
 #define _V3NUMBER_H_ 1
 
@@ -42,6 +42,7 @@ class V3Number {
     bool        m_fromString:1; // True if from string literal
     bool        m_autoExtend:1; // True if SystemVerilog extend-to-any-width
     FileLine*   m_fileline;
+    AstNode*    m_nodep;        // Parent node
     std::vector<uint32_t> m_value;  // The Value, with bit 0 being in bit 0 of this vector (unless X/Z)
     std::vector<uint32_t> m_valueX;  // Each bit is true if it's X or Z, 10=z, 11=x
     string              m_stringVal;  // If isString, the value of the string
@@ -139,8 +140,8 @@ public:
     // CONSTRUCTORS
     explicit V3Number(AstNode* nodep) { init(nodep, 1); }
     V3Number(AstNode* nodep, int width) { init(nodep, width); }  // 0=unsized
-    V3Number(AstNode* nodep, int width, uint32_t value) {
-        init(nodep, width); m_value[0] = value; opCleanThis();
+    V3Number(AstNode* nodep, int width, uint32_t value, bool sized=true) {
+        init(nodep, width, sized); m_value[0] = value; opCleanThis();
     }
     // Create from a verilog 32'hxxxx number.
     V3Number(AstNode* nodep, const char* sourcep) { V3NumberCreate(nodep, sourcep, NULL); }
@@ -150,7 +151,7 @@ public:
     V3Number(VerilogStringLiteral, AstNode* nodep, const string& str);
     class String {};
     V3Number(String, AstNode* nodep, const string& value) { init(nodep, 0); setString(value); }
-    V3Number(const V3Number* nump, int width = 1) {
+    explicit V3Number(const V3Number* nump, int width = 1) {
         init(NULL, width);
         m_fileline = nump->fileline();
     }
@@ -163,17 +164,18 @@ public:
 
 private:
     void V3NumberCreate(AstNode* nodep, const char* sourcep, FileLine* fl);
-    void init(AstNode* nodep, int swidth) {
+    void init(AstNode* nodep, int swidth, bool sized=true) {
         setNames(nodep);
         m_signed = false;
         m_double = false;
         m_isString = false;
         m_autoExtend = false;
         m_fromString = false;
-        width(swidth);
+        width(swidth, sized);
         for (int i=0; i<words(); i++) m_value[i] = m_valueX[i] = 0;
     }
     void setNames(AstNode* nodep);
+    static string displayPad(size_t fmtsize, char pad, bool left, const string& in);
     string displayed(FileLine* fl, const string& vformat) const;
     string displayed(const string& vformat) const {
         return displayed(m_fileline, vformat);
@@ -213,10 +215,7 @@ public:
     bool isString() const { return m_isString; }
     void isString(bool flag)  { m_isString = flag; }
     bool isNegative() const { return bitIs1(width()-1); }
-    bool isFourState() const {
-        for (int i=0;i<words();i++) { if (m_valueX[i]) return true; }
-        return false;
-    }
+    bool isFourState() const;
     bool hasZ() const {
         for(int i=0;i<words();i++) { if ((~m_value[i]) & m_valueX[i]) return true; }
         return false;
@@ -245,8 +244,8 @@ public:
     string toDecimalU() const;  // return ASCII unsigned decimal number
     double toDouble() const;
     uint32_t toHash() const;
-    uint32_t dataWord(int word) const;
-    uint8_t dataByte(int byte) const { return (dataWord(byte/4) >> (8*(byte&3))) & 0xff; }
+    uint32_t edataWord(int eword) const;
+    uint8_t dataByte(int byte) const;
     uint32_t countOnes() const;
     uint32_t mostSetBitP1() const;  // Highest bit set plus one, IE for 16 return 5, for 0 return 0.
 
@@ -290,6 +289,8 @@ public:
     V3Number& opSel     (const V3Number& lhs, uint32_t msbval, uint32_t lsbval);
     V3Number& opSelInto (const V3Number& lhs, const V3Number& lsb, int width);
     V3Number& opSelInto (const V3Number& lhs, int lsbval, int width);
+    V3Number& opToLowerN(const V3Number& lhs);
+    V3Number& opToUpperN(const V3Number& lhs);
     V3Number& opCond    (const V3Number& lhs, const V3Number& if1s, const V3Number& if0s);
     V3Number& opCaseEq  (const V3Number& lhs, const V3Number& rhs);
     V3Number& opCaseNeq (const V3Number& lhs, const V3Number& rhs);
@@ -360,6 +361,11 @@ public:
     V3Number& opLteD    (const V3Number& lhs, const V3Number& rhs);
 
     // "N" - string operations
+    V3Number& opAtoN    (const V3Number& lhs, int base);
+    V3Number& opPutcN   (const V3Number& lhs, const V3Number& rhs, const V3Number& ths);
+    V3Number& opGetcN   (const V3Number& lhs, const V3Number& rhs);
+    V3Number& opSubstrN (const V3Number& lhs, const V3Number& rhs, const V3Number& ths);
+    V3Number& opCompareNN(const V3Number& lhs,const V3Number& rhs, bool ignoreCase);
     V3Number& opConcatN (const V3Number& lhs, const V3Number& rhs);
     V3Number& opReplN   (const V3Number& lhs, const V3Number& rhs);
     V3Number& opReplN   (const V3Number& lhs, uint32_t rhsval);
