@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Netlist (top level) functions
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 // CHEAT!
 #define V3NUMBER_ASCII_BINARY
 #define _V3ERROR_NO_GLOBAL_ 1
@@ -38,11 +38,12 @@ void test(const string& lhss, const string& op, const string& rhss, const string
     char* r1 = strdup(rhss.c_str());
     char* e1 = strdup(exps.c_str());
 
-    V3Number lhnum (new FileLine("ck", __LINE__), l1);
-    V3Number rhnum (new FileLine("ck", __LINE__), r1);
-    V3Number expnum (new FileLine("ck", __LINE__), e1);
+    FileLine fl = new FileLine(FileLine::builtInFinename());
 
-    V3Number gotnum (new FileLine("ck", __LINE__), expnum.width());
+    V3Number lhnum (fl, l1);
+    V3Number rhnum (fl, r1);
+    V3Number expnum (fl, e1);
+    V3Number gotnum (fl, expnum.width());
 
     if (op=="redOr")            gotnum.opRedOr   (lhnum);
     else if (op=="redAnd")      gotnum.opRedAnd  (lhnum);
@@ -82,7 +83,7 @@ void test(const string& lhss, const string& op, const string& rhss, const string
           <<"     = "<<expnum<<endl
           <<"    =? "<<gotnum<<endl);
 
-    V3Number ok (new FileLine("ck", __LINE__), 1);
+    V3Number ok (fl, 1);
     ok.opCaseEq(expnum, gotnum);
     if (ok.toUInt()!=1) {
         v3fatalSrc("%Error:Test FAILED");
