@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Options parsing
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -44,6 +44,10 @@
 
 #include "config_rev.h"
 
+#if defined(_WIN32) || defined(__MINGW32__)
+# include <io.h>  // open, close
+#endif
+
 //######################################################################
 // V3 Internal state
 
@@ -173,14 +177,12 @@ void V3Options::checkParameters() {
                 it != m_parameters.end(); ++it) {
             msg << " " << it->first;
         }
-        v3fatal(msg.str()<<endl);
+        v3error(msg.str());
     }
 }
 
 void V3Options::addCppFile(const string& filename) {
-    if (m_cppFiles.find(filename) == m_cppFiles.end()) {
-        m_cppFiles.insert(filename);
-    }
+    m_cppFiles.insert(filename);
 }
 void V3Options::addCFlags(const string& filename) {
     m_cFlags.push_back(filename);
@@ -189,9 +191,7 @@ void V3Options::addLdLibs(const string& filename) {
     m_ldLibs.push_back(filename);
 }
 void V3Options::addFuture(const string& flag) {
-    if (m_futures.find(flag) == m_futures.end()) {
-        m_futures.insert(flag);
-    }
+    m_futures.insert(flag);
 }
 bool V3Options::isFuture(const string& flag) const {
     return m_futures.find(flag) != m_futures.end();
@@ -200,25 +200,19 @@ bool V3Options::isLibraryFile(const string& filename) const {
     return m_libraryFiles.find(filename) != m_libraryFiles.end();
 }
 void V3Options::addLibraryFile(const string& filename) {
-    if (m_libraryFiles.find(filename) == m_libraryFiles.end()) {
-        m_libraryFiles.insert(filename);
-    }
+    m_libraryFiles.insert(filename);
 }
 bool V3Options::isClocker(const string& signame) const {
     return m_clockers.find(signame) != m_clockers.end();
 }
 void V3Options::addClocker(const string& signame) {
-    if (m_clockers.find(signame) == m_clockers.end()) {
-        m_clockers.insert(signame);
-    }
+    m_clockers.insert(signame);
 }
 bool V3Options::isNoClocker(const string& signame) const {
     return m_noClockers.find(signame) != m_noClockers.end();
 }
 void V3Options::addNoClocker(const string& signame) {
-    if (m_noClockers.find(signame) == m_noClockers.end()) {
-        m_noClockers.insert(signame);
-    }
+    m_noClockers.insert(signame);
 }
 void V3Options::addVFile(const string& filename) {
     // We use a list for v files, because it's legal to have includes
@@ -250,7 +244,7 @@ V3LangCode::V3LangCode(const char* textp) {
     // Return code for given string, or ERROR, which is a bad code
     for (int codei=V3LangCode::L_ERROR; codei<V3LangCode::_ENUM_END; ++codei) {
         V3LangCode code = V3LangCode(codei);
-        if (0==strcasecmp(textp, code.ascii())) {
+        if (0 == VL_STRCASECMP(textp, code.ascii())) {
             m_e = code; return;
         }
     }
@@ -370,7 +364,12 @@ string V3Options::filePath(FileLine* fl, const string& modname, const string& la
 
 void V3Options::filePathLookedMsg(FileLine* fl, const string& modname) {
     static bool shown_notfound_msg = false;
-    if (!shown_notfound_msg) {
+    if (modname.find("__Vhsh") != string::npos) {
+        std::cerr << V3Error::warnMore() << "... Unsupported: Name is longer than 127 characters;"
+                  << " automatic file lookup not supported.\n";
+        std::cerr << V3Error::warnMore() << "... Suggest putting filename with this module/package"
+                  << " onto command line instead.\n";
+    } else if (!shown_notfound_msg) {
         shown_notfound_msg = true;
         if (m_impp->m_incDirUsers.empty()) {
             fl->v3error("This may be because there's no search path specified with -I<dir>."<<endl);
@@ -522,6 +521,64 @@ string V3Options::getenvVERILATOR_ROOT() {
     return var;
 }
 
+//######################################################################
+// V3 Options notification methods
+
+void V3Options::notify() {
+    // Notify that all arguments have been passed and final modification can be made.
+    if (!outFormatOk()
+        && !cdc()
+        && !dpiHdrOnly()
+        && !lintOnly()
+        && !preprocOnly()
+        && !xmlOnly()) {
+        v3fatal("verilator: Need --cc, --sc, --cdc, --dpi-hdr-only, --lint-only, --xml-only or --E option");
+    }
+
+    // Make sure at least one make system is enabled
+    if (!m_gmake && !m_cmake) {
+        m_gmake = true;
+    }
+
+    if (protectIds()) {
+        FileLine* cmdfl = new FileLine(FileLine::commandLineFilename());
+        if (allPublic()) {
+            // We always call protect() on names, we don't check if public or not
+            // Hence any external references wouldn't be able to find the refed public object.
+            cmdfl->v3error("Unsupported: Using --protect-ids with --public\n"
+                           +V3Error::warnMore()+"... Suggest remove --public.");
+        }
+        if (trace()) {
+            cmdfl->v3warn(INSECURE,
+                          "Using --protect-ids with --trace may expose private design details\n"
+                          +V3Error::warnMore()+"... Suggest remove --trace.");
+        }
+        if (vpi()) {
+            cmdfl->v3warn(INSECURE,
+                          "Using --protect-ids with --vpi may expose private design details\n"
+                          +V3Error::warnMore()+"... Suggest remove --vpi.");
+        }
+    }
+
+    // Default some options if not turned on or off
+    if (v3Global.opt.skipIdentical().isDefault()) {
+        v3Global.opt.m_skipIdentical.setTrueOrFalse(
+            !v3Global.opt.cdc()
+            && !v3Global.opt.dpiHdrOnly()
+            && !v3Global.opt.lintOnly()
+            && !v3Global.opt.preprocOnly()
+            && !v3Global.opt.xmlOnly());
+    }
+    if (v3Global.opt.makeDepend().isDefault()) {
+        v3Global.opt.m_makeDepend.setTrueOrFalse(
+            !v3Global.opt.cdc()
+            && !v3Global.opt.dpiHdrOnly()
+            && !v3Global.opt.lintOnly()
+            && !v3Global.opt.preprocOnly()
+            && !v3Global.opt.xmlOnly());
+    }
+}
+
 //######################################################################
 // V3 Options accessors
 
@@ -531,6 +588,16 @@ string V3Options::version() {
     return ver;
 }
 
+string V3Options::protectKeyDefaulted() {
+    if (m_protectKey.empty()) {
+        // Create a key with a human-readable symbol-like name.
+        // This conversion drops ~2 bits of entropy out of 256, shouldn't matter.
+        VHashSha256 digest (V3Os::trueRandom(32));
+        m_protectKey = "VL-KEY-"+digest.digestSymbol();
+    }
+    return m_protectKey;
+}
+
 void V3Options::throwSigsegv() {
 #if !(defined(VL_CPPCHECK) || defined(__clang_analyzer__))
     char* zp=NULL; *zp=0;  // Intentional core dump, ignore warnings here
@@ -555,7 +622,7 @@ string V3Options::argString(int argc, char** argv) {
 
 void V3Options::parseOpts(FileLine* fl, int argc, char** argv) {
     // Parse all options
-    // Inital entry point from Verilator.cpp
+    // Initial entry point from Verilator.cpp
     parseOptsList(fl, ".", argc, argv);
 
     // Default certain options and error check
@@ -589,6 +656,15 @@ bool V3Options::onoff(const char* sw, const char* arg, bool& flag) {
     else if (0==strncmp(sw, "-no-", 4) && (0==strcmp(sw+4, arg+1))) { flag = false; return true; }
     return false;
 }
+bool V3Options::onoffb(const char* sw, const char* arg, VOptionBool& bflag) {
+    bool flag;
+    if (onoff(sw, arg, flag/*ref*/)) {
+        bflag.setTrueOrFalse(flag);
+        return true;
+    } else {
+        return false;
+    }
+}
 
 bool V3Options::suffixed(const string& sw, const char* arg) {
     if (strlen(arg) > sw.length()) return false;
@@ -606,7 +682,7 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
     for (int i=0; i<argc; )  {
         UINFO(9, " Option: "<<argv[i]<<endl);
         if (argv[i][0]=='+') {
-            char *sw = argv[i];
+            char* sw = argv[i];
             if (!strncmp (sw, "+define+", 8)) {
                 addDefine(string(sw+strlen("+define+")), true);
             }
@@ -645,14 +721,16 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             shift;
         }  // + options
         else if (argv[i][0]=='-') {
-            const char *sw = argv[i];
+            const char* sw = argv[i];
             bool flag = true;
+            VOptionBool bflag;
             // Allow gnu -- switches
             if (sw[0]=='-' && sw[1]=='-') ++sw;
+            bool hadSwitchPart1 = true;
             if (0) {}
             // Single switches
             else if (!strcmp(sw, "-E"))                         { m_preprocOnly = true; }
-            else if ( onoff (sw, "-MMD", flag/*ref*/))          { m_makeDepend = flag; }
+            else if ( onoffb(sw, "-MMD", bflag/*ref*/))         { m_makeDepend = bflag; }
             else if ( onoff (sw, "-MP", flag/*ref*/))           { m_makePhony = flag; }
             else if (!strcmp(sw, "-P"))                         { m_preprocNoLine = true; }
             else if ( onoff (sw, "-assert", flag/*ref*/))       { m_assert = flag; }
@@ -669,14 +747,16 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if ( onoff (sw, "-covsp", flag/*ref*/))        { }  // TBD
             else if (!strcmp(sw, "-debug-abort")) { abort(); }  // Undocumented, see also --debug-sigsegv
             else if ( onoff (sw, "-debug-check", flag/*ref*/))  { m_debugCheck = flag; }
-            else if ( onoff   (sw, "-debug-collision", flag/*ref*/) ){ m_debugCollision = flag; }  // Undocumented
+            else if ( onoff (sw, "-debug-collision", flag/*ref*/)) { m_debugCollision = flag; }  // Undocumented
             else if ( onoff (sw, "-debug-leak", flag/*ref*/))   { m_debugLeak = flag; }
             else if ( onoff (sw, "-debug-nondeterminism", flag/*ref*/)){ m_debugNondeterminism = flag; }
             else if ( onoff (sw, "-debug-partition", flag/*ref*/)){ m_debugPartition = flag; }  // Undocumented
+            else if ( onoff (sw, "-debug-protect", flag/*ref*/)){ m_debugProtect = flag; }  // Undocumented
             else if ( onoff (sw, "-debug-self-test", flag/*ref*/)){ m_debugSelfTest = flag; }  // Undocumented
             else if (!strcmp(sw, "-debug-sigsegv"))             { throwSigsegv(); }  // Undocumented, see also --debug-abort
             else if (!strcmp(sw, "-debug-fatalsrc"))            { v3fatalSrc("--debug-fatal-src"); }  // Undocumented, see also --debug-abort
             else if ( onoff (sw, "-decoration", flag/*ref*/))   { m_decoration = flag; }
+            else if ( onoff (sw, "-dpi-hdr-only", flag/*ref*/)) { m_dpiHdrOnly = flag; }
             else if ( onoff (sw, "-dump-defines", flag/*ref*/)) { m_dumpDefines = flag; }
             else if ( onoff (sw, "-dump-tree", flag/*ref*/))    { m_dumpTree = flag ? 3 : 0; }  // Also see --dump-treei
             else if ( onoff (sw, "-exe", flag/*ref*/))          { m_exe = flag; }
@@ -694,27 +774,33 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if ( onoff (sw, "-prof-cfuncs", flag/*ref*/))       { m_profCFuncs = flag; }
             else if ( onoff (sw, "-profile-cfuncs", flag/*ref*/))    { m_profCFuncs = flag; }  // Undocumented, for backward compat
             else if ( onoff (sw, "-prof-threads", flag/*ref*/))      { m_profThreads = flag; }
+            else if ( onoff (sw, "-protect-ids", flag/*ref*/))       { m_protectIds = flag; }
             else if ( onoff (sw, "-public", flag/*ref*/))            { m_public = flag; }
-            else if (!strncmp(sw, "-pvalue+", strlen("-pvalue+")))     { addParameter(string(sw+strlen("-pvalue+")), false); }
+            else if ( onoff (sw, "-public-flat-rw", flag/*ref*/) )   { m_publicFlatRW = flag; v3Global.dpi(true); }
+            else if (!strncmp(sw, "-pvalue+", strlen("-pvalue+")))   { addParameter(string(sw+strlen("-pvalue+")), false); }
             else if ( onoff (sw, "-relative-cfuncs", flag/*ref*/))   { m_relativeCFuncs = flag; }
             else if ( onoff (sw, "-relative-includes", flag/*ref*/)) { m_relativeIncludes = flag; }
             else if ( onoff (sw, "-report-unoptflat", flag/*ref*/))  { m_reportUnoptflat = flag; }
             else if ( onoff (sw, "-savable", flag/*ref*/))           { m_savable = flag; }
             else if (!strcmp(sw, "-sc"))                             { m_outFormatOk = true; m_systemC = true; }
-            else if ( onoff (sw, "-skip-identical", flag/*ref*/))    { m_skipIdentical = flag; }
+            else if ( onoffb(sw, "-skip-identical", bflag/*ref*/))   { m_skipIdentical = bflag; }
             else if ( onoff (sw, "-stats", flag/*ref*/))             { m_stats = flag; }
             else if ( onoff (sw, "-stats-vars", flag/*ref*/))        { m_statsVars = flag; m_stats |= flag; }
             else if (!strcmp(sw, "-sv"))                             { m_defaultLanguage = V3LangCode::L1800_2005; }
             else if ( onoff (sw, "-threads-coarsen", flag/*ref*/))   { m_threadsCoarsen = flag; }  // Undocumented, debug
             else if ( onoff (sw, "-trace", flag/*ref*/))             { m_trace = flag; }
+            else if ( onoff (sw, "-trace-coverage", flag/*ref*/))    { m_traceCoverage = flag; }
             else if ( onoff (sw, "-trace-dups", flag/*ref*/))        { m_traceDups = flag; }
             else if ( onoff (sw, "-trace-params", flag/*ref*/))      { m_traceParams = flag; }
             else if ( onoff (sw, "-trace-structs", flag/*ref*/))     { m_traceStructs = flag; }
             else if ( onoff (sw, "-trace-underscore", flag/*ref*/))  { m_traceUnderscore = flag; }
             else if ( onoff (sw, "-underline-zero", flag/*ref*/))    { m_underlineZero = flag; }  // Undocumented, old Verilator-2
             else if ( onoff (sw, "-vpi", flag/*ref*/))               { m_vpi = flag; }
+            else if ( onoff (sw, "-Wpedantic", flag/*ref*/))         { m_pedantic = flag; }
             else if ( onoff (sw, "-x-initial-edge", flag/*ref*/))    { m_xInitialEdge = flag; }
             else if ( onoff (sw, "-xml-only", flag/*ref*/))          { m_xmlOnly = flag; }  // Undocumented, still experimental
+            else { hadSwitchPart1 = false; }
+            if (hadSwitchPart1) {}
             // Optimization
             else if (!strncmp (sw, "-O", 2)) {
                 for (const char* cp=sw+strlen("-O"); *cp; ++cp) {
@@ -730,7 +816,6 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                     case 'd': m_oDedupe = flag; break;
                     case 'm': m_oAssemble = flag; break;
                     case 'e': m_oCase = flag; break;
-                    case 'f': m_oFlopGater = flag; break;
                     case 'g': m_oGate = flag; break;
                     case 'i': m_oInline = flag; break;
                     case 'k': m_oSubstConst = flag; break;
@@ -812,6 +897,10 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                 shift;
                 m_gateStmts = atoi(argv[i]);
             }
+            else if (!strcmp(sw, "-generate-key")) {
+                cout<<protectKeyDefaulted()<<endl;
+                exit(0);
+            }
             else if (!strcmp(sw, "-getenv") && (i+1)<argc) {
                 shift;
                 cout<<V3Options::getenvBuiltins(argv[i])<<endl;
@@ -839,6 +928,20 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if (!strcmp(sw, "-l2name")) {  // Historical and undocumented
                 m_l2Name = "v";
             }
+            else if (!strcmp(sw, "-make")) {
+                shift;
+                if (!strcmp(argv[i], "cmake")) {
+                    m_cmake = true;
+                } else if (!strcmp(argv[i], "gmake")) {
+                    m_gmake = true;
+                } else {
+                    fl->v3fatal("Unknown --make system specified: '"<<argv[i]<<"'");
+                }
+            }
+            else if (!strcmp(sw, "-max-num-width")) {
+                shift;
+                m_maxNumWidth = atoi(argv[i]);
+            }
             else if (!strcmp(sw, "-no-l2name")) {  // Historical and undocumented
                 m_l2Name = "";
             }
@@ -875,6 +978,10 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                 shift;
                 m_outputSplitCTrace = atoi(argv[i]);
             }
+            else if (!strcmp(sw, "-protect-lib") && (i+1)<argc) {
+                shift; m_protectLib = argv[i];
+                m_protectIds = true;
+            }
             else if (!strcmp(sw, "-trace-fst")) {
                 m_trace = true;
                 m_traceFormat = TraceFormat::FST;
@@ -949,16 +1056,19 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                 addFuture(msg);
             }
             else if (!strncmp (sw, "-Wno-", 5)) {
-                if (!strcmp(sw, "-Wno-lint")) {
+                if (!strcmp(sw, "-Wno-context")) {
+                    m_context = false;
+                }
+                else if (!strcmp(sw, "-Wno-fatal")) {
+                    V3Error::warnFatal(false);
+                }
+                else if (!strcmp(sw, "-Wno-lint")) {
                     FileLine::globalWarnLintOff(true);
                     FileLine::globalWarnStyleOff(true);
                 }
                 else if (!strcmp(sw, "-Wno-style")) {
                     FileLine::globalWarnStyleOff(true);
                 }
-                else if (!strcmp(sw, "-Wno-fatal")) {
-                    V3Error::warnFatal(false);
-                }
                 else {
                     string msg = sw+strlen("-Wno-");
                     if (!(FileLine::globalWarnOff(msg, true))) {
@@ -1018,6 +1128,9 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if (!strcmp(sw, "-gdb")) {
                 // Used only in perl shell
             }
+            else if (!strcmp(sw, "-rr")) {
+                // Used only in perl shell
+            }
             else if (!strcmp(sw, "-gdbbt")) {
                 // Used only in perl shell
             }
@@ -1038,6 +1151,9 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                 shift; m_prefix = argv[i];
                 if (m_modPrefix=="") m_modPrefix = m_prefix;
             }
+            else if (!strcmp(sw, "-protect-key") && (i+1)<argc) {
+                shift; m_protectKey = argv[i];
+            }
             else if (!strcmp(sw, "-no-threads")) { m_threads = 0; }  // Undocumented until functional
             else if (!strcmp(sw, "-threads") && (i+1)<argc) {  // Undocumented until functional
                 shift; m_threads = atoi(argv[i]);
@@ -1085,6 +1201,10 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                     fl->v3fatal("Unknown setting for --x-initial: "<<argv[i]);
                 }
             }
+            else if (!strcmp(sw, "-xml-output") && (i+1)<argc) {
+                shift; m_xmlOutput = argv[i];
+                m_xmlOnly = true;
+            }
             else if (!strcmp(sw, "-y") && (i+1)<argc) {
                 shift; addIncDirUser(parseFileArg(optdir, string(argv[i])));
             }
@@ -1136,13 +1256,15 @@ void V3Options::parseOptsFile(FileLine* fl, const string& filename, bool rel) {
         // Strip simple comments
         string oline;
         // cppcheck-suppress StlMissingComparison
-        for (string::const_iterator pos = line.begin(); pos != line.end(); ++pos) {
+        char lastch = ' ';
+        for (string::const_iterator pos = line.begin(); pos != line.end(); lastch = *pos++) {
             if (inCmt) {
                 if (*pos=='*' && *(pos+1)=='/') {
                     inCmt = false;
                     ++pos;
                 }
-            } else if (*pos=='/' && *(pos+1)=='/') {
+            } else if (*pos=='/' && *(pos+1)=='/'
+                       && (pos == line.begin() || isspace(lastch))) {    // But allow /file//path
                 break;  // Ignore to EOL
             } else if (*pos=='/' && *(pos+1)=='*') {
                 inCmt = true;
@@ -1157,39 +1279,100 @@ void V3Options::parseOptsFile(FileLine* fl, const string& filename, bool rel) {
     whole_file += "\n";  // So string match below is simplified
     if (inCmt) fl->v3error("Unterminated /* comment inside -f file.");
 
-    fl = new FileLine(filename, 0);
+    fl = new FileLine(filename);
 
     // Split into argument list and process
-    // Note we don't respect quotes.  It seems most simulators dont.
-    // Woez those that expect it; we'll at least complain.
-    if (whole_file.find('\"') != string::npos) {
-        fl->v3error("Double quotes in -f files cause unspecified behavior.");
-    }
+    // Note we try to respect escaped char, double/simple quoted strings
+    // Other simulators don't respect a common syntax...
 
     // Strip off arguments and parse into words
     std::vector<string> args;
-    string::size_type startpos = 0;
-    while (startpos < whole_file.length()) {
-        while (isspace(whole_file[startpos])) ++startpos;
-        string::size_type endpos = startpos;
-        while (endpos < whole_file.length() && !isspace(whole_file[endpos])) ++endpos;
-        if (startpos != endpos) {
-            string arg (whole_file, startpos, endpos-startpos);
-            args.reserve(args.size()+1);
-            args.push_back(arg);
+
+    // Parse file using a state machine, taking into account quoted strings and escaped chars
+    enum state {ST_IN_OPTION,
+                ST_ESCAPED_CHAR,
+                ST_IN_QUOTED_STR,
+                ST_IN_DOUBLE_QUOTED_STR};
+
+    state st = ST_IN_OPTION;
+    state last_st = ST_IN_OPTION;
+    string arg;
+    for (string::size_type pos = 0;
+         pos < whole_file.length(); ++pos) {
+        char curr_char = whole_file[pos];
+        switch (st) {
+        case ST_IN_OPTION:  // Get all chars up to a white space or a "="
+            if (isspace(curr_char)) {  // End of option
+                if (!arg.empty()) {  // End of word
+                    args.push_back(arg);
+                }
+                arg = "";
+                break;
+            }
+            if (curr_char == '\\') {  // Escape char, we wait for next char
+                last_st = st;  // Memorize current state
+                st = ST_ESCAPED_CHAR;
+                break;
+            }
+            if (curr_char == '\'') {  // Find begin of quoted string
+                // Examine next char in order to decide between
+                // a string or a base specifier for integer literal
+                ++pos;
+                if (pos < whole_file.length()) curr_char = whole_file[pos];
+                if (curr_char == '"') {  // String
+                    st = ST_IN_QUOTED_STR;
+                } else {  // Base specifier
+                    arg += '\'';
+                }
+                arg +=  curr_char;
+                break;
+            }
+            if (curr_char == '"') {  // Find begin of double quoted string
+                // Doesn't insert the quote
+                st = ST_IN_DOUBLE_QUOTED_STR;
+                break;
+            }
+            arg += curr_char;
+            break;
+        case ST_IN_QUOTED_STR:  // Just store all chars inside string
+            if (curr_char != '\'') {
+                arg += curr_char;
+            } else {  // End of quoted string
+                st = ST_IN_OPTION;
+            }
+            break;
+        case ST_IN_DOUBLE_QUOTED_STR:  // Take into account escaped chars
+            if (curr_char != '"') {
+                if (curr_char == '\\') {
+                    last_st = st;
+                    st = ST_ESCAPED_CHAR;
+                } else {
+                    arg += curr_char;
+                }
+            } else {  // End of double quoted string
+                st = ST_IN_OPTION;
+            }
+            break;
+        case ST_ESCAPED_CHAR:  // Just add the escaped char
+            arg += curr_char;
+            st = last_st;
+            break;
         }
-        startpos = endpos;
+    }
+    if (!arg.empty()) {  // Add last word
+        args.push_back(arg);
     }
 
     // Path
     string optdir = (rel ? V3Os::filenameDir(filename) : ".");
 
     // Convert to argv style arg list and parse them
-    char* argv [args.size()+1];
-    for (unsigned i=0; i<args.size(); ++i) {
-        argv[i] = const_cast<char*>(args[i].c_str());
+    std::vector<char*> argv; argv.reserve(args.size()+1);
+    for (std::vector<std::string>::const_iterator it = args.begin(); it != args.end(); ++it) {
+        argv.push_back(const_cast<char*>(it->c_str()));
     }
-    parseOptsList(fl, optdir, args.size(), argv);
+    argv.push_back(NULL); // argv is NULL-terminated
+    parseOptsList(fl, optdir, static_cast<int>(argv.size()-1), argv.data());
 }
 
 //======================================================================
@@ -1225,13 +1408,13 @@ void V3Options::showVersion(bool verbose) {
     if (!verbose) return;
 
     cout <<endl;
-    cout << "Copyright 2003-2019 by Wilson Snyder.  Verilator is free software; you can\n";
+    cout << "Copyright 2003-2020 by Wilson Snyder.  Verilator is free software; you can\n";
     cout << "redistribute it and/or modify the Verilator internals under the terms of\n";
     cout << "either the GNU Lesser General Public License Version 3 or the Perl Artistic\n";
     cout << "License Version 2.0.\n";
 
     cout <<endl;
-    cout << "See http://www.veripool.org/verilator for documentation\n";
+    cout << "See https://verilator.org for documentation\n";
 
     cout <<endl;
     cout << "Summary of configuration:\n";
@@ -1263,6 +1446,8 @@ V3Options::V3Options() {
     m_bboxSys = false;
     m_bboxUnsup = false;
     m_cdc = false;
+    m_cmake = false;
+    m_context = true;
     m_coverageLine = false;
     m_coverageToggle = false;
     m_coverageUnderscore = false;
@@ -1272,17 +1457,20 @@ V3Options::V3Options() {
     m_debugLeak = true;
     m_debugNondeterminism = false;
     m_debugPartition = false;
+    m_debugProtect = false;
     m_debugSelfTest = false;
     m_decoration = true;
+    m_dpiHdrOnly = false;
     m_dumpDefines = false;
     m_exe = false;
     m_ignc = false;
     m_inhibitSim = false;
     m_lintOnly = false;
-    m_makeDepend = true;
+    m_gmake = false;
     m_makePhony = false;
     m_orderClockDly = true;
     m_outFormatOk = false;
+    m_pedantic = false;
     m_pinsBv = 65;
     m_pinsScUint = false;
     m_pinsScBigUint = false;
@@ -1290,14 +1478,15 @@ V3Options::V3Options() {
     m_ppComments = false;
     m_profCFuncs = false;
     m_profThreads = false;
+    m_protectIds = false;
     m_preprocOnly = false;
     m_preprocNoLine = false;
     m_public = false;
+    m_publicFlatRW = false;
     m_relativeCFuncs = true;
     m_relativeIncludes = false;
     m_reportUnoptflat = false;
     m_savable = false;
-    m_skipIdentical = true;
     m_stats = false;
     m_statsVars = false;
     m_systemC = false;
@@ -1307,8 +1496,9 @@ V3Options::V3Options() {
     m_threadsCoarsen = true;
     m_threadsMaxMTasks = 0;
     m_trace = false;
-    m_traceFormat = TraceFormat::VCD;
+    m_traceCoverage = false;
     m_traceDups = false;
+    m_traceFormat = TraceFormat::VCD;
     m_traceParams = true;
     m_traceStructs = false;
     m_traceUnderscore = false;
@@ -1322,6 +1512,7 @@ V3Options::V3Options() {
     m_gateStmts = 100;
     m_ifDepth = 0;
     m_inlineMult = 2000;
+    m_maxNumWidth = 65536;
     m_moduleRecursion = 100;
     m_outputSplit = 0;
     m_outputSplitCFuncs = 0;
@@ -1357,7 +1548,7 @@ V3Options::V3Options() {
 }
 
 V3Options::~V3Options() {
-    delete m_impp; m_impp = NULL;
+    VL_DO_CLEAR(delete m_impp, m_impp = NULL);
 }
 
 void V3Options::setDebugMode(int level) {
@@ -1418,7 +1609,6 @@ void V3Options::optimize(int level) {
     m_oCombine = flag;
     m_oConst = flag;
     m_oExpand = flag;
-    m_oFlopGater = flag;
     m_oGate = flag;
     m_oInline = flag;
     m_oLife = flag;
