@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Command line options
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3OPTIONS_H_
 #define _V3OPTIONS_H_ 1
 
@@ -37,6 +37,43 @@ class FileLine;
 
 //######################################################################
 
+class VOptionBool {
+    // Class to track options that are either not specified (and default
+    // true/false), versus user setting the option to true or false
+public:
+    enum en {
+        OPT_DEFAULT_FALSE = 0,
+        OPT_DEFAULT_TRUE,
+        OPT_TRUE,
+        OPT_FALSE,
+        _ENUM_END
+    };
+    enum en m_e;
+    inline VOptionBool() : m_e(OPT_DEFAULT_FALSE) {}
+    // cppcheck-suppress noExplicitConstructor
+    inline VOptionBool(en _e) : m_e(_e) {}
+    explicit inline VOptionBool(int _e) : m_e(static_cast<en>(_e)) {}
+    operator en() const { return m_e; }
+    bool isDefault() const { return m_e == OPT_DEFAULT_FALSE || m_e == OPT_DEFAULT_TRUE; }
+    bool isTrue() const { return m_e == OPT_TRUE || m_e == OPT_DEFAULT_TRUE; }
+    bool isFalse() const { return m_e == OPT_FALSE || m_e == OPT_DEFAULT_FALSE; }
+    void setTrueOrFalse(bool flag) { m_e = flag ? OPT_TRUE : OPT_FALSE; }
+    const char* ascii() const {
+        static const char* const names[] = {
+            "DEFAULT_FALSE", "DEFAULT_TRUE", "TRUE", "FALSE"};
+        return names[m_e]; }
+};
+inline bool operator==(const VOptionBool& lhs, const VOptionBool& rhs) {
+    return lhs.m_e == rhs.m_e;
+}
+inline bool operator==(const VOptionBool& lhs, VOptionBool::en rhs) { return lhs.m_e == rhs; }
+inline bool operator==(VOptionBool::en lhs, const VOptionBool& rhs) { return lhs == rhs.m_e; }
+inline std::ostream& operator<<(std::ostream& os, const VOptionBool& rhs) {
+    return os << rhs.ascii();
+}
+
+//######################################################################
+
 class TraceFormat {
 public:
     enum en {
@@ -66,9 +103,11 @@ public:
         return names[m_e];
     }
 };
-inline bool operator==(TraceFormat lhs, TraceFormat rhs) { return (lhs.m_e == rhs.m_e); }
-inline bool operator==(TraceFormat lhs, TraceFormat::en rhs) { return (lhs.m_e == rhs); }
-inline bool operator==(TraceFormat::en lhs, TraceFormat rhs) { return (lhs == rhs.m_e); }
+inline bool operator==(const TraceFormat& lhs, const TraceFormat& rhs) {
+    return lhs.m_e == rhs.m_e;
+}
+inline bool operator==(const TraceFormat& lhs, TraceFormat::en rhs) { return lhs.m_e == rhs; }
+inline bool operator==(TraceFormat::en lhs, const TraceFormat& rhs) { return lhs == rhs.m_e; }
 
 typedef std::vector<string> V3StringList;
 typedef std::set<string> V3StringSet;
@@ -101,7 +140,6 @@ class V3Options {
 
 
     bool        m_preprocOnly;  // main switch: -E
-    bool        m_makeDepend;   // main switch: -MMD
     bool        m_makePhony;    // main switch: -MP
     bool        m_preprocNoLine;// main switch: -P
     bool        m_assert;       // main switch: --assert
@@ -109,6 +147,8 @@ class V3Options {
     bool        m_bboxSys;      // main switch: --bbox-sys
     bool        m_bboxUnsup;    // main switch: --bbox-unsup
     bool        m_cdc;          // main switch: --cdc
+    bool        m_cmake;        // main switch: --make cmake
+    bool        m_context;      // main switch: --Wcontext
     bool        m_coverageLine; // main switch: --coverage-block
     bool        m_coverageToggle;// main switch: --coverage-toggle
     bool        m_coverageUnderscore;// main switch: --coverage-underscore
@@ -118,34 +158,40 @@ class V3Options {
     bool        m_debugLeak;    // main switch: --debug-leak
     bool        m_debugNondeterminism;  // main switch: --debug-nondeterminism
     bool        m_debugPartition;  // main switch: --debug-partition
+    bool        m_debugProtect;  // main switch: --debug-protect
     bool        m_debugSelfTest;  // main switch: --debug-self-test
     bool        m_decoration;   // main switch: --decoration
+    bool        m_dpiHdrOnly;   // main switch: --dpi-hdr-only
     bool        m_dumpDefines;  // main switch: --dump-defines
     bool        m_exe;          // main switch: --exe
     bool        m_ignc;         // main switch: --ignc
     bool        m_inhibitSim;   // main switch: --inhibit-sim
     bool        m_lintOnly;     // main switch: --lint-only
+    bool        m_gmake;        // main switch: --make gmake
     bool        m_orderClockDly;// main switch: --order-clock-delay
     bool        m_outFormatOk;  // main switch: --cc, --sc or --sp was specified
+    bool        m_pedantic;     // main switch: --Wpedantic
     bool        m_pinsScUint;   // main switch: --pins-sc-uint
     bool        m_pinsScBigUint;// main switch: --pins-sc-biguint
     bool        m_pinsUint8;    // main switch: --pins-uint8
     bool        m_ppComments;   // main switch: --pp-comments
     bool        m_profCFuncs;   // main switch: --prof-cfuncs
     bool        m_profThreads;  // main switch: --prof-threads
+    bool        m_protectIds;   // main switch: --protect-ids
     bool        m_public;       // main switch: --public
+    bool        m_publicFlatRW;  // main switch: --public-flat-rw
     bool        m_relativeCFuncs; // main switch: --relative-cfuncs
     bool        m_relativeIncludes; // main switch: --relative-includes
     bool        m_reportUnoptflat; // main switch: --report-unoptflat
     bool        m_savable;      // main switch: --savable
     bool        m_systemC;      // main switch: --sc: System C instead of simple C++
-    bool        m_skipIdentical;// main switch: --skip-identical
     bool        m_stats;        // main switch: --stats
     bool        m_statsVars;    // main switch: --stats-vars
     bool        m_threadsCoarsen;  // main switch: --threads-coarsen
     bool        m_threadsDpiPure;  // main switch: --threads-dpi all/pure
     bool        m_threadsDpiUnpure;  // main switch: --threads-dpi all
     bool        m_trace;        // main switch: --trace
+    bool        m_traceCoverage;  // main switch: --trace-coverage
     bool        m_traceDups;    // main switch: --trace-dups
     bool        m_traceParams;  // main switch: --trace-params
     bool        m_traceStructs; // main switch: --trace-structs
@@ -160,11 +206,14 @@ class V3Options {
     int         m_gateStmts;    // main switch: --gate-stmts
     int         m_ifDepth;      // main switch: --if-depth
     int         m_inlineMult;   // main switch: --inline-mult
+    VOptionBool m_makeDepend;  // main switch: -MMD
+    int         m_maxNumWidth;  // main switch: --max-num-width
     int         m_moduleRecursion;// main switch: --module-recursion-depth
     int         m_outputSplit;  // main switch: --output-split
     int         m_outputSplitCFuncs;// main switch: --output-split-cfuncs
     int         m_outputSplitCTrace;// main switch: --output-split-ctrace
     int         m_pinsBv;       // main switch: --pins-bv
+    VOptionBool m_skipIdentical;  // main switch: --skip-identical
     int         m_threads;      // main switch: --threads (0 == --no-threads)
     int         m_threadsMaxMTasks;  // main switch: --threads-max-mtasks
     int         m_traceDepth;   // main switch: --trace-depth
@@ -186,10 +235,13 @@ class V3Options {
     string      m_modPrefix;    // main switch: --mod-prefix
     string      m_pipeFilter;   // main switch: --pipe-filter
     string      m_prefix;       // main switch: --prefix
+    string      m_protectKey;   // main switch: --protect-key
+    string      m_protectLib;   // main switch: --protect-lib {lib_name}
     string      m_topModule;    // main switch: --top-module
     string      m_unusedRegexp; // main switch: --unused-regexp
     string      m_xAssign;      // main switch: --x-assign
     string      m_xInitial;     // main switch: --x-initial
+    string      m_xmlOutput;    // main switch: --xml-output
 
     // Language is now held in FileLine, on a per-node basis. However we still
     // have a concept of the default language at a global level.
@@ -204,7 +256,6 @@ class V3Options {
     bool        m_oDedupe;      // main switch: -Od: logic deduplication
     bool        m_oAssemble;    // main switch: -Om: assign assemble
     bool        m_oExpand;      // main switch: -Ox: expansion of C macros
-    bool        m_oFlopGater;   // main switch: -Of: flop gater detection
     bool        m_oGate;        // main switch: -Og: gate wire elimination
     bool        m_oLife;        // main switch: -Ol: variable lifetime
     bool        m_oLifePost;    // main switch: -Ot: delayed assignment elimination
@@ -231,6 +282,7 @@ class V3Options {
     void showVersion(bool verbose);
     void coverage(bool flag) { m_coverageLine = m_coverageToggle = m_coverageUser = flag; }
     bool onoff(const char* sw, const char* arg, bool& flag);
+    bool onoffb(const char* sw, const char* arg, VOptionBool& flag);
     bool suffixed(const string& sw, const char* arg);
     string parseFileArg(const string& optdir, const string& relfilename);
     bool parseLangExt(const char* swp, const char* langswp, const V3LangCode& lc);
@@ -256,10 +308,10 @@ class V3Options {
     void addNoClocker(const string& signame);
     void addVFile(const string& filename);
     void addForceInc(const string& filename);
+    void notify();
 
     // ACCESSORS (options)
     bool preprocOnly() const { return m_preprocOnly; }
-    bool makeDepend() const { return m_makeDepend; }
     bool makePhony() const { return m_makePhony; }
     bool preprocNoLine() const { return m_preprocNoLine; }
     bool underlineZero() const { return m_underlineZero; }
@@ -268,7 +320,6 @@ class V3Options {
     bool systemC() const { return m_systemC; }
     bool usingSystemCLibs() const { return !lintOnly() && systemC(); }
     bool savable() const { return m_savable; }
-    bool skipIdentical() const { return m_skipIdentical; }
     bool stats() const { return m_stats; }
     bool statsVars() const { return m_statsVars; }
     bool assertOn() const { return m_assert; }  // assertOn as __FILE__ may be defined
@@ -276,6 +327,8 @@ class V3Options {
     bool bboxSys() const { return m_bboxSys; }
     bool bboxUnsup() const { return m_bboxUnsup; }
     bool cdc() const { return m_cdc; }
+    bool cmake() const { return m_cmake; }
+    bool context() const { return m_context; }
     bool coverage() const { return m_coverageLine || m_coverageToggle || m_coverageUser; }
     bool coverageLine() const { return m_coverageLine; }
     bool coverageToggle() const { return m_coverageToggle; }
@@ -286,14 +339,18 @@ class V3Options {
     bool debugLeak() const { return m_debugLeak; }
     bool debugNondeterminism() const { return m_debugNondeterminism; }
     bool debugPartition() const { return m_debugPartition; }
+    bool debugProtect() const { return m_debugProtect; }
     bool debugSelfTest() const { return m_debugSelfTest; }
     bool decoration() const { return m_decoration; }
+    bool dpiHdrOnly() const { return m_dpiHdrOnly; }
     bool dumpDefines() const { return m_dumpDefines; }
     bool exe() const { return m_exe; }
+    bool gmake() const { return m_gmake; }
     bool threadsDpiPure() const { return m_threadsDpiPure; }
     bool threadsDpiUnpure() const { return m_threadsDpiUnpure; }
     bool threadsCoarsen() const { return m_threadsCoarsen; }
     bool trace() const { return m_trace; }
+    bool traceCoverage() const { return m_traceCoverage; }
     bool traceDups() const { return m_traceDups; }
     bool traceParams() const { return m_traceParams; }
     bool traceStructs() const { return m_traceStructs; }
@@ -301,13 +358,16 @@ class V3Options {
     bool orderClockDly() const { return m_orderClockDly; }
     bool outFormatOk() const { return m_outFormatOk; }
     bool keepTempFiles() const { return (V3Error::debugDefault()!=0); }
+    bool pedantic() const { return m_pedantic; }
     bool pinsScUint() const { return m_pinsScUint; }
     bool pinsScBigUint() const { return m_pinsScBigUint; }
     bool pinsUint8() const { return m_pinsUint8; }
     bool ppComments() const { return m_ppComments; }
     bool profCFuncs() const { return m_profCFuncs; }
     bool profThreads() const { return m_profThreads; }
+    bool protectIds() const { return m_protectIds; }
     bool allPublic() const { return m_public; }
+    bool publicFlatRW() const { return m_publicFlatRW; }
     bool lintOnly() const { return m_lintOnly; }
     bool ignc() const { return m_ignc; }
     bool inhibitSim() const { return m_inhibitSim; }
@@ -322,11 +382,14 @@ class V3Options {
     int gateStmts() const { return m_gateStmts; }
     int ifDepth() const { return m_ifDepth; }
     int inlineMult() const { return m_inlineMult; }
+    VOptionBool makeDepend() const { return m_makeDepend; }
+    int maxNumWidth() const { return m_maxNumWidth; }
     int moduleRecursionDepth() const { return m_moduleRecursion; }
     int outputSplit() const { return m_outputSplit; }
     int outputSplitCFuncs() const { return m_outputSplitCFuncs; }
     int outputSplitCTrace() const { return m_outputSplitCTrace; }
     int pinsBv() const { return m_pinsBv; }
+    VOptionBool skipIdentical() const { return m_skipIdentical; }
     int threads() const { return m_threads; }
     int threadsMaxMTasks() const { return m_threadsMaxMTasks; }
     bool mtasks() const { return (m_threads > 1); }
@@ -347,10 +410,23 @@ class V3Options {
     string modPrefix() const { return m_modPrefix; }
     string pipeFilter() const { return m_pipeFilter; }
     string prefix() const { return m_prefix; }
+    string protectKey() const { return m_protectKey; }
+    string protectKeyDefaulted();  // Set default key if not set by user
+    string protectLib() const { return m_protectLib; }
+    string protectLibName(bool shared) {
+        string libName = "lib"+protectLib();
+        if (shared) {
+            libName += ".so";
+        } else {
+            libName += ".a";
+        }
+        return libName;
+    }
     string topModule() const { return m_topModule; }
     string unusedRegexp() const { return m_unusedRegexp; }
     string xAssign() const { return m_xAssign; }
     string xInitial() const { return m_xInitial; }
+    string xmlOutput() const { return m_xmlOutput; }
 
     const V3StringSet& cppFiles() const { return m_cppFiles; }
     const V3StringList& cFlags() const { return m_cFlags; }
@@ -377,7 +453,6 @@ class V3Options {
     bool oDedupe() const { return m_oDedupe; }
     bool oAssemble() const { return m_oAssemble; }
     bool oExpand() const { return m_oExpand; }
-    bool oFlopGater() const { return m_oFlopGater; }
     bool oGate() const { return m_oGate; }
     bool oDup() const { return oLife(); }
     bool oLife() const { return m_oLife; }
