@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Block code ordering
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -75,7 +75,7 @@
 //      and make a new block.  Add that new activation block to the list of calls to make.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -117,16 +117,16 @@ static bool domainsExclusive(const AstSenTree* fromp, const AstSenTree* top);
 void OrderGraph::loopsVertexCb(V3GraphVertex* vertexp) {
     if (debug()) cout<<"-Info-Loop: "<<vertexp<<" "<<endl;
     if (OrderLogicVertex* vvertexp = dynamic_cast<OrderLogicVertex*>(vertexp)) {
-        std::cerr<<vvertexp->nodep()->fileline()->warnMore()
+        std::cerr<<vvertexp->nodep()->fileline()->warnOther()
                  <<"     Example path: "
                  <<vvertexp->nodep()->typeName()<<endl;
     }
     if (OrderVarVertex* vvertexp = dynamic_cast<OrderVarVertex*>(vertexp)) {
-        std::cerr<<vvertexp->varScp()->fileline()->warnMore()
+        std::cerr<<vvertexp->varScp()->fileline()->warnOther()
                  <<"     Example path: "
                  <<vvertexp->varScp()->prettyName()<<endl;
     }
-};
+}
 
 //######################################################################
 
@@ -202,7 +202,7 @@ public:
     // METHODS
     OrderVarVertex* newVarUserVertex(V3Graph* graphp, AstScope* scopep,
                                      AstVarScope* varscp, WhichVertex type, bool* createdp=NULL) {
-        if (type>=WV_MAX) varscp->v3fatalSrc("Bad case");
+        UASSERT_OBJ(type < WV_MAX, varscp, "Bad case");
         OrderVarVertex* vertexp = m_vertexp[type];
         if (!vertexp) {
             UINFO(6,"New vertex "<<varscp<<endl);
@@ -274,15 +274,15 @@ private:
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         m_hasClk = false;
         if (AstVarRef* varrefp = VN_CAST(nodep->rhsp(), VarRef)) {
             this->visit(varrefp);
             m_rightClkWidth = varrefp->width();
-            if (varrefp->varp()->attrClocker() == AstVarAttrClocker::CLOCKER_YES) {
+            if (varrefp->varp()->attrClocker() == VVarAttrClocker::CLOCKER_YES) {
                 if (m_inClocked) {
                     varrefp->v3warn(CLKDATA, "Clock used as data (on rhs of assignment) in sequential block "
-                                    <<varrefp->prettyName()<<endl);
+                                    <<varrefp->prettyNameQ()<<endl);
                 } else {
                     m_hasClk = true;
                     UINFO(5, "node is already marked as clocker "<<varrefp<<endl);
@@ -307,20 +307,20 @@ private:
             }
 
             const AstVarRef* lhsp = VN_CAST(nodep->lhsp(), VarRef);
-            if (lhsp && (lhsp->varp()->attrClocker() == AstVarAttrClocker::CLOCKER_UNKNOWN)) {
-                lhsp->varp()->attrClocker(AstVarAttrClocker::CLOCKER_YES);  // mark as clocker
+            if (lhsp && (lhsp->varp()->attrClocker() == VVarAttrClocker::CLOCKER_UNKNOWN)) {
+                lhsp->varp()->attrClocker(VVarAttrClocker::CLOCKER_YES);  // mark as clocker
                 m_newClkMarked = true;  // enable a further run since new clocker is marked
                 UINFO(5, "node is newly marked as clocker by assignment "<<lhsp<<endl);
             }
         }
     }
 
-    virtual void visit(AstVarRef* nodep) {
-        if (m_inAss && nodep->varp()->attrClocker() == AstVarAttrClocker::CLOCKER_YES) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
+        if (m_inAss && nodep->varp()->attrClocker() == VVarAttrClocker::CLOCKER_YES) {
             if (m_inClocked) {
                 nodep->v3warn(CLKDATA,
                               "Clock used as data (on rhs of assignment) in sequential block "
-                              <<nodep->prettyName());
+                              <<nodep->prettyNameQ());
             } else {
                 m_hasClk = true;
                 m_childClkWidth = nodep->width();  // Pass up
@@ -328,7 +328,7 @@ private:
             }
         }
     }
-    virtual void visit(AstConcat* nodep) {
+    virtual void visit(AstConcat* nodep) VL_OVERRIDE {
         if (m_inAss) {
             iterateAndNextNull(nodep->lhsp());
             int lw = m_childClkWidth;
@@ -337,20 +337,20 @@ private:
             m_childClkWidth = lw + rw;  // Pass up
         }
     }
-    virtual void visit(AstNodeSel* nodep) {
+    virtual void visit(AstNodeSel* nodep) VL_OVERRIDE {
         if (m_inAss) {
             iterateChildren(nodep);
             // Pass up result width
             if (m_childClkWidth > nodep->width()) m_childClkWidth = nodep->width();
         }
     }
-    virtual void visit(AstSel* nodep) {
+    virtual void visit(AstSel* nodep) VL_OVERRIDE {
         if (m_inAss) {
             iterateChildren(nodep);
             if (m_childClkWidth > nodep->width()) m_childClkWidth = nodep->width();
         }
     }
-    virtual void visit(AstReplicate* nodep) {
+    virtual void visit(AstReplicate* nodep) VL_OVERRIDE {
         if (m_inAss) {
             iterateChildren(nodep);
             if (VN_IS(nodep->rhsp(), Const)) {
@@ -360,17 +360,17 @@ private:
             }
         }
     }
-    virtual void visit(AstActive* nodep) {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {
         m_inClocked = nodep->hasClocked();
         iterateChildren(nodep);
         m_inClocked = false;
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit OrderClkMarkVisitor(AstNode* nodep) {
         m_hasClk    = false;
         m_inClocked = false;
@@ -393,26 +393,26 @@ private:
     bool m_clkAss;  // There is signals marked as clocker in the assignment
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         if (const AstVarRef* varrefp = VN_CAST(nodep->lhsp(), VarRef)) {
-            if (varrefp->varp()->attrClocker() == AstVarAttrClocker::CLOCKER_YES) {
+            if (varrefp->varp()->attrClocker() == VVarAttrClocker::CLOCKER_YES) {
                 m_clkAss = true;
                 UINFO(6, "node was marked as clocker "<<varrefp<<endl);
             }
         }
         iterateChildren(nodep->rhsp());
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         // Previous versions checked attrClocker() here, but this breaks
         // the updated t_clocker VCD test.
         // If reenable this visitor note AstNodeMath short circuit below
     }
-    virtual void visit(AstNodeMath* nodep) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNodeMath* nodep) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit OrderClkAssVisitor(AstNode* nodep) {
         m_clkAss = false;
         iterate(nodep);
@@ -722,7 +722,7 @@ protected:
 
 private:
     // STATS
-    V3Double0           m_statCut[OrderVEdgeType::_ENUM_END];   // Count of each edge type cut
+    VDouble0 m_statCut[OrderVEdgeType::_ENUM_END];  // Count of each edge type cut
 
     // TYPES
     enum VarUsage { VU_NONE=0, VU_CON=1, VU_GEN=2 };
@@ -735,7 +735,7 @@ private:
             UINFO(4,"   STMT "<<nodep<<endl);
             //VV*****  We reset user4p()
             AstNode::user4ClearTree();
-            if (!m_activep || !m_activep->sensesp()) nodep->v3fatalSrc("NULL");
+            UASSERT_OBJ(m_activep && m_activep->sensesp(), nodep, "NULL");
             // If inside combo logic, ignore the domain, we'll assign one based on interconnect
             AstSenTree* startDomainp = m_activep->sensesp();
             if (startDomainp->hasCombo()) startDomainp=NULL;
@@ -833,10 +833,10 @@ private:
             //
             if (vertexp->isClock()) {
                 // Seems obvious; no warning yet
-                //nodep->v3warn(GENCLK,"Signal unoptimizable: Generated clock: "<<nodep->prettyName());
+                //nodep->v3warn(GENCLK, "Signal unoptimizable: Generated clock: "<<nodep->prettyNameQ());
             } else if (nodep->varp()->isSigPublic()) {
                 nodep->v3warn(UNOPT, "Signal unoptimizable: Feedback to public clock or circular logic: "
-                              <<nodep->prettyName());
+                              <<nodep->prettyNameQ());
                 if (!nodep->fileline()->warnIsOff(V3ErrorCode::UNOPT)) {
                     nodep->fileline()->modifyWarnOff(V3ErrorCode::UNOPT, true);  // Complain just once
                     // Give the user an example.
@@ -850,7 +850,7 @@ private:
                 // it was needed, that aren't any more
                 // First v3warn not inside warnIsOff so we can see the suppressions with --debug
                 nodep->v3warn(UNOPTFLAT, "Signal unoptimizable: Feedback to clock or circular logic: "
-                              <<nodep->prettyName());
+                              <<nodep->prettyNameQ());
                 if (!nodep->fileline()->warnIsOff(V3ErrorCode::UNOPTFLAT)) {
                     nodep->fileline()->modifyWarnOff(V3ErrorCode::UNOPTFLAT, true);  // Complain just once
                     // Give the user an example.
@@ -953,7 +953,7 @@ private:
         }
     }
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         {
             AstUser4InUse       m_inuser4;      // Used only when building tree, so below
             iterateChildren(nodep);
@@ -961,9 +961,9 @@ private:
         // We're finished, complete the topscopes
         if (m_topScopep) { process(); m_topScopep=NULL; }
     }
-    virtual void visit(AstTopScope* nodep) {
+    virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
         // Process the last thing we're finishing
-        if (m_topScopep) nodep->v3fatalSrc("Only one topscope should ever be created");
+        UASSERT_OBJ(!m_topScopep, nodep, "Only one topscope should ever be created");
         UINFO(2,"  Loading tree...\n");
         //VV*****  We reset userp()
         AstNode::user1ClearTree();
@@ -1000,12 +1000,15 @@ private:
         AstNode::user3ClearTree();
         AstNode::user4ClearTree();
     }
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
-    virtual void visit(AstScope* nodep) {
+    virtual void visit(AstScope* nodep) VL_OVERRIDE {
         UINFO(4," SCOPE "<<nodep<<endl);
         m_scopep = nodep;
         m_logicVxp = NULL;
@@ -1015,14 +1018,15 @@ private:
         iterateChildren(nodep);
         m_scopep = NULL;
     }
-    virtual void visit(AstActive* nodep) {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {
         // Create required activation blocks and add to module
         UINFO(4,"  ACTIVE  "<<nodep<<endl);
         m_activep = nodep;
         m_activeSenVxp = NULL;
         m_inClocked = nodep->hasClocked();
         // Grab the sensitivity list
-        if (nodep->sensesStorep()) nodep->v3fatalSrc("Senses should have been activeTop'ed to be global!");
+        UASSERT_OBJ(!nodep->sensesStorep(), nodep,
+                    "Senses should have been activeTop'ed to be global!");
         iterate(nodep->sensesp());
         // Collect statements under it
         iterateChildren(nodep);
@@ -1030,25 +1034,26 @@ private:
         m_activeSenVxp = NULL;
         m_inClocked = false;
     }
-    virtual void visit(AstVarScope* nodep) {
+    virtual void visit(AstVarScope* nodep) VL_OVERRIDE {
         // Create links to all input signals
+        UASSERT_OBJ(m_modp, nodep, "Scope not under module");
         if (m_modp->isTop() && nodep->varp()->isNonOutput()) {
             OrderVarVertex* varVxp = newVarUserVertex(nodep, WV_STD);
             new OrderEdge(&m_graph, m_inputsVxp, varVxp, WEIGHT_INPUT);
         }
     }
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         if (m_scopep) {
             AstVarScope* varscp = nodep->varScopep();
-            if (!varscp) nodep->v3fatalSrc("Var didn't get varscoped in V3Scope.cpp");
+            UASSERT_OBJ(varscp, nodep, "Var didn't get varscoped in V3Scope.cpp");
             if (m_inSenTree) {
                 // Add CLOCK dependency... This is a root of the tree we'll trace
-                if (nodep->lvalue()) nodep->v3fatalSrc("How can a sensitivity be setting a var?");
+                UASSERT_OBJ(!nodep->lvalue(), nodep, "How can a sensitivity be setting a var?");
                 OrderVarVertex* varVxp = newVarUserVertex(varscp, WV_STD);
                 varVxp->isClock(true);
                 new OrderEdge(&m_graph, varVxp, m_activeSenVxp, WEIGHT_MEDIUM);
             } else {
-                if (!m_logicVxp) nodep->v3fatalSrc("Var ref not under a logic block");
+                UASSERT_OBJ(m_logicVxp, nodep, "Var ref not under a logic block");
                 // What new directions is this used
                 // We don't want to add extra edges if the logic block has many usages of same var
                 bool gen = false;
@@ -1070,11 +1075,11 @@ private:
                         con = false;
                     }
                     if (varscp->varp()->attrClockEn() && !m_inPre && !m_inPost && !m_inClocked) {
-                        // clock_enable attribute: user's worring about it for us
+                        // clock_enable attribute: user's worrying about it for us
                         con = false;
                     }
                     if (m_inClkAss && (varscp->varp()->attrClocker()
-                                       != AstVarAttrClocker::CLOCKER_YES)) {
+                                       != VVarAttrClocker::CLOCKER_YES)) {
                         con = false;
                         UINFO(4, "nodep used as clock_enable "<<varscp
                               <<" in "<<m_logicVxp->nodep()<<endl);
@@ -1104,7 +1109,7 @@ private:
                                 // If the lhs is a clocker, avoid marking that as circular by
                                 // putting a hard edge instead of normal cuttable
                                 if (varscp->varp()->attrClocker()
-                                    == AstVarAttrClocker::CLOCKER_YES) {
+                                    == VVarAttrClocker::CLOCKER_YES) {
                                     new OrderEdge(&m_graph, m_logicVxp, varVxp, WEIGHT_NORMAL);
                                 } else {
                                     new OrderComboCutEdge(&m_graph, m_logicVxp, varVxp);
@@ -1166,7 +1171,7 @@ private:
             }
         }
     }
-    virtual void visit(AstSenTree* nodep) {
+    virtual void visit(AstSenTree* nodep) VL_OVERRIDE {
         // Having a node derived from the sentree isn't required for
         // correctness, it merely makes the graph better connected
         // and improves graph algorithmic performance
@@ -1181,27 +1186,27 @@ private:
             m_inSenTree = false;
         }
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep);
     }
-    virtual void visit(AstAlwaysPost* nodep) {
+    virtual void visit(AstAlwaysPost* nodep) VL_OVERRIDE {
         m_inPost = true;
         iterateNewStmt(nodep);
         m_inPost = false;
     }
-    virtual void visit(AstAlwaysPublic* nodep) {
+    virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep);
     }
-    virtual void visit(AstAssignAlias* nodep) {
+    virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep);
     }
-    virtual void visit(AstAssignW* nodep) {
+    virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         OrderClkAssVisitor visitor(nodep);
         m_inClkAss = visitor.isClkAss();
         iterateNewStmt(nodep);
         m_inClkAss = false;
     }
-    virtual void visit(AstAssignPre* nodep) {
+    virtual void visit(AstAssignPre* nodep) VL_OVERRIDE {
         OrderClkAssVisitor visitor(nodep);
         m_inClkAss = visitor.isClkAss();
         m_inPre = true;
@@ -1209,7 +1214,7 @@ private:
         m_inPre = false;
         m_inClkAss = false;
     }
-    virtual void visit(AstAssignPost* nodep) {
+    virtual void visit(AstAssignPost* nodep) VL_OVERRIDE {
         OrderClkAssVisitor visitor(nodep);
         m_inClkAss = visitor.isClkAss();
         m_inPost = true;
@@ -1217,15 +1222,15 @@ private:
         m_inPost = false;
         m_inClkAss = false;
     }
-    virtual void visit(AstCoverToggle* nodep) {
+    virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep);
     }
-    virtual void visit(AstInitial* nodep) {
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         // We use initials to setup parameters and static consts's which may be referenced
         // in user initial blocks.  So use ordering to sort them all out.
         iterateNewStmt(nodep);
     }
-    virtual void visit(AstCFunc*) {
+    virtual void visit(AstCFunc*) VL_OVERRIDE {
         // Ignore for now
         // We should detect what variables are set in the function, and make
         // settlement code for them, then set a global flag, so we call "settle"
@@ -1233,11 +1238,11 @@ private:
     }
     //--------------------
     // Default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     OrderVisitor() {
         m_topScopep = NULL;
         m_scopetopp = NULL;
@@ -1307,8 +1312,8 @@ static bool domainsExclusive(const AstSenTree* fromp, const AstSenTree* top) {
     const AstSenItem* toSenListp = VN_CAST(top->sensesp(), SenItem);
     // If clk gating is ever reenabled, we may need to update this to handle
     // AstSenGate also.
-    if (!fromSenListp) fromp->v3fatalSrc("sensitivity list item is not an AstSenItem");
-    if (!toSenListp) top->v3fatalSrc("sensitivity list item is not an AstSenItem");
+    UASSERT_OBJ(fromSenListp, fromp, "sensitivity list item is not an AstSenItem");
+    UASSERT_OBJ(toSenListp, top, "sensitivity list item is not an AstSenItem");
 
     if (fromSenListp->nextp()) return false;
     if (toSenListp->nextp()) return false;
@@ -1337,9 +1342,8 @@ inline void OrderMoveDomScope::ready(OrderVisitor* ovp) {
 
 // Mark one vertex as finished, remove from ready list if done
 inline void OrderMoveDomScope::movedVertex(OrderVisitor* ovp, OrderMoveVertex* vertexp) {
-    if (!m_onReadyList) {
-        vertexp->v3fatalSrc("Moving vertex from ready when nothing was on que as ready.");
-    }
+    UASSERT_OBJ(m_onReadyList, vertexp,
+                "Moving vertex from ready when nothing was on que as ready.");
     if (m_readyVertices.empty()) {  // Else more work to get to later
         m_onReadyList = false;
         m_readyDomScopeE.unlink(ovp->m_pomReadyDomScope, this);
@@ -1406,13 +1410,12 @@ void OrderVisitor::processInputsOutIterate(OrderEitherVertex* vertexp, VertexVec
     // First make sure input path is fully recursed
     processInputsInIterate(vertexp, todoVec);
     // Propagate PrimaryIn through simple assignments
-    if (!vertexp->isFromInput()) {
-        vertexp->v3fatalSrc("processInputsOutIterate only for input marked vertexes");
-    }
+    UASSERT_OBJ(vertexp->isFromInput(), vertexp,
+                "processInputsOutIterate only for input marked vertexes");
     vertexp->user(3);  // out-edges processed
 
     {
-        // Propagate PrimaryIn through simple assignments, followint target of vertex
+        // Propagate PrimaryIn through simple assignments, following target of vertex
         for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
             OrderEitherVertex* toVertexp = static_cast<OrderEitherVertex*>(edgep->top());
             if (OrderVarStdVertex* vvertexp = dynamic_cast<OrderVarStdVertex*>(toVertexp)) {
@@ -1460,7 +1463,7 @@ void OrderVisitor::processCircular() {
             for (V3GraphEdge* edgep = vvertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
                 if (edgep->weight()==0) {  // was cut
                     OrderEdge* oedgep = dynamic_cast<OrderEdge*>(edgep);
-                    if (!oedgep) vvertexp->varScp()->v3fatalSrc("Cuttable edge not of proper type");
+                    UASSERT_OBJ(oedgep, vvertexp->varScp(), "Cutable edge not of proper type");
                     UINFO(6,"      CutCircularO: "<<vvertexp->name()<<endl);
                     nodeMarkCircular(vvertexp, oedgep);
                 }
@@ -1468,7 +1471,7 @@ void OrderVisitor::processCircular() {
             for (V3GraphEdge* edgep = vvertexp->inBeginp(); edgep; edgep = edgep->inNextp()) {
                 if (edgep->weight()==0) {  // was cut
                     OrderEdge* oedgep = dynamic_cast<OrderEdge*>(edgep);
-                    if (!oedgep) vvertexp->varScp()->v3fatalSrc("Cuttable edge not of proper type");
+                    UASSERT_OBJ(oedgep, vvertexp->varScp(), "Cutable edge not of proper type");
                     UINFO(6,"      CutCircularI: "<<vvertexp->name()<<endl);
                     nodeMarkCircular(vvertexp, oedgep);
                 }
@@ -1563,7 +1566,8 @@ void OrderVisitor::processDomainsIterate(OrderEitherVertex* vertexp) {
                     }
                     AstSenTree* newtreep = domainp->cloneTree(false);
                     AstNodeSenItem* newtree2p = fromVertexp->domainp()->sensesp()->cloneTree(true);
-                    if (!newtree2p) fromVertexp->domainp()->v3fatalSrc("No senitem found under clocked domain");
+                    UASSERT_OBJ(newtree2p, fromVertexp->domainp(),
+                                "No senitem found under clocked domain");
                     newtreep->addSensesp(newtree2p);
                     newtree2p = NULL;  // Below edit may replace it
                     V3Const::constifyExpensiveEdit(newtreep);  // Remove duplicates
@@ -1576,7 +1580,7 @@ void OrderVisitor::processDomainsIterate(OrderEitherVertex* vertexp) {
                         domainp->dumpTree(cout);
                         cout<<endl;
                     }
-                    newtreep->deleteTree(); VL_DANGLING(newtreep);
+                    VL_DO_DANGLING(newtreep->deleteTree(), newtreep);
                 }
             }
         }  // next input edgep
@@ -1747,7 +1751,7 @@ void OrderVisitor::processMoveDoneOne(OrderMoveVertex* vertexp) {
         UINFO(9,"          Clear to "<<(toVertexp->inEmpty()?"[EMP] ":"      ")
               <<toVertexp<<endl);
         // Delete this edge
-        edgep->unlinkDelete(); VL_DANGLING(edgep);
+        VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
         if (toVertexp->inEmpty()) {
             // If destination node now has all inputs resolved; recurse to move that vertex
             // This is thus depth first (before width) which keeps the
@@ -1759,9 +1763,7 @@ void OrderVisitor::processMoveDoneOne(OrderMoveVertex* vertexp) {
 
 void OrderVisitor::processMoveOne(OrderMoveVertex* vertexp,
                                   OrderMoveDomScope* domScopep, int level) {
-    if (vertexp->domScopep() != domScopep) {
-        vertexp->v3fatalSrc("Domain mismatch; list misbuilt?");
-    }
+    UASSERT_OBJ(vertexp->domScopep() == domScopep, vertexp, "Domain mismatch; list misbuilt?");
     const OrderLogicVertex* lvertexp = vertexp->logicp();
     const AstScope* scopep = lvertexp->scopep();
     UINFO(5,"    POSmove l"<<std::setw(3)<<level<<" d="<<cvtToHex(lvertexp->domainp())
@@ -1781,10 +1783,7 @@ AstActive* OrderVisitor::processMoveOneLogic(const OrderLogicVertex* lvertexp,
     AstNode* nodep = lvertexp->nodep();
     AstNodeModule* modp = VN_CAST(scopep->user1p(), NodeModule);  // Stashed by visitor func
     UASSERT(modp, "NULL");
-    if (VN_IS(nodep, UntilStable)) {
-        nodep->v3fatalSrc("Not implemented");
-    }
-    else if (VN_IS(nodep, SenTree)) {
+    if (VN_IS(nodep, SenTree)) {
         // Just ignore sensitivities, we'll deal with them when we move statements that need them
     }
     else {  // Normal logic
@@ -1816,7 +1815,7 @@ AstActive* OrderVisitor::processMoveOneLogic(const OrderLogicVertex* lvertexp,
         nodep->unlinkFrBack();
         if (domainp == m_deleteDomainp) {
             UINFO(4," Ordering deleting pre-settled "<<nodep<<endl);
-            pushDeletep(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);
         } else {
             newFuncpr->addStmtsp(nodep);
             if (v3Global.opt.outputSplitCFuncs()) {
