@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Os-specific function wrapper
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,13 +17,14 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3OS_H_
 #define _V3OS_H_ 1
 
 #include "config_build.h"
 #include "verilatedos.h"
 
+// Limited V3 headers here - this is a base class for Vlc etc
 #include "V3Error.h"
 
 //============================================================================
@@ -55,8 +56,10 @@ public:
 
     // METHODS (random)
     static vluint64_t rand64(vluint64_t* statep);
+    static string trueRandom(size_t size);
 
-    // METHODS (performance)
+    // METHODS (time & performance)
+    static void u_sleep(int64_t usec);  ///< Sleep for a given number of microseconds.
     static uint64_t timeUsecs();  ///< Return wall time since epoch in microseconds, or 0 if not implemented
     static uint64_t memUsageBytes();  ///< Return memory usage in bytes, or 0 if not implemented
 };
