@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Replicate modules for parameterization
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -47,7 +47,7 @@
 //   and must be relinked.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -77,6 +77,7 @@ private:
     //   AstVar::user4()        // int    Global parameter number (for naming new module)
     //                          //        (0=not processed, 1=iterated, but no number,
     //                          //         65+ parameter numbered)
+    //   AstCell::user5p()      // string* Generate portion of hierarchical name
     AstUser4InUse       m_inuser4;
     AstUser5InUse       m_inuser5;
     // User1/2/3 used by constant function simulations
@@ -115,6 +116,8 @@ private:
 
     UnrollStateful m_unroller;  // Loop unroller
 
+    string m_generateHierName;  // Generate portion of hierarchical name
+
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
@@ -204,16 +207,14 @@ private:
                 // Find it in the clone structure
                 //UINFO(8,"Clone find 0x"<<hex<<(uint32_t)pinp->modVarp()<<endl);
                 CloneMap::iterator cloneiter = clonemapp->find(pinp->modVarp());
-                if (cloneiter == clonemapp->end()) {
-                    pinp->v3fatalSrc("Couldn't find pin in clone list");
-                }
+                UASSERT_OBJ(cloneiter != clonemapp->end(), pinp,
+                            "Couldn't find pin in clone list");
                 pinp->modVarp(VN_CAST(cloneiter->second, Var));
             }
             else if (pinp->modPTypep()) {
                 CloneMap::iterator cloneiter = clonemapp->find(pinp->modPTypep());
-                if (cloneiter == clonemapp->end()) {
-                    pinp->v3fatalSrc("Couldn't find pin in clone list");
-                }
+                UASSERT_OBJ(cloneiter != clonemapp->end(), pinp,
+                            "Couldn't find pin in clone list");
                 pinp->modPTypep(VN_CAST(cloneiter->second, ParamTypeDType));
             }
             else {
@@ -221,18 +222,19 @@ private:
             }
         }
     }
-    void visitCell(AstCell* nodep);
+    void visitCell(AstCell* nodep, const string& hierName);
     void visitModules() {
         // Loop on all modules left to process
         // Hitting a cell adds to the appropriate level of this level-sorted list,
         // so since cells originally exist top->bottom we process in top->bottom order too.
         while (!m_todoModps.empty()) {
-            LevelModMap::iterator it = m_todoModps.begin();
-            AstNodeModule* nodep = it->second;
-            m_todoModps.erase(it);
+            LevelModMap::iterator itm = m_todoModps.begin();
+            AstNodeModule* nodep = itm->second;
+            m_todoModps.erase(itm);
             if (!nodep->user5SetOnce()) {  // Process once; note clone() must clear so we do it again
                 m_modp = nodep;
                 UINFO(4," MOD   "<<nodep<<endl);
+                if (m_modp->hierName().empty()) m_modp->hierName(m_modp->origName());
                 iterateChildren(nodep);
                 // Note above iterate may add to m_todoModps
                 //
@@ -242,10 +244,21 @@ private:
                         AstCell* nodep = *it;
                         if ((nonIf==0 && VN_IS(nodep->modp(), Iface))
                             || (nonIf==1 && !VN_IS(nodep->modp(), Iface))) {
-                            visitCell(nodep);
+                            string fullName (m_modp->hierName());
+                            if (string* genHierNamep = (string *) nodep->user5p()) {
+                                fullName += *genHierNamep;
+                            }
+                            visitCell(nodep, fullName);
                         }
                     }
                 }
+                for (CellList::iterator it=m_cellps.begin(); it!=m_cellps.end(); ++it) {
+                    AstCell* cellp = *it;
+                    if (string* genHierNamep = (string *) cellp->user5p()) {
+                        cellp->user5p(NULL);
+                        VL_DO_DANGLING(delete genHierNamep, genHierNamep);
+                    }
+                }
                 m_cellps.clear();
                 m_modp = NULL;
             }
@@ -253,11 +266,11 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         // Modules must be done in top-down-order
         iterateChildren(nodep);
     }
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         if (nodep->dead()) {
             UINFO(4," MOD-dead.  "<<nodep<<endl);  // Marked by LinkDot
         } else if (nodep->recursiveClone()) {
@@ -267,6 +280,7 @@ private:
                    || VN_IS(nodep, Package)) {  // Likewise haven't done wrapTopPackages yet
             // Add request to END of modules left to process
             m_todoModps.insert(make_pair(nodep->level(), nodep));
+            m_generateHierName = "";
             visitModules();
         } else if (nodep->user5()) {
             UINFO(4," MOD-done   "<<nodep<<endl);  // Already did it
@@ -274,20 +288,22 @@ private:
             UINFO(4," MOD-dead?  "<<nodep<<endl);  // Should have been done by now, if not dead
         }
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         // Must do ifaces first, so push to list and do in proper order
+        string* genHierNamep = new string(m_generateHierName);
+        nodep->user5p(genHierNamep);
         m_cellps.push_back(nodep);
     }
 
     // Make sure all parameters are constantified
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         if (!nodep->user5SetOnce()) {  // Process once
             iterateChildren(nodep);
             if (nodep->isParam()) {
                 if (!nodep->valuep()) {
                     nodep->v3error("Parameter without initial value is never given value"
                                    <<" (IEEE 1800-2017 6.20.1): "
-                                   <<nodep->prettyName());
+                                   <<nodep->prettyNameQ());
                 } else {
                     V3Const::constifyParamsEdit(nodep);  // The variable, not just the var->init()
                     if (!VN_IS(nodep->valuep(), Const)) {  // Complex init, like an array
@@ -306,7 +322,7 @@ private:
         }
     }
     // Make sure varrefs cause vars to constify before things above
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->varp()) iterate(nodep->varp());
     }
     bool ifaceParamReplace(AstVarXRef* nodep, AstNode* candp) {
@@ -318,15 +334,15 @@ private:
                     return true;
                 } else if (AstPin* pinp = VN_CAST(candp, Pin)) {
                     UINFO(9,"Found interface parameter: "<<pinp<<endl);
-                    if (!pinp->exprp()) pinp->v3fatalSrc("Interface parameter pin missing expression");
-                    nodep->replaceWith(pinp->exprp()->cloneTree(false)); VL_DANGLING(nodep);
+                    UASSERT_OBJ(pinp->exprp(), pinp, "Interface parameter pin missing expression");
+                    VL_DO_DANGLING(nodep->replaceWith(pinp->exprp()->cloneTree(false)), nodep);
                     return true;
                 }
             }
         }
         return false;
     }
-    virtual void visit(AstVarXRef* nodep) {
+    virtual void visit(AstVarXRef* nodep) VL_OVERRIDE {
         // Check to see if the scope is just an interface because interfaces are special
         string dotted = nodep->dotted();
         if (!dotted.empty() && nodep->varp() && nodep->varp()->isParam()) {
@@ -339,9 +355,16 @@ private:
                 if (VN_IS(backp, Var)
                     && VN_CAST(backp, Var)->isIfaceRef()
                     && VN_CAST(backp, Var)->childDTypep()
-                    && VN_CAST(VN_CAST(backp, Var)->childDTypep(), IfaceRefDType)) {
+                    && (VN_CAST(VN_CAST(backp, Var)->childDTypep(), IfaceRefDType)
+                        || (VN_CAST(VN_CAST(backp, Var)->childDTypep(), UnpackArrayDType)
+                            && VN_CAST(VN_CAST(backp, Var)->childDTypep()->getChildDTypep(),
+                                       IfaceRefDType)))) {
                     AstIfaceRefDType* ifacerefp
                         = VN_CAST(VN_CAST(backp, Var)->childDTypep(), IfaceRefDType);
+                    if (!ifacerefp) {
+                        ifacerefp = VN_CAST(VN_CAST(backp, Var)->childDTypep()->getChildDTypep(),
+                                            IfaceRefDType);
+                    }
                     // Interfaces passed in on the port map have ifaces
                     if (AstIface* ifacep = ifacerefp->ifacep()) {
                         if (dotted == backp->name()) {
@@ -366,7 +389,7 @@ private:
         nodep->varp(NULL);  // Needs relink, as may remove pointed-to var
     }
 
-    virtual void visit(AstUnlinkedRef* nodep) {
+    virtual void visit(AstUnlinkedRef* nodep) VL_OVERRIDE {
         AstVarXRef* varxrefp = VN_CAST(nodep->op1p(), VarXRef);
         AstNodeFTaskRef* taskrefp = VN_CAST(nodep->op1p(), NodeFTaskRef);
         if (varxrefp) {
@@ -385,9 +408,9 @@ private:
             taskrefp->dotted(m_unlinkedTxt);
         }
         nodep->replaceWith(nodep->op1p()->unlinkFrBack());
-        pushDeletep(nodep); VL_DANGLING(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
-    virtual void visit(AstCellArrayRef* nodep) {
+    virtual void visit(AstCellArrayRef* nodep) VL_OVERRIDE {
         V3Const::constifyParamsEdit(nodep->selp());
         if (const AstConst* constp = VN_CAST(nodep->selp(), Const)) {
             string index = AstNode::encodeNumber(constp->toSInt());
@@ -402,13 +425,13 @@ private:
                                   nodep->name()+"__BRA__"+index+"__KET__");
         } else {
             nodep->v3error("Could not expand constant selection inside dotted reference: "
-                           <<nodep->selp()->prettyName());
+                           <<nodep->selp()->prettyNameQ());
             return;
         }
     }
 
     // Generate Statements
-    virtual void visit(AstGenerate* nodep) {
+    virtual void visit(AstGenerate* nodep) VL_OVERRIDE {
         if (debug()>=9) nodep->dumpTree(cout, "-genin: ");
         iterateChildren(nodep);
         // After expanding the generate, all statements under it can be moved
@@ -420,9 +443,9 @@ private:
         } else {
             nodep->unlinkFrBack();
         }
-        nodep->deleteTree(); VL_DANGLING(nodep);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
-    virtual void visit(AstGenIf* nodep) {
+    virtual void visit(AstGenIf* nodep) VL_OVERRIDE {
         UINFO(9,"  GENIF "<<nodep<<endl);
         iterateAndNextNull(nodep->condp());
         // We suppress errors when widthing params since short-circuiting in
@@ -441,27 +464,27 @@ private:
             } else {
                 nodep->unlinkFrBack();
             }
-            nodep->deleteTree(); VL_DANGLING(nodep);
+            VL_DO_DANGLING(nodep->deleteTree(), nodep);
             // Normal edit rules will now recurse the replacement
         } else {
             nodep->condp()->v3error("Generate If condition must evaluate to constant");
         }
     }
 
-    //! Parameter subsitution for generated for loops.
+    //! Parameter substitution for generated for loops.
     //! @todo Unlike generated IF, we don't have to worry about short-circuiting the conditional
     //!       expression, since this is currently restricted to simple comparisons. If we ever do
     //!       move to more generic constant expressions, such code will be needed here.
-    virtual void visit(AstBegin* nodep) {
+    virtual void visit(AstBegin* nodep) VL_OVERRIDE {
         if (nodep->genforp()) {
             AstGenFor* forp = VN_CAST(nodep->genforp(), GenFor);
-            if (!forp) nodep->v3fatalSrc("Non-GENFOR under generate-for BEGIN");
+            UASSERT_OBJ(forp, nodep, "Non-GENFOR under generate-for BEGIN");
             // We should have a GENFOR under here.  We will be replacing the begin,
             // so process here rather than at the generate to avoid iteration problems
             UINFO(9,"  BEGIN "<<nodep<<endl);
             UINFO(9,"  GENFOR "<<forp<<endl);
             V3Width::widthParamsEdit(forp);  // Param typed widthing will NOT recurse the body
-            // Outer wrapper around generate used to hold genvar, and to insure genvar
+            // Outer wrapper around generate used to hold genvar, and to ensure genvar
             // doesn't conflict in V3LinkDot resolution with other genvars
             // Now though we need to change BEGIN("zzz", GENFOR(...)) to
             // a BEGIN("zzz__BRA__{loop#}__KET__")
@@ -470,7 +493,7 @@ private:
             // Note V3Unroll will replace some AstVarRef's to the loop variable with constants
             // Don't remove any deleted nodes in m_unroller until whole process finishes,
             // (are held in m_unroller), as some AstXRefs may still point to old nodes.
-            m_unroller.unrollGen(forp, beginName); VL_DANGLING(forp);
+            VL_DO_DANGLING(m_unroller.unrollGen(forp, beginName), forp);
             // Blocks were constructed under the special begin, move them up
             // Note forp is null, so grab statements again
             if (AstNode* stmtsp = nodep->genforp()) {
@@ -479,13 +502,16 @@ private:
                 // Note this clears nodep->genforp(), so begin is no longer special
             }
         } else {
+            string rootHierName(m_generateHierName);
+            m_generateHierName += "." + nodep->prettyName();
             iterateChildren(nodep);
+            m_generateHierName = rootHierName;
         }
     }
-    virtual void visit(AstGenFor* nodep) {
+    virtual void visit(AstGenFor* nodep) VL_OVERRIDE {
         nodep->v3fatalSrc("GENFOR should have been wrapped in BEGIN");
     }
-    virtual void visit(AstGenCase* nodep) {
+    virtual void visit(AstGenCase* nodep) VL_OVERRIDE {
         UINFO(9,"  GENCASE "<<nodep<<endl);
         AstNode* keepp = NULL;
         iterateAndNextNull(nodep->exprp());
@@ -500,7 +526,7 @@ private:
             for (AstNode* ep = itemp->condsp(); ep; ) {
                 AstNode* nextp = ep->nextp();  // May edit list
                 iterateAndNextNull(ep);
-                V3Const::constifyParamsEdit(ep); VL_DANGLING(ep);  // ep may change
+                VL_DO_DANGLING(V3Const::constifyParamsEdit(ep), ep);  // ep may change
                 ep = nextp;
             }
         }
@@ -534,16 +560,16 @@ private:
             nodep->replaceWith(keepp);
         }
         else nodep->unlinkFrBack();
-        nodep->deleteTree(); VL_DANGLING(nodep);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
     // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit ParamVisitor(AstNetlist* nodep) {
         m_longId = 0;
         m_modp = NULL;
@@ -557,34 +583,35 @@ public:
 //----------------------------------------------------------------------
 // VISITs
 
-void ParamVisitor::visitCell(AstCell* nodep) {
+void ParamVisitor::visitCell(AstCell* nodep, const string& hierName) {
     // Cell: Check for parameters in the instantiation.
     iterateChildren(nodep);
-    if (!nodep->modp()) nodep->v3fatalSrc("Not linked?");
+    UASSERT_OBJ(nodep->modp(), nodep, "Not linked?");
     // We always run this, even if no parameters, as need to look for interfaces,
     // and remove any recursive references
     {
         UINFO(4,"De-parameterize: "<<nodep<<endl);
         // Create new module name with _'s between the constants
-        if (debug()>=10) nodep->dumpTree(cout, "-cell:\t");
+        if (debug()>=10) nodep->dumpTree(cout, "-cell: ");
         // Evaluate all module constants
         V3Const::constifyParamsEdit(nodep);
         AstNodeModule* srcModp = nodep->modp();
+        srcModp->hierName(hierName + "." + nodep->name());
 
         // Make sure constification worked
         // Must be a separate loop, as constant conversion may have changed some pointers.
-        //if (debug()) nodep->dumpTree(cout, "-cel2:\t");
+        //if (debug()) nodep->dumpTree(cout, "-cel2: ");
         string longname = srcModp->name();
         bool any_overrides = false;
         if (nodep->recursive()) any_overrides = true;  // Must always clone __Vrcm (recursive modules)
         longname += "_";
-        if (debug()>8) nodep->paramsp()->dumpTreeAndNext(cout, "-cellparams:\t");
+        if (debug()>8) nodep->paramsp()->dumpTreeAndNext(cout, "-cellparams: ");
         for (AstPin* pinp = nodep->paramsp(); pinp; pinp=VN_CAST(pinp->nextp(), Pin)) {
             if (!pinp->exprp()) continue;  // No-connect
             if (AstVar* modvarp = pinp->modVarp()) {
                 if (!modvarp->isGParam()) {
                     pinp->v3error("Attempted parameter setting of non-parameter: Param "
-                                  <<pinp->prettyName()<<" of "<<nodep->prettyName());
+                                  <<pinp->prettyNameQ()<<" of "<<nodep->prettyNameQ());
                 } else if (VN_IS(pinp->exprp(), InitArray)
                            && VN_IS(modvarp->subDTypep(), UnpackArrayDType)) {
                     // Array assigned to array
@@ -597,7 +624,7 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                     if (!exprp) {
                         //if (debug()) pinp->dumpTree(cout, "error:");
                         pinp->v3error("Can't convert defparam value to constant: Param "
-                                      <<pinp->name()<<" of "<<nodep->prettyName());
+                                      <<pinp->prettyNameQ()<<" of "<<nodep->prettyNameQ());
                         pinp->exprp()->replaceWith(
                             new AstConst(pinp->fileline(),
                                          AstConst::WidthedValue(), modvarp->width(), 0));
@@ -622,13 +649,13 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                 AstNodeDType* origp = modvarp->subDTypep();
                 if (!exprp) {
                     pinp->v3error("Parameter type pin value isn't a type: Param "
-                                  <<pinp->prettyName()<<" of "<<nodep->prettyName());
+                                  <<pinp->prettyNameQ()<<" of "<<nodep->prettyNameQ());
                 } else if (!origp) {
                     pinp->v3error("Parameter type variable isn't a type: Param "
-                                  <<modvarp->prettyName());
+                                  <<modvarp->prettyNameQ());
                 } else {
                     UINFO(9,"Parameter type assignment expr="<<exprp<<" to "<<origp<<endl);
-                    if (origp && exprp->sameTree(origp)) {
+                    if (exprp->sameTree(origp)) {
                         // Setting parameter to its default value.  Just ignore it.
                         // This prevents making additional modules, and makes coverage more
                         // obvious as it won't show up under a unique module page name.
@@ -640,7 +667,7 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                 }
             } else {
                 pinp->v3error("Parameter not found in sub-module: Param "
-                              <<pinp->prettyName()<<" of "<<nodep->prettyName());
+                              <<pinp->prettyNameQ()<<" of "<<nodep->prettyNameQ());
             }
         }
         IfaceRefRefs ifaceRefRefs;
@@ -682,11 +709,11 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                 UINFO(9,"     portIfaceRef "<<portIrefp<<endl);
 
                 if (!portIrefp) {
-                    pinp->v3error("Interface port '"<<modvarp->prettyName()
-                                  <<"' is not an interface " << modvarp);
+                    pinp->v3error("Interface port "<<modvarp->prettyNameQ()
+                                  <<" is not an interface " << modvarp);
                 } else if (!pinIrefp) {
-                    pinp->v3error("Interface port '"<<modvarp->prettyName()
-                                  <<"' is not connected to interface/modport pin expression");
+                    pinp->v3error("Interface port "<<modvarp->prettyNameQ()
+                                  <<" is not connected to interface/modport pin expression");
                 } else {
                     UINFO(9,"     pinIfaceRef "<<pinIrefp<<endl);
                     if (portIrefp->ifaceViaCellp() != pinIrefp->ifaceViaCellp()) {
@@ -698,10 +725,11 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                         if (portIrefp->ifacep() != pinIrefp->ifacep()
                             // Might be different only due to param cloning, so check names too
                             && portIrefp->ifaceName() != pinIrefp->ifaceName()) {
-                            pinp->v3error("Port '"<<pinp->prettyName()<<"' expects '"
-                                          <<AstNode::prettyName(portIrefp->ifaceName())
-                                          <<"' interface but pin connects '"
-                                          <<AstNode::prettyName(pinIrefp->ifaceName())<<"' interface");
+                            pinp->v3error("Port "<<pinp->prettyNameQ()<<" expects "
+                                          <<AstNode::prettyNameQ(portIrefp->ifaceName())
+                                          <<" interface but pin connects "
+                                          <<AstNode::prettyNameQ(pinIrefp->ifaceName())
+                                          <<" interface");
                         }
                     }
                 }
@@ -777,7 +805,8 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                     AstIfaceRefDType* cloneIrefp = portIrefp->clonep();
                     UINFO(8,"     IfaceOld "<<portIrefp<<endl);
                     UINFO(8,"     IfaceTo  "<<pinIrefp<<endl);
-                    if (!cloneIrefp) portIrefp->v3fatalSrc("parameter clone didn't hit AstIfaceRefDType");
+                    UASSERT_OBJ(cloneIrefp, portIrefp,
+                                "parameter clone didn't hit AstIfaceRefDType");
                     UINFO(8,"     IfaceClo "<<cloneIrefp<<endl);
                     cloneIrefp->ifacep(pinIrefp->ifaceViaCellp());
                     UINFO(8,"     IfaceNew "<<cloneIrefp<<endl);
@@ -796,7 +825,7 @@ void ParamVisitor::visitCell(AstCell* nodep) {
                         }
                         else if (AstParamTypeDType* modptp = pinp->modPTypep()) {
                             AstNodeDType* dtypep = VN_CAST(pinp->exprp(), NodeDType);
-                            if (!dtypep) pinp->v3fatalSrc("unlinked param dtype");
+                            UASSERT_OBJ(dtypep, pinp, "unlinked param dtype");
                             if (modptp->childDTypep()) {
                                 pushDeletep(modptp->childDTypep()->unlinkFrBack());
                             }
