@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Parse syntax tree
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 
 #include "V3Ast.h"  // This must be before V3ParseBison.cpp, as we don't want #defines to conflict
 
@@ -79,7 +79,7 @@ void V3ParseGrammar::argWrapList(AstNodeFTaskRef* nodep) {
     if (outp) nodep->addPinsp(outp);
 }
 
-AstNode* V3ParseGrammar::createSupplyExpr(FileLine* fileline, string name, int value) {
+AstNode* V3ParseGrammar::createSupplyExpr(FileLine* fileline, const string& name, int value) {
     return new AstAssignW(fileline, new AstVarRef(fileline, name, true),
                           new AstConst(fileline, AstConst::StringToParse(),
                                        (value ? "'1" : "'0")));
@@ -88,12 +88,17 @@ AstNode* V3ParseGrammar::createSupplyExpr(FileLine* fileline, string name, int v
 AstRange* V3ParseGrammar::scrubRange(AstNodeRange* nrangep) {
     // Remove any UnsizedRange's from list
     for (AstNodeRange* nodep = nrangep, *nextp; nodep; nodep = nextp) {
-        nextp = VN_CAST(nrangep->nextp(), NodeRange);
+        nextp = VN_CAST(nodep->nextp(), NodeRange);
         if (!VN_IS(nodep, Range)) {
             nodep->v3error("Unsupported or syntax error: Unsized range in cell or other declaration");
-            nodep->unlinkFrBack(); nodep->deleteTree(); VL_DANGLING(nodep);
+            nodep->unlinkFrBack(); VL_DO_DANGLING(nodep->deleteTree(), nodep);
         }
     }
+    if (nrangep && nrangep->nextp()) {
+        // Not supported by at least 2 of big 3
+        nrangep->nextp()->v3error("Unsupported: Multidimensional cells/interfaces.");
+        nrangep->nextp()->unlinkFrBackWithNext()->deleteTree();
+    }
     return VN_CAST(nrangep, Range);
 }
 
@@ -108,18 +113,29 @@ AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep,
             AstNodeRange* prevp = VN_CAST(nrangep->backp(), NodeRange);
             if (prevp) nrangep->unlinkFrBack();
             AstRange* rangep = VN_CAST(nrangep, Range);
-            if (!rangep) {
-                if (!VN_IS(nrangep, UnsizedRange)) {
-                    nrangep->v3fatalSrc("Expected range or unsized range");
-                }
-                arrayp = new AstUnsizedArrayDType
-                    (nrangep->fileline(), VFlagChildDType(), arrayp);
-            } else if (isPacked) {
+            if (rangep && isPacked) {
                 arrayp = new AstPackArrayDType
                     (rangep->fileline(), VFlagChildDType(), arrayp, rangep);
-            } else {
+            } else if (VN_IS(nrangep, QueueRange)) {
+                arrayp = new AstQueueDType
+                    (nrangep->fileline(), VFlagChildDType(), arrayp, NULL);
+            } else if (rangep && (VN_IS(rangep->leftp(), Unbounded)
+                                  || VN_IS(rangep->rightp(), Unbounded))) {
+                arrayp = new AstQueueDType(nrangep->fileline(), VFlagChildDType(), arrayp,
+                                           rangep->rightp()->cloneTree(true));
+            } else if (rangep) {
                 arrayp = new AstUnpackArrayDType
                     (rangep->fileline(), VFlagChildDType(), arrayp, rangep);
+            } else if (VN_IS(nrangep, UnsizedRange)) {
+                arrayp = new AstUnsizedArrayDType
+                    (nrangep->fileline(), VFlagChildDType(), arrayp);
+            } else if (VN_IS(nrangep, AssocRange)) {
+                AstAssocRange* arangep = VN_CAST(nrangep, AssocRange);
+                AstNodeDType* keyp = arangep->keyDTypep(); keyp->unlinkFrBack();
+                arrayp = new AstAssocArrayDType
+                    (nrangep->fileline(), VFlagChildDType(), arrayp, keyp);
+            } else {
+                UASSERT_OBJ(0, nrangep, "Expected range or unsized range");
             }
             nrangep = prevp;
         }
@@ -127,7 +143,7 @@ AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep,
     return arrayp;
 }
 
-AstVar* V3ParseGrammar::createVariable(FileLine* fileline, string name,
+AstVar* V3ParseGrammar::createVariable(FileLine* fileline, const string& name,
                                        AstNodeRange* arrayp, AstNode* attrsp) {
     AstNodeDType* dtypep = GRAMMARP->m_varDTypep;
     UINFO(5,"  creVar "<<name<<"  decl="<<GRAMMARP->m_varDecl
@@ -166,6 +182,8 @@ AstVar* V3ParseGrammar::createVariable(FileLine* fileline, string name,
 
     AstVar* nodep = new AstVar(fileline, type, name, VFlagChildDType(), arrayDTypep);
     nodep->addAttrsp(attrsp);
+    nodep->ansi(m_pinAnsi);
+    nodep->declTyped(m_varDeclTyped);
     if (GRAMMARP->m_varDecl != AstVarType::UNKNOWN) nodep->combineType(GRAMMARP->m_varDecl);
     if (GRAMMARP->m_varIO != VDirection::NONE) {
         nodep->declDirection(GRAMMARP->m_varIO);
