@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilog::Preproc: Internal implementation of default preprocessor
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2000-2019 by Wilson Snyder.  This program is free software;
+// Copyright 2000-2020 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the
 // GNU Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -24,9 +24,11 @@
 #include "V3Error.h"
 #include "V3Global.h"
 #include "V3File.h"
+#include "V3LanguageWords.h"
 #include "V3PreLex.h"
 #include "V3PreProc.h"
 #include "V3PreShell.h"
+#include "V3String.h"
 
 #include <cstdarg>
 #include <cstdlib>
@@ -45,7 +47,7 @@
 
 //*************************************************************************
 
-class V3Define {
+class VDefine {
     // Define class.  One for each define.
     //string    m_name;         // Name of the define (list is keyed by this)
     FileLine*   m_fileline;     // Where it was declared
@@ -53,7 +55,7 @@ class V3Define {
     string      m_params;       // Parameters
     bool        m_cmdline;      // Set on command line, don't `undefineall
 public:
-    V3Define(FileLine* fl, const string& value, const string& params, bool cmdline)
+    VDefine(FileLine* fl, const string& value, const string& params, bool cmdline)
         : m_fileline(fl), m_value(value), m_params(params), m_cmdline(cmdline) {}
     FileLine* fileline() const { return m_fileline; }
     string value() const { return m_value; }
@@ -63,7 +65,7 @@ public:
 
 //*************************************************************************
 
-class V3DefineRef {
+class VDefineRef {
     // One for each pending define substitution
     string      m_name;         // Define last name being defined
     string      m_params;       // Define parameter list for next expansion
@@ -79,9 +81,9 @@ public:
     int parenLevel() const { return m_parenLevel; }
     void parenLevel(int value) { m_parenLevel = value; }
     std::vector<string>& args() { return m_args; }
-    V3DefineRef(const string& name, const string& params)
+    VDefineRef(const string& name, const string& params)
         : m_name(name), m_params(params), m_parenLevel(0) {}
-    ~V3DefineRef() {}
+    ~VDefineRef() {}
 };
 
 //*************************************************************************
@@ -105,8 +107,8 @@ public:
 class V3PreProcImp : public V3PreProc {
 public:
     // TYPES
-    typedef std::map<string,V3Define> DefinesMap;
-    typedef V3InFilter::StrList StrList;
+    typedef std::map<string,VDefine> DefinesMap;
+    typedef VInFilter::StrList StrList;
 
     // debug() -> see V3PreShellImp::debug; use --debugi-V3PreShell
 
@@ -117,6 +119,8 @@ public:
     V3PreProc* m_preprocp;  ///< Object we're holding data for
     V3PreLex* m_lexp;  ///< Current lexer state (NULL = closed)
     std::stack<V3PreLex*> m_includeStack;  ///< Stack of includers above current m_lexp
+    int m_lastLineno;  // Last line number (stall detection)
+    int m_tokensOnLine;  // Number of tokens on line (stall detection)
 
     enum ProcState { ps_TOP,
                      ps_DEFNAME_UNDEF, ps_DEFNAME_DEFINE,
@@ -131,10 +135,11 @@ public:
                "ps_DEFFORM", "ps_DEFVALUE", "ps_DEFPAREN", "ps_DEFARG",
                "ps_INCNAME", "ps_ERRORNAME", "ps_JOIN", "ps_STRIFY"};
         return states[s];
-    };
+    }
 
     std::stack<ProcState> m_states;  ///< Current state of parser
     int         m_off;          ///< If non-zero, ifdef level is turned off, don't dump text
+    bool        m_incError;     ///< Include error found
     string      m_lastSym;      ///< Last symbol name found.
     string      m_formals;      ///< Last formals found
 
@@ -155,7 +160,7 @@ public:
     string      m_strify;       ///< Text to be stringified
 
     // For defines
-    std::stack<V3DefineRef> m_defRefs;  ///< Pending definine substitution
+    std::stack<VDefineRef> m_defRefs;  ///< Pending define substitution
     std::stack<VPreIfEntry> m_ifdefStack;   ///< Stack of true/false emitting evaluations
     unsigned    m_defDepth;     ///< How many `defines deep
     bool        m_defPutJoin;   ///< Insert `` after substitution
@@ -178,7 +183,7 @@ public:
 private:
     // Internal methods
     void endOfOneFile();
-    string defineSubst(V3DefineRef* refp);
+    string defineSubst(VDefineRef* refp);
 
     bool defExists(const string& name);
     string defValue(const string& name);
@@ -215,9 +220,9 @@ private:
     }
     void statePop() {
         m_states.pop();
-        if (m_states.empty()) {
-            error("InternalError: Pop of parser state with nothing on stack");
-            m_states.push(ps_TOP);
+        if (VL_UNCOVERABLE(m_states.empty())) {
+            error("InternalError: Pop of parser state with nothing on stack");  // LCOV_EXCL_LINE
+            m_states.push(ps_TOP);  // LCOV_EXCL_LINE
         }
     }
     void stateChange(ProcState state) {
@@ -226,13 +231,15 @@ private:
 
 public:
     // METHODS, called from upper level shell
-    void openFile(FileLine* fl, V3InFilter* filterp, const string& filename);
+    void openFile(FileLine* fl, VInFilter* filterp, const string& filename);
     bool isEof() const { return m_lexp->curStreamp()->m_eof; }
+    void forceEof() { m_lexp->curStreamp()->m_eof = true; }
     string getline();
     void insertUnreadback(const string& text) { m_lineCmt += text; }
     void insertUnreadbackAtBol(const string& text);
     void addLineComment(int enterExit);
     void dumpDefines(std::ostream& os);
+    void candidateDefines(VSpellCheck* spellerp);
 
     // METHODS, callbacks
     virtual void comment(const string& text);  // Comment detected (if keepComments==2)
@@ -248,6 +255,7 @@ public:
         m_debug = 0;
         m_states.push(ps_TOP);
         m_off = 0;
+        m_incError = false;
         m_lineChars = "";
         m_lastSym = "";
         m_lineAdd = 0;
@@ -261,11 +269,14 @@ public:
         m_finFilelinep = NULL;
         m_lexp = NULL;
         m_preprocp = NULL;
+        m_lastLineno = 0;
+        m_tokensOnLine = 0;
     }
     void configure(FileLine* filelinep) {
         // configure() separate from constructor to avoid calling abstract functions
         m_preprocp = this;  // Silly, but to make code more similar to Verilog-Perl
-        m_finFilelinep = filelinep->create(1);
+        m_finFilelinep = new FileLine(filelinep->filename());
+        m_finFilelinep->lineno(1);
         // Create lexer
         m_lexp = new V3PreLex(this, filelinep);
         m_lexp->m_keepComments = m_preprocp->keepComments();
@@ -274,7 +285,7 @@ public:
         m_lexp->debug(debug()>=5 ? debug() : 0);  // See also V3PreProc::debug() method
     }
     ~V3PreProcImp() {
-        if (m_lexp) { delete m_lexp; m_lexp = NULL; }
+        if (m_lexp) VL_DO_CLEAR(delete m_lexp, m_lexp = NULL);
     }
 };
 
@@ -327,22 +338,28 @@ FileLine* V3PreProcImp::defFileline(const string& name) {
 void V3PreProcImp::define(FileLine* fl, const string& name, const string& value,
                           const string& params, bool cmdline) {
     UINFO(4,"DEFINE '"<<name<<"' as '"<<value<<"' params '"<<params<<"'"<<endl);
-    if (defExists(name)) {
-        if (!(defValue(name)==value && defParams(name)==params)) {  // Duplicate defs are OK
-            fl->v3warn(REDEFMACRO, "Redefining existing define: "<<name<<", with different value: "
-                       <<value<<(params=="" ? "":" ")<<params);
-            defFileline(name)->v3warn(REDEFMACRO, "Previous definition is here, with value: "
-                                      <<defValue(name)
-                                      <<(defParams(name)=="" ? "":" ")
-                                      <<defParams(name));
+    if (!V3LanguageWords::isKeyword(string("`") + name).empty()) {
+        fl->v3error("Attempting to define built-in directive: '`"
+                    << name << "' (IEEE 1800-2017 22.5.1)");
+    } else {
+        if (defExists(name)) {
+            if (!(defValue(name) == value
+                  && defParams(name) == params)) {  // Duplicate defs are OK
+                fl->v3warn(REDEFMACRO, "Redefining existing define: '"<<name<<"', with different value: "
+                           <<value<<(params=="" ? "":" ")<<params);
+                defFileline(name)->v3warn(REDEFMACRO, "Previous definition is here, with value: "
+                                          << defValue(name)
+                                          << (defParams(name).empty() ? "" : " ")
+                                          << defParams(name));
+            }
+            undef(name);
         }
-        undef(name);
+        m_defines.insert(make_pair(name, VDefine(fl, value, params, cmdline)));
     }
-    m_defines.insert(make_pair(name, V3Define(fl, value, params, cmdline)));
 }
 
 string V3PreProcImp::removeDefines(const string& text) {
-    string val = "0_never_match";
+    string val;
     string rtnsym = text;
     for (int loopprevent=0; loopprevent<100; loopprevent++) {
         string xsym = rtnsym;
@@ -492,6 +509,7 @@ const char* V3PreProcImp::tokenName(int tok) {
     case VP_ELSIF       : return("ELSIF");
     case VP_ENDIF       : return("ENDIF");
     case VP_EOF         : return("EOF");
+    case VP_EOF_ERROR   : return("EOF_ERROR");
     case VP_ERROR       : return("ERROR");
     case VP_IFDEF       : return("IFDEF");
     case VP_IFNDEF      : return("IFNDEF");
@@ -554,14 +572,14 @@ string V3PreProcImp::trimWhitespace(const string& strg, bool trailing) {
     return out;
 }
 
-string V3PreProcImp::defineSubst(V3DefineRef* refp) {
+string V3PreProcImp::defineSubst(VDefineRef* refp) {
     // Substitute out defines in a define reference.
     // (We also need to call here on non-param defines to handle `")
     // We could push the define text back into the lexer, but that's slow
     // and would make recursive definitions and parameter handling nasty.
     //
     // Note we parse the definition parameters and value here.  If a
-    // parametrized define is used many, many times, we could cache the
+    // parameterized define is used many, many times, we could cache the
     // parsed result.
     UINFO(4,"defineSubstIn  `"<<refp->name()<<" "<<refp->params()<<endl);
     for (unsigned i=0; i<refp->args().size(); i++) {
@@ -595,7 +613,7 @@ string V3PreProcImp::defineSubst(V3DefineRef* refp) {
                     // Parse it
                     if (argName!="") {
                         if (refp->args().size() > numArgs) {
-                            // A call `def( a ) must be equivelent to `def(a ), so trimWhitespace
+                            // A call `def( a ) must be equivalent to `def(a ), so trimWhitespace
                             // At one point we didn't trim trailing
                             // whitespace, but this confuses `"
                             string arg = trimWhitespace(refp->args()[numArgs], true);
@@ -743,8 +761,9 @@ string V3PreProcImp::defineSubst(V3DefineRef* refp) {
 //**********************************************************************
 // Parser routines
 
-void V3PreProcImp::openFile(FileLine* fl, V3InFilter* filterp, const string& filename) {
+void V3PreProcImp::openFile(FileLine* fl, VInFilter* filterp, const string& filename) {
     // Open a new file, possibly overriding the current one which is active.
+    if (m_incError) return;
     V3File::addSrcDepend(filename);
 
     // Read a list<string> with the whole file.
@@ -758,16 +777,27 @@ void V3PreProcImp::openFile(FileLine* fl, V3InFilter* filterp, const string& fil
     if (!m_preprocp->isEof()) {  // IE not the first file.
         // We allow the same include file twice, because occasionally it pops
         // up, with guards preventing a real recursion.
-        if (m_lexp->m_streampStack.size()>V3PreProc::INCLUDE_DEPTH_MAX) {
+        if (m_lexp->m_streampStack.size() > V3PreProc::INCLUDE_DEPTH_MAX) {
             error("Recursive inclusion of file: "+filename);
+            // Include might be a tree of includes that is O(n^2) or worse.
+            // Once hit this error then, ignore all further includes so can unwind.
+            m_incError = true;
             return;
         }
         // There's already a file active.  Push it to work on the new one.
         addLineComment(0);
     }
 
+    // Save file contents for future error reporting
+    FileLine* flsp = new FileLine(filename);
+    flsp->lineno(1);
+    flsp->newContent();
+    for (StrList::iterator it=wholefile.begin(); it!=wholefile.end(); ++it) {
+        flsp->contentp()->pushText(*it);
+    }
+
     // Create new stream structure
-    m_lexp->scanNewFile(m_preprocp->fileline()->create(filename, 1));
+    m_lexp->scanNewFile(flsp);
     addLineComment(1);  // Enter
 
     // Filter all DOS CR's en-mass.  This avoids bugs with lexing CRs in the wrong places.
@@ -818,7 +848,7 @@ void V3PreProcImp::addLineComment(int enterExit) {
 }
 
 void V3PreProcImp::dumpDefines(std::ostream& os) {
-    for (DefinesMap::iterator it = m_defines.begin(); it != m_defines.end(); ++it) {
+    for (DefinesMap::const_iterator it = m_defines.begin(); it != m_defines.end(); ++it) {
         os<<"`define "<<it->first;
         // No need to print "()" below as already part of params()
         if (!it->second.params().empty()) os<<it->second.params();
@@ -827,6 +857,12 @@ void V3PreProcImp::dumpDefines(std::ostream& os) {
     }
 }
 
+void V3PreProcImp::candidateDefines(VSpellCheck* spellerp) {
+    for (DefinesMap::const_iterator it = m_defines.begin(); it != m_defines.end(); ++it) {
+        spellerp->pushCandidate(string("`") + it->first);
+    }
+}
+
 int V3PreProcImp::getRawToken() {
     // Get a token from the file, whatever it may be.
     while (1) {
@@ -836,7 +872,7 @@ int V3PreProcImp::getRawToken() {
             m_rawAtBol = true;
             yyourtext("\n", 1);
             if (debug()>=5) debugToken(VP_WHITE, "LNA");
-            return (VP_WHITE);
+            return VP_WHITE;
         }
         if (m_lineCmt!="") {
             // We have some `line directive or other processed data to return to the user.
@@ -854,19 +890,30 @@ int V3PreProcImp::getRawToken() {
                 goto next_tok;
             } else {
                 if (debug()>=5) debugToken(VP_TEXT, "LCM");
-                return (VP_TEXT);
+                return VP_TEXT;
             }
         }
-        if (isEof()) return (VP_EOF);
+        if (isEof()) return VP_EOF;
 
         // Snarf next token from the file
+        m_lexp->curFilelinep()->startToken();
         int tok = m_lexp->lex();
-
         if (debug()>=5) debugToken(tok, "RAW");
 
-        // A EOF on an include, so we can print `line and detect mis-matched "s
-        if (tok==VP_EOF) {
-            goto next_tok;  // find the EOF, after adding needed lines
+        if (m_lastLineno != m_lexp->m_tokFilelinep->lineno()) {
+            m_lastLineno = m_lexp->m_tokFilelinep->lineno();
+            m_tokensOnLine = 0;
+        } else if (++m_tokensOnLine > LINE_TOKEN_MAX) {
+            error("Too many preprocessor tokens on a line (>"+cvtToStr(LINE_TOKEN_MAX)
+                  +"); perhaps recursive `define");
+            tok = VP_EOF_ERROR;
+        }
+
+        if (tok==VP_EOF || tok==VP_EOF_ERROR) {
+            // An error might be in an unexpected point, so stop parsing
+            if (tok==VP_EOF_ERROR) forceEof();
+            // A EOF on an include, stream will find the EOF, after adding needed `lines
+            goto next_tok;
         }
 
         if (yyourleng()) m_rawAtBol = (yyourtext()[yyourleng()-1]=='\n');
@@ -875,16 +922,22 @@ int V3PreProcImp::getRawToken() {
 }
 
 void V3PreProcImp::debugToken(int tok, const char* cmtp) {
-    if (debug()>=5) {
+    static int s_debugFileline = v3Global.opt.debugSrcLevel("fileline");  // --debugi-fileline 9
+    if (debug() >= 5) {
         string buf = string(yyourtext(), yyourleng());
         string::size_type pos;
         while ((pos = buf.find('\n')) != string::npos) { buf.replace(pos, 1, "\\n"); }
         while ((pos = buf.find('\r')) != string::npos) { buf.replace(pos, 1, "\\r"); }
-        fprintf(stderr, "%d: %s %s %s(%d) dr%d:  <%d>%-10s: %s\n",
-                m_lexp->m_tokFilelinep->lineno(), cmtp, m_off?"of":"on",
+        string flcol = m_lexp->m_tokFilelinep->asciiLineCol();
+        fprintf(stderr, "%s: %s %s %s(%d) dr%d:  <%d>%-10s: %s\n",
+                flcol.c_str(),
+                cmtp, (m_off ? "of" : "on"),
                 procStateName(state()), static_cast<int>(m_states.size()),
                 static_cast<int>(m_defRefs.size()),
                 m_lexp->currentStartState(), tokenName(tok), buf.c_str());
+        if (s_debugFileline >= 9) {
+            std::cerr<<m_lexp->m_tokFilelinep->warnContextSecondary()<<endl;
+        }
     }
 }
 
@@ -899,7 +952,7 @@ int V3PreProcImp::getStateToken() {
         int tok = getRawToken();
 
         // Most states emit white space and comments between tokens. (Unless collecting a string)
-        if (tok==VP_WHITE && state() !=ps_STRIFY) return (tok);
+        if (tok==VP_WHITE && state() !=ps_STRIFY) return tok;
         if (tok==VP_BACKQUOTE && state() !=ps_STRIFY) { tok = VP_TEXT; }
         if (tok==VP_COMMENT) {
             if (!m_off) {
@@ -909,7 +962,7 @@ int V3PreProcImp::getStateToken() {
                     // Need to ensure "foo/**/bar" becomes two tokens
                     insertUnreadback(" ");
                 } else if (m_lexp->m_keepComments) {
-                    return (tok);
+                    return tok;
                 } else {
                     // Need to ensure "foo/**/bar" becomes two tokens
                     insertUnreadback(" ");
@@ -930,7 +983,7 @@ int V3PreProcImp::getStateToken() {
 
         if (tok==VP_DEFREF_JOIN) {
             // Here's something fun and unspecified as yet:
-            // The existance of non-existance of a base define changes `` expansion
+            // The existence of non-existance of a base define changes `` expansion
             //  `define QA_b zzz
             //  `define Q1 `QA``_b
             //   1Q1 -> zzz
@@ -1024,7 +1077,7 @@ int V3PreProcImp::getStateToken() {
                 else goto next_tok;
             }
             else if (tok==VP_DEFREF) {
-                // IE, `ifdef `MACRO(x): Substitue and come back here when state pops.
+                // IE, `ifdef `MACRO(x): Substitute and come back here when state pops.
                 break;
             }
             else {
@@ -1097,7 +1150,7 @@ int V3PreProcImp::getStateToken() {
                 goto next_tok;
             } else {
                 if (m_defRefs.empty()) fatalSrc("Shouldn't be in DEFPAREN w/o active defref");
-                V3DefineRef* refp = &(m_defRefs.top());
+                VDefineRef* refp = &(m_defRefs.top());
                 error(string("Expecting ( to begin argument list for define reference `")+refp->name()+"\n");
                 statePop();
                 goto next_tok;
@@ -1105,7 +1158,7 @@ int V3PreProcImp::getStateToken() {
         }
         case ps_DEFARG: {
             if (m_defRefs.empty()) fatalSrc("Shouldn't be in DEFARG w/o active defref");
-            V3DefineRef* refp = &(m_defRefs.top());
+            VDefineRef* refp = &(m_defRefs.top());
             refp->nextarg(refp->nextarg()+m_lexp->m_defValue); m_lexp->m_defValue = "";
             UINFO(4,"defarg++ "<<refp->nextarg()<<endl);
             if (tok==VP_DEFARG && yyourleng()==1 && yyourtext()[0]==',') {
@@ -1123,7 +1176,7 @@ int V3PreProcImp::getStateToken() {
                     out = defineSubst(refp);
                     //NOP: out = m_preprocp->defSubstitute(out);
                 }
-                m_defRefs.pop(); VL_DANGLING(refp);
+                VL_DO_DANGLING(m_defRefs.pop(), refp);
                 if (m_defRefs.empty()) {
                     statePop();
                     if (state() == ps_JOIN) {  // Handle {left}```FOO(ARG) where `FOO(ARG) might be empty
@@ -1264,7 +1317,7 @@ int V3PreProcImp::getStateToken() {
             }
             else if (tok==VP_DEFREF) {
                 // Spec says to expand macros inside `"
-                // Substitue it into the stream, then return here
+                // Substitute it into the stream, then return here
                 break;
             }
             else {
@@ -1339,7 +1392,7 @@ int V3PreProcImp::getStateToken() {
                 if (m_off) {
                     goto next_tok;
                 } else {
-                    return (VP_TEXT);
+                    return VP_TEXT;
                 }
             }
             else {
@@ -1347,7 +1400,7 @@ int V3PreProcImp::getStateToken() {
                 if (params=="0" || params=="") {  // Found, as simple substitution
                     string out;
                     if (!m_off) {
-                        V3DefineRef tempref(name, "");
+                        VDefineRef tempref(name, "");
                         out = defineSubst(&tempref);
                     }
                     // Similar code in parenthesized define (Search for END_OF_DEFARG)
@@ -1369,7 +1422,7 @@ int V3PreProcImp::getStateToken() {
                         // Can't subst now, or
                         // `define a x,y
                         // foo(`a,`b)  would break because a contains comma
-                        V3DefineRef* refp = &(m_defRefs.top());
+                        VDefineRef* refp = &(m_defRefs.top());
                         refp->nextarg(refp->nextarg()+m_lexp->m_defValue+out);
                         m_lexp->m_defValue = "";
                     }
@@ -1380,7 +1433,7 @@ int V3PreProcImp::getStateToken() {
                     // The CURRENT macro needs the paren saved, it's not a
                     // property of the child macro
                     if (!m_defRefs.empty()) m_defRefs.top().parenLevel(m_lexp->m_parenLevel);
-                    m_defRefs.push(V3DefineRef(name, params));
+                    m_defRefs.push(VDefineRef(name, params));
                     statePush(ps_DEFPAREN);
                     m_lexp->pushStateDefArg(0);
                     goto next_tok;
@@ -1441,8 +1494,10 @@ int V3PreProcImp::getFinalToken(string& buf) {
     buf = m_finBuf;
     if (0 && debug()>=5) {
         string bufcln = V3PreLex::cleanDbgStrg(buf);
-        fprintf(stderr, "%d: FIN:      %-10s: %s\n",
-                m_lexp->m_tokFilelinep->lineno(), tokenName(tok), bufcln.c_str());
+        string flcol = m_lexp->m_tokFilelinep->asciiLineCol();
+        fprintf(stderr, "%s: FIN:      %-10s: %s\n",
+                flcol.c_str(),
+                tokenName(tok), bufcln.c_str());
     }
     // Track `line
     const char* bufp = buf.c_str();
@@ -1454,14 +1509,17 @@ int V3PreProcImp::getFinalToken(string& buf) {
     else {
         if (m_finAtBol && !(tok==VP_TEXT && buf=="\n")
             && m_preprocp->lineDirectives()) {
-            if (int outBehind = m_lexp->m_tokFilelinep->lineno() - m_finFilelinep->lineno()) {
+            if (int outBehind = (m_lexp->m_tokFilelinep->lastLineno()
+                                 - m_finFilelinep->lastLineno())) {
                 if (debug()>=5) {
-                    fprintf(stderr, "%d: FIN: readjust, fin at %d  request at %d\n",
-                            m_lexp->m_tokFilelinep->lineno(),
-                            m_finFilelinep->lineno(), m_lexp->m_tokFilelinep->lineno());
+                    string flcol = m_lexp->m_tokFilelinep->asciiLineCol();
+                    fprintf(stderr, "%s: FIN: readjust, fin at %d  request at %d\n",
+                            flcol.c_str(),
+                            m_finFilelinep->lastLineno(),
+                            m_lexp->m_tokFilelinep->lastLineno());
                 }
-                m_finFilelinep = m_finFilelinep->create(m_lexp->m_tokFilelinep->filename(),
-                                                        m_lexp->m_tokFilelinep->lineno());
+                m_finFilelinep->filename(m_lexp->m_tokFilelinep->filename());
+                m_finFilelinep->lineno(m_lexp->m_tokFilelinep->lastLineno());
                 if (outBehind > 0
                     && (outBehind <= static_cast<int>(V3PreProc::NEWLINES_VS_TICKLINE))) {
                     // Output stream is behind, send newlines to get back in sync
@@ -1481,8 +1539,7 @@ int V3PreProcImp::getFinalToken(string& buf) {
         for (string::iterator cp=buf.begin(); cp!=buf.end(); ++cp) {
             if (*cp == '\n') {
                 m_finAtBol = true;
-                // Increment in place to avoid new/delete calls.  It's private data.
-                m_finFilelinep->linenoIncInPlace();
+                m_finFilelinep->linenoInc();
             } else {
                 m_finAtBol = false;
             }
@@ -1502,8 +1559,10 @@ string V3PreProcImp::getline() {
         int tok = getFinalToken(buf/*ref*/);
         if (debug()>=5) {
             string bufcln = V3PreLex::cleanDbgStrg(buf);
-            fprintf(stderr, "%d: GETFETC:  %-10s: %s\n",
-                    m_lexp->m_tokFilelinep->lineno(), tokenName(tok), bufcln.c_str());
+            string flcol = m_lexp->m_tokFilelinep->asciiLineCol();
+            fprintf(stderr, "%s: GETFETC:  %-10s: %s\n",
+                    flcol.c_str(),
+                    tokenName(tok), bufcln.c_str());
         }
         if (tok==VP_EOF) {
             // Add a final newline, if the user forgot the final \n.
@@ -1523,8 +1582,10 @@ string V3PreProcImp::getline() {
     m_lineChars = m_lineChars.erase(0, len);  // Remove returned characters
     if (debug()>=4) {
         string lncln = V3PreLex::cleanDbgStrg(theLine);
-        fprintf(stderr, "%d: GETLINE:  %s\n",
-                m_lexp->m_tokFilelinep->lineno(), lncln.c_str());
+        string flcol = m_lexp->m_tokFilelinep->asciiLineCol();
+        fprintf(stderr, "%s: GETLINE:  %s\n",
+                flcol.c_str(),
+                lncln.c_str());
     }
     return theLine;
 }
