@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Preprocessing wrapper program
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2004-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2004-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3PRESHELL_H_
 #define _V3PRESHELL_H_ 1
 
@@ -28,7 +28,8 @@
 #include "V3FileLine.h"
 
 class V3ParseImp;
-class V3InFilter;
+class VInFilter;
+class VSpellCheck;
 
 //============================================================================
 
@@ -36,13 +37,13 @@ class V3PreShell {
     // Static class for calling preprocessor
 public:
     static void boot(char** env);
-    static bool preproc(FileLine* fl, const string& modname, V3InFilter* filterp,
+    static bool preproc(FileLine* fl, const string& modname, VInFilter* filterp,
                         V3ParseImp* parsep, const string& errmsg);
     static void preprocInclude(FileLine* fl, const string& modname);
-    static string dependFiles() { return ""; }  // Perl only
     static void defineCmdLine(const string& name, const string& value);
     static void undef(const string& name);
     static void dumpDefines(std::ostream& os);
+    static void candidateDefines(VSpellCheck* spellerp);
 };
 
 #endif  // Guard
