@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Break always into separate statements to reduce temps
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -80,7 +80,7 @@
 //  Also vars must not be "public" and we also scoreboard nodep->isPure()
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -110,11 +110,7 @@ protected:
     // Do not make accessor for nodep(),  It may change due to
     // reordering a lower block, but we don't repair it
     virtual string name() const {
-        if (m_nodep->name() == "") {
-            return cvtToHex(m_nodep);
-        } else {
-            return m_nodep->name();
-        }
+        return cvtToHex(m_nodep) + ' ' + m_nodep->prettyTypeName();
     }
     virtual FileLine* fileline() const { return nodep()->fileline(); }
 public:
@@ -263,9 +259,9 @@ protected:
     SplitPliVertex*     m_pliVertexp;   // Element specifying PLI ordering
     V3Graph             m_graph;        // Scoreboard of var usages/dependencies
     bool                m_inDly;        // Inside ASSIGNDLY
-    V3Double0           m_statSplits;   // Statistic tracking
+    VDouble0            m_statSplits;   // Statistic tracking
 
-    // CONSTUCTORS
+    // CONSTRUCTORS
 public:
     SplitReorderBaseVisitor() {
         scoreboardClear();
@@ -309,7 +305,7 @@ private:
         //UINFO(9,"    push "<<nodep<<endl);
         SplitLogicVertex* vertexp = new SplitLogicVertex(&m_graph, nodep);
         m_stmtStackps.push_back(vertexp);
-        if (nodep->user3p()) nodep->v3fatalSrc("user3p should not be used; cleared in processBlock");
+        UASSERT_OBJ(!nodep->user3p(), nodep, "user3p should not be used; cleared in processBlock");
         nodep->user3p(vertexp);
     }
     void scoreboardPopStmt() {
@@ -350,22 +346,22 @@ protected:
     virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) = 0;
 
     // VISITORS
-    virtual void visit(AstAlways* nodep) = 0;
-    virtual void visit(AstNodeIf* nodep) = 0;
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE = 0;
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE = 0;
 
     // We don't do AstNodeFor/AstWhile loops, due to the standard question
     // of what is before vs. after
 
-    virtual void visit(AstAssignDly* nodep) {
+    virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         m_inDly = true;
         UINFO(4,"    ASSIGNDLY "<<nodep<<endl);
         iterateChildren(nodep);
         m_inDly = false;
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (!m_stmtStackps.empty()) {
             AstVarScope* vscp = nodep->varScopep();
-            if (!vscp) nodep->v3fatalSrc("Not linked");
+            UASSERT_OBJ(vscp, nodep, "Not linked");
             if (!nodep->varp()->isConst()) {  // Constant lookups can be ignored
                 // ---
                 // NOTE: Formerly at this location we would avoid
@@ -426,7 +422,7 @@ protected:
         }
     }
 
-    virtual void visit(AstJumpGo* nodep) {
+    virtual void visit(AstJumpGo* nodep) VL_OVERRIDE {
         // Jumps will disable reordering at all levels
         // This is overly pessimistic; we could treat jumps as barriers, and
         // reorder everything between jumps/labels, however jumps are rare
@@ -438,7 +434,7 @@ protected:
 
     //--------------------
     // Default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // **** SPECIAL default type that sets PLI_ORDERING
         if (!m_stmtStackps.empty() && !nodep->isPure()) {
             UINFO(9,"         NotSplittable "<<nodep<<endl);
@@ -461,7 +457,7 @@ public:
 
     // METHODS
 protected:
-    void makeRvalueEdges(SplitVarStdVertex* vstdp) {
+    virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) VL_OVERRIDE {
         for (VStack::iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end(); ++it) {
             new SplitRVEdge(&m_graph, *it, vstdp);
         }
@@ -518,7 +514,7 @@ protected:
         for (AstNode* nextp=nodep; nextp; nextp=nextp->nextp()) {
             SplitLogicVertex* vvertexp = reinterpret_cast<SplitLogicVertex*>(nextp->user3p());
             uint32_t color = vvertexp->color();
-            if (!color) nextp->v3fatalSrc("No node color assigned");
+            UASSERT_OBJ(color, nextp, "No node color assigned");
             if (lastOfColor[color]) {
                 new SplitStrictEdge(&m_graph, lastOfColor[color], vvertexp);
             }
@@ -580,9 +576,8 @@ protected:
         AstNode* firstp = nodep;  // We may reorder, and nodep is no longer first.
         void* oldBlockUser3 = nodep->user3p();  // May be overloaded in below loop, save it
         nodep->user3p(NULL);
-        if (!nodep->firstAbovep()) {
-            nodep->v3fatalSrc("Node passed is in next list; should have processed all list at once");
-        }
+        UASSERT_OBJ(nodep->firstAbovep(), nodep,
+                    "Node passed is in next list; should have processed all list at once");
         // Process it
         if (!nodep->nextp()) {
             // Just one, so can't reorder.  Just look for more blocks/statements.
@@ -611,7 +606,7 @@ protected:
         firstp->user3p(oldBlockUser3);
     }
 
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         UINFO(4,"   ALW   "<<nodep<<endl);
         if (debug()>=9) nodep->dumpTree(cout, "   alwIn:: ");
         scoreboardClear();
@@ -619,7 +614,7 @@ protected:
         if (debug()>=9) nodep->dumpTree(cout, "   alwOut: ");
     }
 
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"     IF "<<nodep<<endl);
         iterateAndNextNull(nodep->condp());
         processBlock(nodep->ifsp());
@@ -656,18 +651,12 @@ public:
     const ColorSet& colors() const { return m_colors; }
     const ColorSet& colors(AstNodeIf* nodep) const {
         IfColorMap::const_iterator it = m_ifColors.find(nodep);
-        if (it == m_ifColors.end()) nodep->v3fatalSrc("Unknown node in split color() map");
+        UASSERT_OBJ(it != m_ifColors.end(), nodep, "Node missing from split color() map");
         return it->second;
     }
 
-protected:
-    virtual void visit(AstNodeIf* nodep) {
-        m_ifStack.push_back(nodep);
-        iterateChildren(nodep);
-        m_ifStack.pop_back();
-    }
-
-    virtual void visit(AstNode* nodep) {
+private:
+    void trackNode(AstNode* nodep) {
         if (nodep->user3p()) {
             SplitLogicVertex* vertexp = reinterpret_cast<SplitLogicVertex*>(nodep->user3p());
             uint32_t color = vertexp->color();
@@ -680,6 +669,17 @@ protected:
                 m_ifColors[*it].insert(color);
             }
         }
+    }
+
+protected:
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
+        m_ifStack.push_back(nodep);
+        trackNode(nodep);
+        iterateChildren(nodep);
+        m_ifStack.pop_back();
+    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
+        trackNode(nodep);
         iterateChildren(nodep);
     }
 
@@ -746,7 +746,7 @@ protected:
         return new AstSplitPlaceholder(m_origAlwaysp->fileline());
     }
 
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // Anything that's not an if/else we assume is a leaf
         // (that is, something we won't split.) Don't visit further
         // into the leaf.
@@ -758,7 +758,7 @@ protected:
         // for such an embedded if.
 
         // Each leaf must have a user3p
-        if (!nodep->user3p()) nodep->v3fatalSrc("null user3p in V3Split leaf");
+        UASSERT_OBJ(nodep->user3p(), nodep, "null user3p in V3Split leaf");
 
         // Clone the leaf into its new always block
         SplitLogicVertex* vxp = reinterpret_cast<SplitLogicVertex*>(nodep->user3p());
@@ -768,7 +768,7 @@ protected:
         m_addAfter[color] = clonedp;
     }
 
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         const ColorSet& colors = m_ifColorp->colors(nodep);
         typedef vl_unordered_map<uint32_t, AstNodeIf*> CloneMap;
         CloneMap clones;
@@ -825,14 +825,14 @@ public:
              it != m_removeSet.end(); ++it) {
             AstNode* np = *it;
             np->unlinkFrBack();  // Without next
-            np->deleteTree(); VL_DANGLING(np);
+            VL_DO_DANGLING(np->deleteTree(), np);
         }
     }
     virtual ~RemovePlaceholdersVisitor() {}
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
-    virtual void visit(AstSplitPlaceholder* nodep) {
+    virtual void visit(AstSplitPlaceholder* nodep) VL_OVERRIDE {
         m_removeSet.insert(nodep);
     }
 private:
@@ -868,7 +868,7 @@ public:
                 RemovePlaceholdersVisitor removePlaceholders(*addme);
             }
             origp->unlinkFrBack();  // Without next
-            origp->deleteTree(); VL_DANGLING(origp);
+            VL_DO_DANGLING(origp->deleteTree(), origp);
         }
     }
 
@@ -876,7 +876,7 @@ public:
 
     // METHODS
 protected:
-    void makeRvalueEdges(SplitVarStdVertex* vstdp) {
+    virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) VL_OVERRIDE {
         // Each 'if' depends on rvalues in its own conditional ONLY,
         // not rvalues in the if/else bodies.
         for (VStack::const_iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end(); ++it) {
@@ -945,18 +945,17 @@ protected:
             }
         }
 
-        if (debug()>=9) {
-            m_graph.dumpDotFilePrefixed("splitg_nodup", false);
-        }
+        if (debug()>=9) m_graph.dumpDotFilePrefixed("splitg_nodup", false);
 
         // Weak coloring to determine what needs to remain grouped
         // in a single always. This follows all edges excluding:
         //  - those we pruned above
         //  - PostEdges, which are done later
         m_graph.weaklyConnected(&SplitEdge::followScoreboard);
+        if (debug()>=9) m_graph.dumpDotFilePrefixed("splitg_colored", false);
     }
 
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // build the scoreboard
         scoreboardClear();
         scanBlock(nodep->bodysp());
@@ -989,7 +988,7 @@ protected:
             emitSplit.go();
         }
     }
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"     IF "<<nodep<<endl);
         m_curIfConditional = nodep;
         iterateAndNextNull(nodep->condp());
