@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Break always into separate statements to reduce temps
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -24,7 +24,7 @@
 //      Replicate the Always, and remove mis-colored duplicate code.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -55,17 +55,17 @@ private:
     AstVarScope* m_splitVscp;  // Variable we want to split
 
     // METHODS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->lvalue() && !m_splitVscp
             && nodep->varp()->attrIsolateAssign()) {
             m_splitVscp = nodep->varScopep();
         }
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit SplitAsFindVisitor(AstAlways* nodep) {
         m_splitVscp = NULL;
         iterate(nodep);
@@ -87,7 +87,7 @@ private:
     bool         m_matches;     // Statement below has matching lvalue reference
 
     // METHODS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->lvalue()) {
             if (nodep->varScopep()==m_splitVscp) {
                 UINFO(6,"       CL VAR "<<nodep<<endl);
@@ -95,7 +95,7 @@ private:
             }
         }
     }
-    virtual void visit(AstNodeStmt* nodep) {
+    virtual void visit(AstNodeStmt* nodep) VL_OVERRIDE {
         if (!nodep->isStatement()) {
             iterateChildren(nodep);
             return;
@@ -121,11 +121,11 @@ private:
         m_keepStmt = oldKeep || m_keepStmt;
         UINFO(9,"     upKeep="<<m_keepStmt<<" STMT "<<nodep<<endl);
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     SplitAsCleanVisitor(AstAlways* nodep, AstVarScope* vscp, bool modeMatch) {
         m_splitVscp = vscp;
         m_modeMatch = modeMatch;
@@ -146,8 +146,8 @@ private:
     AstUser1InUse       m_inuser1;
 
     // STATE
-    V3Double0   m_statSplits;   // Statistic tracking
-    AstVarScope* m_splitVscp;   // Variable we want to split
+    VDouble0 m_statSplits;  // Statistic tracking
+    AstVarScope* m_splitVscp;  // Variable we want to split
 
     // METHODS
     void splitAlways(AstAlways* nodep) {
@@ -168,7 +168,7 @@ private:
         }
     }
 
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // Are there any lvalue references below this?
         // There could be more than one.  So, we process the first one found first.
         AstVarScope* lastSplitVscp = NULL;
@@ -179,7 +179,7 @@ private:
             if (m_splitVscp && m_splitVscp == lastSplitVscp) {
                 // We did this last time!  Something's stuck!
                 nodep->v3fatalSrc("Infinite loop in isolate_assignments removal for: "
-                                  <<m_splitVscp->prettyName())
+                                  <<m_splitVscp->prettyNameQ())
                 m_splitVscp = NULL;
             }
             lastSplitVscp = m_splitVscp;
@@ -194,14 +194,14 @@ private:
     }
 
     // Speedup; no always under math
-    virtual void visit(AstNodeMath* nodep) {}
+    virtual void visit(AstNodeMath* nodep) VL_OVERRIDE {}
 
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit SplitAsVisitor(AstNetlist* nodep) {
         m_splitVscp = NULL;
         AstNode::user1ClearTree();  // user1p() used on entire tree
