@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Collect and print statistics
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2005-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2005-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -49,22 +49,22 @@ private:
     bool        m_fast;
 
     AstCFunc*   m_cfuncp;               // Current CFUNC
-    V3Double0   m_statInstrLong;        // Instruction count
+    VDouble0    m_statInstrLong;        // Instruction count
     bool        m_counting;             // Currently counting
     double      m_instrs;               // Current instr count (for determining branch direction)
     bool        m_tracingCall;          // Iterating into a CCall to a CFunc
 
-    std::vector<V3Double0> m_statTypeCount;     // Nodes of given type
-    V3Double0           m_statAbove[AstType::_ENUM_END][AstType::_ENUM_END];    // Nodes of given type
-    V3Double0           m_statPred[AstBranchPred::_ENUM_END];   // Nodes of given type
-    V3Double0           m_statInstr;            // Instruction count
-    V3Double0           m_statInstrFast;        // Instruction count, non-slow() eval functions only
-    std::vector<V3Double0> m_statVarWidths;     // Variables of given width
-    std::vector<NameMap>   m_statVarWidthNames; // Var names of given width
-    V3Double0           m_statVarArray;         // Statistic tracking
-    V3Double0           m_statVarBytes;         // Statistic tracking
-    V3Double0           m_statVarClock;         // Statistic tracking
-    V3Double0           m_statVarScpBytes;      // Statistic tracking
+    std::vector<VDouble0> m_statTypeCount;     // Nodes of given type
+    VDouble0           m_statAbove[AstType::_ENUM_END][AstType::_ENUM_END];  // Nodes of given type
+    VDouble0           m_statPred[VBranchPred::_ENUM_END];  // Nodes of given type
+    VDouble0           m_statInstr;            // Instruction count
+    VDouble0           m_statInstrFast;        // Instruction count, non-slow() eval functions only
+    std::vector<VDouble0> m_statVarWidths;     // Variables of given width
+    std::vector<NameMap>  m_statVarWidthNames;  // Var names of given width
+    VDouble0           m_statVarArray;         // Statistic tracking
+    VDouble0           m_statVarBytes;         // Statistic tracking
+    VDouble0           m_statVarClock;         // Statistic tracking
+    VDouble0           m_statVarScpBytes;      // Statistic tracking
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -82,7 +82,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         allNodes(nodep);
         if (!m_fast) {
             // Count all CFuncs below this module
@@ -91,7 +91,7 @@ private:
         // Else we recursively trace fast CFuncs from the top _eval
         // func, see visit(AstNetlist*)
     }
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         allNodes(nodep);
         iterateChildrenConst(nodep);
         if (m_counting && nodep->dtypep()) {
@@ -114,7 +114,7 @@ private:
             }
         }
     }
-    virtual void visit(AstVarScope* nodep) {
+    virtual void visit(AstVarScope* nodep) VL_OVERRIDE {
         allNodes(nodep);
         iterateChildrenConst(nodep);
         if (m_counting) {
@@ -123,7 +123,7 @@ private:
             }
         }
     }
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"   IF i="<<m_instrs<<" "<<nodep<<endl);
         allNodes(nodep);
         // Condition is part of cost allocated to PREVIOUS block
@@ -140,7 +140,7 @@ private:
             // Need to do even if !m_counting because maybe determining upstream if/else
             double ifInstrs = 0.0;
             double elseInstrs = 0.0;
-            if (nodep->branchPred() != AstBranchPred::BP_UNLIKELY) {  // Check if
+            if (nodep->branchPred() != VBranchPred::BP_UNLIKELY) {  // Check if
                 double prevInstr = m_instrs;
                 bool prevCounting = m_counting;
                 {
@@ -152,7 +152,7 @@ private:
                 m_instrs = prevInstr;
                 m_counting = prevCounting;
             }
-            if (nodep->branchPred() != AstBranchPred::BP_LIKELY) {  // Check else
+            if (nodep->branchPred() != VBranchPred::BP_LIKELY) {  // Check else
                 double prevInstr = m_instrs;
                 bool prevCounting = m_counting;
                 {
@@ -175,9 +175,9 @@ private:
         }
     }
     // While's we assume evaluate once.
-    //virtual void visit(AstWhile* nodep) {
+    //virtual void visit(AstWhile* nodep) VL_OVERRIDE {
 
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstCCall* nodep) VL_OVERRIDE {
         allNodes(nodep);
         iterateChildrenConst(nodep);
         if (m_fast && !nodep->funcp()->entryPoint()) {
@@ -186,7 +186,7 @@ private:
             iterate(nodep->funcp());
         }
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         if (m_fast) {
             if (!m_tracingCall && !nodep->entryPoint()) return;
             m_tracingCall = false;
@@ -196,15 +196,15 @@ private:
         iterateChildrenConst(nodep);
         m_cfuncp = NULL;
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         allNodes(nodep);
         iterateChildrenConst(nodep);
     }
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         if (m_fast && nodep->evalp()) {
             m_instrs = 0;
             m_counting = true;
-            if (nodep->evalp()) iterateChildrenConst(nodep->evalp());
+            iterateChildrenConst(nodep->evalp());
             m_counting = false;
         }
         allNodes(nodep);
@@ -258,8 +258,8 @@ public:
                 V3Stats::addStat(m_stage, string("Node count, ")+AstType(type).ascii(), count);
             }
         }
-        for (int type=0; type<AstType::_ENUM_END; type++) {
-            for (int type2=0; type2<AstType::_ENUM_END; type2++) {
+        for (int type=0; type < AstType::_ENUM_END; type++) {
+            for (int type2=0; type2 < AstType::_ENUM_END; type2++) {
                 double count = double(m_statAbove[type][type2]);
                 if (count != 0.0) {
                     V3Stats::addStat(m_stage, (string("Node pairs, ")
@@ -269,11 +269,11 @@ public:
             }
         }
         // Branch pred
-        for (int type=0; type<AstBranchPred::_ENUM_END; type++) {
+        for (int type=0; type < VBranchPred::_ENUM_END; type++) {
             double count = double(m_statPred[type]);
             if (count != 0.0) {
                 V3Stats::addStat(m_stage, (string("Branch prediction, ")
-                                           + AstBranchPred(type).ascii()), count);
+                                           + VBranchPred(type).ascii()), count);
             }
         }
     }
