@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Substitute constants and expressions in expr temp's
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2004-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2004-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -25,7 +25,7 @@
 //      the RHS hasn't changed value.
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -136,7 +136,7 @@ public:
         if (!m_varp->isWide()
             && !m_whole.m_complex && m_whole.m_assignp && !m_wordAssign) {
             AstNodeAssign* assp = m_whole.m_assignp;
-            if (!assp) errp->v3fatalSrc("Reading whole that was never assigned");
+            UASSERT_OBJ(assp, errp, "Reading whole that was never assigned");
             return (assp->rhsp());
         } else {
             return NULL;
@@ -145,7 +145,7 @@ public:
     AstNode* substWord(AstNode* errp, int word) {  // Return what to substitute given word number for
         if (!m_whole.m_complex && !m_whole.m_assignp && !m_words[word].m_complex) {
             AstNodeAssign* assp = getWordAssignp(word);
-            if (!assp) errp->v3fatalSrc("Reading a word that was never assigned, or bad word #");
+            UASSERT_OBJ(assp, errp, "Reading a word that was never assigned, or bad word #");
             return (assp->rhsp());
         } else {
             return NULL;
@@ -159,17 +159,17 @@ public:
     }
     void deleteAssign(AstNodeAssign* nodep) {
         UINFO(5, "Delete "<<nodep<<endl);
-        nodep->unlinkFrBack()->deleteTree(); VL_DANGLING(nodep);
+        VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
     }
     void deleteUnusedAssign() {
         // If there are unused assignments in this var, kill them
         if (!m_whole.m_use && !m_wordUse && m_whole.m_assignp) {
-            deleteAssign(m_whole.m_assignp); m_whole.m_assignp = NULL;
+            VL_DO_CLEAR(deleteAssign(m_whole.m_assignp), m_whole.m_assignp = NULL);
         }
         for (unsigned i=0; i<m_words.size(); i++) {
             if (!m_whole.m_use && !m_words[i].m_use
                 && m_words[i].m_assignp && !m_words[i].m_complex) {
-                deleteAssign(m_words[i].m_assignp); m_words[i].m_assignp = NULL;
+                VL_DO_CLEAR(deleteAssign(m_words[i].m_assignp), m_words[i].m_assignp = NULL);
             }
         }
     }
@@ -193,7 +193,7 @@ private:
         return reinterpret_cast<SubstVarEntry*>(nodep->varp()->user1p());  // Might be NULL
     }
     // VISITORS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         SubstVarEntry* entryp = findEntryp(nodep);
         if (entryp) {
             // Don't sweat it.  We assign a new temp variable for every new assignment,
@@ -206,12 +206,12 @@ private:
             }
         }
     }
-    virtual void visit(AstConst* nodep) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     SubstUseVisitor(AstNode* nodep, int origStep) {
         UINFO(9, "        SubstUseVisitor "<<origStep<<" "<<nodep<<endl);
         m_ok = true;
@@ -239,7 +239,7 @@ private:
     std::vector<SubstVarEntry*> m_entryps;      // Nodes to delete when we are finished
     int                         m_ops;          // Number of operators on assign rhs
     int                         m_assignStep;   // Assignment number to determine var lifetime
-    V3Double0                   m_statSubsts;   // Statistic tracking
+    VDouble0                    m_statSubsts;   // Statistic tracking
 
     enum { SUBST_MAX_OPS_SUBST = 30,            // Maximum number of ops to substitute in
            SUBST_MAX_OPS_NA = 9999 };           // Not allowed to substitute
@@ -261,7 +261,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         m_ops = 0;
         m_assignStep++;
         iterateAndNextNull(nodep->rhsp());
@@ -308,10 +308,10 @@ private:
         }
         if (debug()>5)  newp->dumpTree(cout, "       w_new: ");
         nodep->replaceWith(newp);
-        pushDeletep(nodep); VL_DANGLING(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
         ++m_statSubsts;
     }
-    virtual void visit(AstWordSel* nodep) {
+    virtual void visit(AstWordSel* nodep) VL_OVERRIDE {
         iterate(nodep->rhsp());
         AstVarRef* varrefp = VN_CAST(nodep->lhsp(), VarRef);
         AstConst* constp = VN_CAST(nodep->rhsp(), Const);
@@ -327,7 +327,7 @@ private:
                 // Check that the RHS hasn't changed value since we recorded it.
                 SubstUseVisitor visitor (substp, entryp->getWordStep(word));
                 if (visitor.ok()) {
-                    replaceSubstEtc(nodep, substp); VL_DANGLING(nodep);
+                    VL_DO_DANGLING(replaceSubstEtc(nodep, substp), nodep);
                 } else {
                     entryp->consumeWord(word);
                 }
@@ -338,7 +338,7 @@ private:
             iterate(nodep->lhsp());
         }
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         // Any variable
         if (nodep->lvalue()) {
             m_assignStep++;
@@ -355,7 +355,7 @@ private:
                 SubstUseVisitor visitor (substp, entryp->getWholeStep());
                 if (visitor.ok()) {
                     UINFO(8," USEwhole "<<nodep<<endl);
-                    replaceSubstEtc(nodep, substp); VL_DANGLING(nodep);
+                    VL_DO_DANGLING(replaceSubstEtc(nodep, substp), nodep);
                 } else {
                     UINFO(8," USEwholeButChg "<<nodep<<endl);
                     entryp->consumeWhole();
@@ -366,9 +366,9 @@ private:
             }
         }
     }
-    virtual void visit(AstVar* nodep) {}
-    virtual void visit(AstConst* nodep) {}
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {}
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {}
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         m_ops++;
         if (!nodep->isSubstOptimizable()) {
             m_ops = SUBST_MAX_OPS_NA;
@@ -376,7 +376,7 @@ private:
         iterateChildren(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit SubstVisitor(AstNode* nodep) {
         AstNode::user1ClearTree();  // user1p() used on entire tree
         AstNode::user2ClearTree();  // user2p() used on entire tree
