@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Symbol table
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3LINKSYMTABLE_H_
 #define _V3LINKSYMTABLE_H_ 1
 
@@ -27,6 +27,7 @@
 #include "V3Global.h"
 #include "V3Ast.h"
 #include "V3File.h"
+#include "V3String.h"
 
 #include <cstdarg>
 #include <map>
@@ -158,6 +159,23 @@ public:
         if (m_fallbackp) return m_fallbackp->findIdFallback(name);
         return NULL;
     }
+    void candidateIdFlat(VSpellCheck* spellerp, const VNodeMatcher* matcherp) const {
+        // Suggest alternative symbol candidates without looking upward through symbol hierarchy
+        for (IdNameMap::const_iterator it = m_idNameMap.begin();
+             it != m_idNameMap.end(); ++it) {
+            const AstNode* itemp = it->second->nodep();
+            if (itemp && (!matcherp || matcherp->nodeMatch(itemp))) {
+                spellerp->pushCandidate(itemp->prettyName());
+            }
+        }
+    }
+    void candidateIdFallback(VSpellCheck* spellerp, const VNodeMatcher* matcherp) const {
+        // Suggest alternative symbol candidates with looking upward through symbol hierarchy
+        // Note VSpellCheck wants the most important (closest) items pushed first
+        candidateIdFlat(spellerp, matcherp);
+        // Then suggest the upper begin/end block or module
+        if (m_fallbackp) m_fallbackp->candidateIdFallback(spellerp, matcherp);
+    }
 private:
     void importOneSymbol(VSymGraph* graphp, const string& name, const VSymEnt* srcp) {
         if (srcp->exported()
@@ -231,9 +249,9 @@ public:
         if (prettyName=="") prettyName = lookp->prettyName();
         string scopes;
         for (IdNameMap::iterator it = m_idNameMap.begin(); it!=m_idNameMap.end(); ++it) {
-            AstNode* nodep = it->second->nodep();
-            if (VN_IS(nodep, Cell)
-                || (VN_IS(nodep, Module) && VN_CAST(nodep, Module)->isTop())) {
+            AstNode* itemp = it->second->nodep();
+            if (VN_IS(itemp, Cell)
+                || (VN_IS(itemp, Module) && VN_CAST(itemp, Module)->isTop())) {
                 if (scopes != "") scopes += ", ";
                 scopes += AstNode::prettyName(it->first);
             }
@@ -241,7 +259,7 @@ public:
         if (scopes=="") scopes="<no cells found>";
         std::cerr<<V3Error::warnMore()<<"... Known scopes under '"<<prettyName<<"': "
                  <<scopes<<endl;
-        if (debug()) dump(std::cerr,"\t\t      KnownScope: ", 1);
+        if (debug()) dump(std::cerr, "       KnownScope: ", 1);
     }
 };
 
