@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Make lookup tables
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -24,7 +24,7 @@
 //      replace with lookup table
 //
 //*************************************************************************
-
+
 #include "config_build.h"
 #include "verilatedos.h"
 
@@ -75,12 +75,13 @@ private:
 
     // STATE
     double      m_totalBytes;           // Total bytes in tables created
-    V3Double0   m_statTablesCre;        // Statistic tracking
+    VDouble0    m_statTablesCre;        // Statistic tracking
 
     //  State cleared on each module
     AstNodeModule*      m_modp;         // Current MODULE
     int                 m_modTables;    // Number of tables created in this module
-    std::deque<AstVarScope*> m_modTableVscs;  // All tables created
+    typedef std::deque<AstVarScope*> ModTableVector;
+    ModTableVector m_modTableVscs;  // All tables created
 
     //  State cleared on each scope
     AstScope*   m_scopep;               // Current SCOPE
@@ -154,7 +155,7 @@ private:
 
 public:
     void simulateVarRefCb(AstVarRef* nodep) {
-        // Called by TableSimulateVisitor on each unique varref enountered
+        // Called by TableSimulateVisitor on each unique varref encountered
         UINFO(9,"   SimVARREF "<<nodep<<endl);
         AstVarScope* vscp = nodep->varScopep();
         if (nodep->lvalue()) {
@@ -219,7 +220,7 @@ private:
             nodeap->bodysp()->unlinkFrBackWithNext()->deleteTree();
             nodeap->addStmtp(stmtsp);
             if (debug()>=6) nodeap->dumpTree(cout, "  table_new: ");
-        } else {
+        } else {  // LCOV_EXCL_LINE
             nodep->v3fatalSrc("Creating table under unknown node type");
         }
 
@@ -283,7 +284,7 @@ private:
         // Create table
         // There may be a simulation path by which the output doesn't change value.
         // We could bail on these cases, or we can have a "change it" boolean.
-        // We've choosen the later route, since recirc is common in large FSMs.
+        // We've chosen the latter route, since recirc is common in large FSMs.
         for (std::deque<AstVarScope*>::iterator it = m_outVarps.begin();
              it != m_outVarps.end(); ++it) {
             m_outNotSet.push_back(false);
@@ -304,22 +305,21 @@ private:
                  it != m_inVarps.end(); ++it) {
                 AstVarScope* invscp = *it;
                 // LSB is first variable, so extract it that way
-                simvis.newNumber(invscp,
-                                 V3Number(invscp, invscp->width(),
-                                          VL_MASK_I(invscp->width()) & (inValue>>shift)));
+                AstConst cnst(invscp->fileline(), AstConst::WidthedValue(), invscp->width(),
+                              VL_MASK_I(invscp->width()) & (inValue>>shift));
+                simvis.newValue(invscp, &cnst);
                 shift += invscp->width();
                 // We're just using32 bit arithmetic, because there's no
                 // way the input table can be 2^32 bytes!
-                if (shift>31) nodep->v3fatalSrc("shift overflow");
-                UINFO(8,"   Input "<<invscp->name()<<" = "<<*(simvis.fetchNumber(invscp))<<endl);
+                UASSERT_OBJ(shift <= 32, nodep, "shift overflow");
+                UINFO(8,"   Input "<<invscp->name()<<" = "<<cnst.name()<<endl);
             }
 
             // Simulate
             simvis.mainTableEmulate(nodep);
-            if (!simvis.optimizable()) {
-                simvis.whyNotNodep()->v3fatalSrc("Optimizable cleared, even though earlier test run said not: "
-                                                 <<simvis.whyNotMessage());
-            }
+            UASSERT_OBJ(simvis.optimizable(), simvis.whyNotNodep(),
+                        "Optimizable cleared, even though earlier test run said not: "
+                        <<simvis.whyNotMessage());
 
             // If a output changed, add it to table
             int outnum = 0;
@@ -348,8 +348,9 @@ private:
             }
 
             {   // Set changed table
-                if (inValue != inValueNextInitArray++)
-                    nodep->v3fatalSrc("InitArray requires us to have the values in inValue order");
+                UASSERT_OBJ(inValue == inValueNextInitArray, nodep,
+                            "InitArray requires us to have the values in inValue order");
+                inValueNextInitArray++;
                 AstNode* setp = new AstConst(nodep->fileline(), outputChgMask);
                 VN_CAST(chgVscp->varp()->valuep(), InitArray)->addValuep(setp);
             }
@@ -371,7 +372,7 @@ private:
                 const AstNode* init2p = VN_CAST(var2p->valuep(), InitArray);
                 if (init1p->sameGateTree(init2p)) {
                     UINFO(8,"   Duplicate table var "<<vsc2p<<" == "<<vsc1p<<endl);
-                    vsc1p->unlinkFrBack()->deleteTree();
+                    VL_DO_DANGLING(vsc1p->unlinkFrBack()->deleteTree(), vsc1p);
                     return vsc2p;
                 }
             }
@@ -423,37 +424,44 @@ private:
 
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
-    virtual void visit(AstNodeModule* nodep) {
-        m_modTables = 0;
-        m_modTableVscs.clear();
-        m_modp = nodep;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        int origModTables = m_modTables;
+        ModTableVector origModTableVscs = m_modTableVscs;
+        {
+            m_modp = nodep;
+            m_modTables = 0;
+            m_modTableVscs.clear();
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
+        m_modTables = origModTables;
+        m_modTableVscs = origModTableVscs;
     }
-    virtual void visit(AstScope* nodep) {
+    virtual void visit(AstScope* nodep) VL_OVERRIDE {
         UINFO(4," SCOPE "<<nodep<<endl);
         m_scopep = nodep;
         iterateChildren(nodep);
         m_scopep = NULL;
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         UINFO(4,"  ALWAYS  "<<nodep<<endl);
         if (treeTest(nodep)) {
             // Well, then, I'll be a memory hog.
-            createTable(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(createTable(nodep), nodep);
         }
     }
-    virtual void visit(AstAssignAlias* nodep) {}
-    virtual void visit(AstAssignW* nodep) {
+    virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {}
+    virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         // It's nearly impossible to have a large enough assign to make this worthwhile
         // For now we won't bother.
         // Accelerated: no iterate
     }
     // default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 public:
