@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Inlining of modules
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3TASK_H_
 #define _V3TASK_H_ 1
 
@@ -41,6 +41,11 @@ public:
     static void taskAll(AstNetlist* nodep);
     /// Return vector of [port, pin-connects-to]  (SLOW)
     static V3TaskConnects taskConnects(AstNodeFTaskRef* nodep, AstNode* taskStmtsp);
+    static string assignInternalToDpi(AstVar* portp, bool isRtn, bool isPtr,
+                                      const string& frSuffix, const string& toSuffix,
+                                      const string& frPrefix="");
+    static bool dpiToInternalFrStmt(AstVar* portp, const string& frName, bool cvt,
+                                    string& frstmt);
 };
 
-#endif // Guard
+#endif  // Guard
