@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Waves tracing
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -131,7 +131,8 @@ public:
     virtual FileLine* fileline() const { return nodep()->fileline(); }
     TraceTraceVertex* duplicatep() const { return m_duplicatep; }
     void duplicatep(TraceTraceVertex* dupp) {
-        if (duplicatep()) nodep()->v3fatalSrc("Assigning duplicatep() to already duplicated node");
+        UASSERT_OBJ(!duplicatep(), nodep(),
+                    "Assigning duplicatep() to already duplicated node");
         m_duplicatep = dupp;
     }
 };
@@ -189,9 +190,9 @@ private:
     bool                m_finding;      // Pass one of algorithm?
     int                 m_funcNum;      // Function number being built
 
-    V3Double0           m_statChgSigs;  // Statistic tracking
-    V3Double0           m_statUniqSigs; // Statistic tracking
-    V3Double0           m_statUniqCodes;// Statistic tracking
+    VDouble0 m_statChgSigs;  // Statistic tracking
+    VDouble0 m_statUniqSigs;  // Statistic tracking
+    VDouble0 m_statUniqCodes;  // Statistic tracking
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -205,10 +206,9 @@ private:
             if (TraceTraceVertex* vvertexp = dynamic_cast<TraceTraceVertex*>(itp)) {
                 AstTraceInc* nodep = vvertexp->nodep();
                 if (nodep->valuep()) {
-                    if (nodep->valuep()->backp() != nodep) {
-                        nodep->v3fatalSrc("Trace duplicate back needs consistency,"
-                                          " so we can map duplicates back to TRACEINCs");
-                    }
+                    UASSERT_OBJ(nodep->valuep()->backp() == nodep, nodep,
+                                "Trace duplicate back needs consistency,"
+                                " so we can map duplicates back to TRACEINCs");
                     hashed.hash(nodep->valuep());
                     UINFO(8, "  Hashed "<<std::hex<<hashed.nodeHash(nodep->valuep())
                           <<" "<<nodep<<endl);
@@ -229,7 +229,7 @@ private:
                     if (dupit != hashed.end()) {
                         AstTraceInc* dupincp
                             = VN_CAST(hashed.iteratorNodep(dupit)->backp(), TraceInc);
-                        if (!dupincp) nodep->v3fatalSrc("Trace duplicate of wrong type");
+                        UASSERT_OBJ(dupincp, nodep, "Trace duplicate of wrong type");
                         TraceTraceVertex* dupvertexp
                             = dynamic_cast<TraceTraceVertex*>(dupincp->user1u().toGraphVertex());
                         UINFO(8,"  Orig "<<nodep<<endl);
@@ -275,7 +275,8 @@ private:
                 for (V3GraphEdge* edgep = vvertexp->inBeginp(); edgep; edgep=edgep->inNextp()) {
                     TraceActivityVertex* actVtxp
                         = dynamic_cast<TraceActivityVertex*>(edgep->fromp());
-                    if (!actVtxp) vvertexp->nodep()->v3fatalSrc("Tracing a node with FROM non activity");
+                    UASSERT_OBJ(actVtxp, vvertexp->nodep(),
+                                "Tracing a node with FROM non activity");
                     if (actVtxp->activityAlways()) {
                         alwaysEdgep = edgep;
                         break;
@@ -340,8 +341,8 @@ private:
                                  AstVarType::MODULETEMP,
                                   "__Vm_traceActivity", newArrDtp);
         } else {
-            // For tighter code; round to next 32 bit point.
-            int activityBits = VL_WORDS_I(m_activityNumber)*VL_WORDSIZE;
+            // For tighter code; round to next word point.
+            int activityBits = VL_WORDS_I(m_activityNumber) * VL_EDATASIZE;
             newvarp = new AstVar(m_chgFuncp->fileline(), AstVarType::MODULETEMP,
                                  "__Vm_traceActivity", VFlagBitPacked(), activityBits);
         }
@@ -438,7 +439,8 @@ private:
                 for (V3GraphEdge* edgep = vvertexp->inBeginp(); edgep; edgep=edgep->inNextp()) {
                     TraceActivityVertex* cfvertexp
                         = dynamic_cast<TraceActivityVertex*>(edgep->fromp());
-                    if (!cfvertexp) vvertexp->nodep()->v3fatalSrc("Should have been function pointing to this trace");
+                    UASSERT_OBJ(cfvertexp, vvertexp->nodep(),
+                                "Should have been function pointing to this trace");
                     UINFO(9,"   Activity: "<<cfvertexp<<endl);
                     if (cfvertexp->activityAlways()) {
                         // If code 0, we always trace; ignore other codes
@@ -447,9 +449,7 @@ private:
                         break;
                     } else {
                         uint32_t acode = cfvertexp->activityCode();
-                        if (actset.find(acode) == actset.end()) {
-                            actset.insert(acode);
-                        }
+                        actset.insert(acode);
                     }
                 }
                 // If a trace doesn't have activity, it's constant, and we
@@ -499,7 +499,7 @@ private:
                         else condp = selp;
                     }
                     AstIf* ifp = new AstIf(fl, condp, NULL, NULL);
-                    ifp->branchPred(AstBranchPred::BP_UNLIKELY);
+                    ifp->branchPred(VBranchPred::BP_UNLIKELY);
                     m_chgFuncp->addStmtsp(ifp);
                     lastactp = &actset;
                     ifnodep = ifp;
@@ -550,7 +550,8 @@ private:
             dupvertexp = dupvertexp->duplicatep();
             UINFO(9,"   dupOf "<<cvtToHex(dupvertexp)<<" "<<cvtToHex(dupvertexp->nodep())
                   <<" "<<dupvertexp<<endl);
-            if (dupvertexp->duplicatep()) dupvertexp->nodep()->v3fatalSrc("Original node was marked as a duplicate");
+            UASSERT_OBJ(!dupvertexp->duplicatep(), dupvertexp->nodep(),
+                        "Original node was marked as a duplicate");
         }
 
         if (dupvertexp != vvertexp) {
@@ -584,7 +585,7 @@ private:
             m_fullSubStmts += EmitCBaseCounterVisitor(nodep).count();
         } else {
             // Duplicates don't need a TraceInc
-            pushDeletep(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
         return incAddp;
     }
@@ -610,7 +611,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         m_code = 1;  // Multiple TopScopes will require fixing how code#s
         // are assigned as duplicate varscopes must result in the same tracing code#.
 
@@ -638,17 +639,17 @@ private:
         assignActivity();
         putTracesIntoTree();
     }
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         if (nodep->isTop()) m_topModp = nodep;
         iterateChildren(nodep);
     }
-    virtual void visit(AstTopScope* nodep) {
+    virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
         AstScope* scopep = nodep->scopep();
-        if (!scopep) nodep->v3fatalSrc("No scope found on top level");
+        UASSERT_OBJ(scopep, nodep, "No scope found on top level");
         m_highScopep = scopep;
         iterateChildren(nodep);
     }
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstCCall* nodep) VL_OVERRIDE {
         UINFO(8,"   CCALL "<<nodep<<endl);
         if (!m_finding && !nodep->user2()) {
             // See if there are other calls in same statement list;
@@ -666,7 +667,7 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         UINFO(8,"   CFUNC "<<nodep<<endl);
         if (nodep->funcType() == AstCFuncType::TRACE_INIT) {
             m_initFuncp = nodep;
@@ -681,7 +682,7 @@ private:
                 || nodep == v3Global.rootp()->evalp()) {
                 // Need a non-null place to remember to later add a statement; make one
                 if (!nodep->stmtsp()) nodep->addStmtsp(
-                    new AstComment(nodep->fileline(), "Tracing activity check"));
+                    new AstComment(nodep->fileline(), "Tracing activity check", true));
                 V3GraphVertex* activityVtxp = getActivityVertexp(nodep->stmtsp(), nodep->slow());
                 new V3GraphEdge(&m_graph, activityVtxp, funcVtxp, 1);
             }
@@ -690,23 +691,23 @@ private:
         iterateChildren(nodep);
         m_funcp = NULL;
     }
-    virtual void visit(AstTraceInc* nodep) {
+    virtual void visit(AstTraceInc* nodep) VL_OVERRIDE {
         UINFO(8,"   TRACE "<<nodep<<endl);
-        if (m_finding) nodep->v3fatalSrc("Traces should have been removed in prev step.");
+        UASSERT_OBJ(!m_finding, nodep, "Traces should have been removed in prev step.");
         nodep->unlinkFrBack();
 
         V3GraphVertex* vertexp = new TraceTraceVertex(&m_graph, nodep);
         nodep->user1p(vertexp);
 
-        if (!m_funcp || (!m_chgFuncp || !m_fullFuncp)) nodep->v3fatalSrc("Trace not under func");
+        UASSERT_OBJ(m_funcp && m_chgFuncp && m_fullFuncp, nodep, "Trace not under func");
         m_tracep = nodep;
         iterateChildren(nodep);
         m_tracep = NULL;
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (m_tracep) {
-            if (!nodep->varScopep()) nodep->v3fatalSrc("No var scope?");
-            if (nodep->lvalue()) nodep->v3fatalSrc("Lvalue in trace?  Should be const.");
+            UASSERT_OBJ(nodep->varScopep(), nodep, "No var scope?");
+            UASSERT_OBJ(!nodep->lvalue(), nodep, "Lvalue in trace?  Should be const.");
             V3GraphVertex* varVtxp = nodep->varScopep()->user1u().toGraphVertex();
             if (!varVtxp) {
                 varVtxp = new TraceVarVertex(&m_graph, nodep->varScopep());
@@ -720,7 +721,7 @@ private:
             }
         }
         else if (m_funcp && m_finding && nodep->lvalue()) {
-            if (!nodep->varScopep()) nodep->v3fatalSrc("No var scope?");
+            UASSERT_OBJ(nodep->varScopep(), nodep, "No var scope?");
             V3GraphVertex* funcVtxp = getCFuncVertexp(m_funcp);
             V3GraphVertex* varVtxp = nodep->varScopep()->user1u().toGraphVertex();
             if (varVtxp) {  // else we're not tracing this signal
@@ -729,12 +730,12 @@ private:
         }
     }
     //--------------------
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
 
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit TraceVisitor(AstNetlist* nodep) {
         m_funcp = NULL;
         m_tracep = NULL;
@@ -753,7 +754,6 @@ public:
         m_chgSubStmts = 0;
         m_activityNumber = 0;
         m_code = 0;
-        m_finding = false;
         m_funcNum = 0;
         iterate(nodep);
     }
