@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: Cleanup stage in V3Width
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _V3WIDTHCOMMIT_H_
 #define _V3WIDTHCOMMIT_H_ 1
 
@@ -39,20 +39,20 @@
 class WidthRemoveVisitor : public AstNVisitor {
 private:
     // VISITORS
-    virtual void visit(AstSigned* nodep) {
-        replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()); VL_DANGLING(nodep);
+    virtual void visit(AstSigned* nodep) VL_OVERRIDE {
+        VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
     }
-    virtual void visit(AstUnsigned* nodep) {
-        replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()); VL_DANGLING(nodep);
+    virtual void visit(AstUnsigned* nodep) VL_OVERRIDE {
+        VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
     }
     void replaceWithSignedVersion(AstNode* nodep, AstNode* newp) {
         UINFO(6," Replace "<<nodep<<" w/ "<<newp<<endl);
         nodep->replaceWith(newp);
         newp->dtypeFrom(nodep);
-        pushDeletep(nodep); VL_DANGLING(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
 public:
     // CONSTRUCTORS
@@ -114,27 +114,27 @@ private:
         return nodep;
     }
     // VISITORS
-    virtual void visit(AstConst* nodep) {
-        if (!nodep->dtypep()) nodep->v3fatalSrc("No dtype");
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {
+        UASSERT_OBJ(nodep->dtypep(), nodep, "No dtype");
         iterate(nodep->dtypep());  // Do datatype first
         if (AstConst* newp = newIfConstCommitSize(nodep)) {
             nodep->replaceWith(newp);
             AstNode* oldp = nodep; nodep = newp;
             //if (debug()>4) oldp->dumpTree(cout, "  fixConstSize_old: ");
             //if (debug()>4) newp->dumpTree(cout, "              _new: ");
-            pushDeletep(oldp); VL_DANGLING(oldp);
+            VL_DO_DANGLING(pushDeletep(oldp), oldp);
         }
         editDType(nodep);
     }
-    virtual void visit(AstNodeDType* nodep) {
+    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
         visitIterateNodeDType(nodep);
     }
-    virtual void visit(AstNodeClassDType* nodep) {
+    virtual void visit(AstNodeUOrStructDType* nodep) VL_OVERRIDE {
         if (nodep->user1SetOnce()) return;  // Process once
         visitIterateNodeDType(nodep);
         nodep->clearCache();
     }
-    virtual void visit(AstParamTypeDType* nodep) {
+    virtual void visit(AstParamTypeDType* nodep) VL_OVERRIDE {
         if (nodep->user1SetOnce()) return;  // Process once
         visitIterateNodeDType(nodep);
         // Move to type table as all dtype pointers must resolve there
@@ -151,17 +151,18 @@ private:
         if (nodep->numeric().isNosign()) nodep->numeric(AstNumeric::UNSIGNED);
         iterateChildren(nodep);
         nodep->virtRefDTypep(editOneDType(nodep->virtRefDTypep()));
+        nodep->virtRefDType2p(editOneDType(nodep->virtRefDType2p()));
     }
-    virtual void visit(AstNodePreSel* nodep) {
+    virtual void visit(AstNodePreSel* nodep) VL_OVERRIDE {  // LCOV_EXCL_LINE
         // This check could go anywhere after V3Param
         nodep->v3fatalSrc("Presels should have been removed before this point");
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         editDType(nodep);
     }
 public:
-    // CONSTUCTORS
+    // CONSTRUCTORS
     explicit WidthCommitVisitor(AstNetlist* nodep) {
         // Were changing widthMin's, so the table is now somewhat trashed
         nodep->typeTablep()->clearCache();
