@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: main()
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #include "V3Global.h"
 #include "V3Ast.h"
 
@@ -31,19 +31,20 @@
 #include "V3Cast.h"
 #include "V3Changed.h"
 #include "V3Clean.h"
-#include "V3ClkGater.h"
 #include "V3Clock.h"
 #include "V3Combine.h"
 #include "V3Const.h"
 #include "V3Coverage.h"
 #include "V3CoverageJoin.h"
 #include "V3CCtors.h"
+#include "V3CUse.h"
 #include "V3Dead.h"
 #include "V3Delayed.h"
 #include "V3Depth.h"
 #include "V3DepthBlock.h"
 #include "V3Descope.h"
 #include "V3EmitC.h"
+#include "V3EmitCMake.h"
 #include "V3EmitMk.h"
 #include "V3EmitV.h"
 #include "V3EmitXml.h"
@@ -74,6 +75,7 @@
 #include "V3Partition.h"
 #include "V3PreShell.h"
 #include "V3Premit.h"
+#include "V3ProtectLib.h"
 #include "V3Reloop.h"
 #include "V3Scope.h"
 #include "V3Scoreboard.h"
@@ -99,67 +101,7 @@
 
 V3Global v3Global;
 
-//######################################################################
-// V3 Class -- top level
-
-AstNetlist* V3Global::makeNetlist() {
-    AstNetlist* newp = new AstNetlist();
-    newp->addTypeTablep(new AstTypeTable(newp->fileline()));
-    return newp;
-}
-
-void V3Global::checkTree() { rootp()->checkTree(); }
-
-void V3Global::clear() {
-    if (m_rootp) { m_rootp->deleteTree(); m_rootp = NULL; }
-}
-
-void V3Global::readFiles() {
-    // NODE STATE
-    //   AstNode::user4p()      // VSymEnt*    Package and typedef symbol names
-    AstUser4InUse       inuser4;
-
-    V3InFilter filter (v3Global.opt.pipeFilter());
-    V3ParseSym parseSyms (v3Global.rootp());  // Symbol table must be common across all parsing
-
-    V3Parse parser (v3Global.rootp(), &filter, &parseSyms);
-    // Read top module
-    const V3StringList& vFiles = v3Global.opt.vFiles();
-    for (V3StringList::const_iterator it = vFiles.begin(); it != vFiles.end(); ++it) {
-        string filename = *it;
-        parser.parseFile(new FileLine(FileLine::commandLineFilename(), 0),
-                         filename, false,
-                         "Cannot find file containing module: ");
-    }
-
-    // Read libraries
-    // To be compatible with other simulators,
-    // this needs to be done after the top file is read
-    const V3StringSet& libraryFiles = v3Global.opt.libraryFiles();
-    for (V3StringSet::const_iterator it = libraryFiles.begin(); it != libraryFiles.end(); ++it) {
-        string filename = *it;
-        parser.parseFile(new FileLine(FileLine::commandLineFilename(), 0),
-                         filename, true,
-                         "Cannot find file containing library module: ");
-    }
-    //v3Global.rootp()->dumpTreeFile(v3Global.debugFilename("parse.tree"));
-    V3Error::abortIfErrors();
-
-    if (!v3Global.opt.preprocOnly()) {
-        // Resolve all modules cells refer to
-        V3LinkCells::link(v3Global.rootp(), &filter, &parseSyms);
-    }
-}
-
-void V3Global::dumpCheckGlobalTree(const string& stagename, int newNumber, bool doDump) {
-    v3Global.rootp()->dumpTreeFile(v3Global.debugFilename(stagename+".tree", newNumber),
-                                   false, doDump);
-    if (v3Global.opt.stats()) V3Stats::statsStage(stagename);
-}
-
-//######################################################################
-
-void process() {
+static void process() {
     // Sort modules by level so later algorithms don't need to care
     V3LinkLevel::modSortByLevel();
     V3Error::abortIfErrors();
@@ -332,12 +274,6 @@ void process() {
         V3Dead::deadifyDTypesScoped(v3Global.rootp());
         v3Global.checkTree();
 
-        // Detect clock enables and mode into sensitives, and split always based on clocks
-        // (so this is a good prelude to splitAlways.)
-        if (v3Global.opt.oFlopGater()) {
-            V3ClkGater::clkGaterAll(v3Global.rootp());
-        }
-
         // Move assignments/sensitives into a SBLOCK for each unique sensitivity list
         // (May convert some ALWAYS to combo blocks, so should be before V3Gate step.)
         V3Active::activeAll(v3Global.rootp());
@@ -475,7 +411,8 @@ void process() {
     }
 
     // Expand macros and wide operators into C++ primitives
-    if (!v3Global.opt.xmlOnly()
+    if (!v3Global.opt.lintOnly()
+        && !v3Global.opt.xmlOnly()
         && v3Global.opt.oExpand()) {
         V3Expand::expandAll(v3Global.rootp());
     }
@@ -526,11 +463,18 @@ void process() {
 
     // Output the text
     if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()) {
+        && !v3Global.opt.xmlOnly()
+        && !v3Global.opt.dpiHdrOnly()) {
+        // Create AstCUse to determine what class forward declarations/#includes needed in C
+        // Must be before V3EmitC
+        V3CUse::cUseAll(v3Global.rootp());
+
         // emitcInlines is first, as it may set needHInlines which other emitters read
         V3EmitC::emitcInlines();
         V3EmitC::emitcSyms();
         V3EmitC::emitcTrace();
+    } else if (v3Global.opt.dpiHdrOnly()) {
+        V3EmitC::emitcSyms(true);
     }
     if (!v3Global.opt.xmlOnly()
         && v3Global.opt.mtasks()) {
@@ -540,15 +484,24 @@ void process() {
         // costs of mtasks.
         V3Partition::finalize();
     }
-    if (!v3Global.opt.xmlOnly()) {  // Unfortunately we have some lint checks in emitc.
+    if (!v3Global.opt.xmlOnly()
+        && !v3Global.opt.dpiHdrOnly()) {  // Unfortunately we have some lint checks in emitc.
         V3EmitC::emitc();
     }
     if (v3Global.opt.xmlOnly()
         // Check XML when debugging to make sure no missing node types
-        || (v3Global.opt.debugCheck() && !v3Global.opt.lintOnly())) {
+        || (v3Global.opt.debugCheck() && !v3Global.opt.lintOnly()
+            && !v3Global.opt.dpiHdrOnly())) {
         V3EmitXml::emitxml();
     }
 
+    // Output DPI protected library files
+    if (!v3Global.opt.protectLib().empty()) {
+        V3ProtectLib::protect();
+        V3EmitV::emitvFiles();
+        V3EmitC::emitcFiles();
+    }
+
     // Statistics
     if (v3Global.opt.stats()) {
         V3Stats::statsFinalAll(v3Global.rootp());
@@ -556,9 +509,15 @@ void process() {
     }
 
     if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()) {
+        && !v3Global.opt.xmlOnly()
+        && !v3Global.opt.dpiHdrOnly()) {
         // Makefile must be after all other emitters
-        V3EmitMk::emitmk(v3Global.rootp());
+        if (v3Global.opt.cmake()) {
+            V3EmitCMake::emit();
+        }
+        if (v3Global.opt.gmake()) {
+            V3EmitMk::emitmk();
+        }
     }
 
     // Note early return above when opt.cdc()
@@ -584,29 +543,17 @@ int main(int argc, char** argv, char** env) {
     // Command option parsing
     v3Global.opt.bin(argv[0]);
     string argString = V3Options::argString(argc-1, argv+1);
-    v3Global.opt.parseOpts(new FileLine(FileLine::commandLineFilename(), 0),
+    v3Global.opt.parseOpts(new FileLine(FileLine::commandLineFilename()),
                            argc-1, argv+1);
-    if (!v3Global.opt.outFormatOk()
-        && !v3Global.opt.preprocOnly()
-        && !v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()
-        && !v3Global.opt.cdc()) {
-        v3fatal("verilator: Need --cc, --sc, --cdc, --lint-only, --xml_only or --E option");
-    }
-    // Check environment
-    V3Options::getenvSYSTEMC();
-    V3Options::getenvSYSTEMC_ARCH();
-    V3Options::getenvSYSTEMC_INCLUDE();
-    V3Options::getenvSYSTEMC_LIBDIR();
+
+    // Validate settings (aka Boost.Program_options)
+    v3Global.opt.notify();
 
     V3Error::abortIfErrors();
 
     // Can we skip doing everything if times are ok?
     V3File::addSrcDepend(v3Global.opt.bin());
-    if (v3Global.opt.skipIdentical()
-        && !v3Global.opt.preprocOnly()
-        && !v3Global.opt.lintOnly()
-        && !v3Global.opt.cdc()
+    if (v3Global.opt.skipIdentical().isTrue()
         && V3File::checkTimes(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()
                               +"__verFiles.dat", argString)) {
         UINFO(1,"--skip-identical: No change to any source files, exiting\n");
@@ -622,10 +569,11 @@ int main(int argc, char** argv, char** env) {
 
     // Internal tests (after option parsing as need debug() setting,
     // and after removing files as may make debug output)
-    VHashSha1::selfTest();
     AstBasicDTypeKwd::selfTest();
-    V3Graph::selfTest();
     if (v3Global.opt.debugSelfTest()) {
+        VHashSha256::selfTest();
+        VSpellCheck::selfTest();
+        V3Graph::selfTest();
         V3TSP::selfTest();
         V3ScoreboardBase::selfTest();
         V3Partition::selfTest();
@@ -643,15 +591,16 @@ int main(int argc, char** argv, char** env) {
     V3Global::dumpCheckGlobalTree("final", 990, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
     V3Error::abortIfWarnings();
 
-    if (!v3Global.opt.lintOnly() && !v3Global.opt.cdc()
-        && v3Global.opt.makeDepend()) {
+    if (v3Global.opt.makeDepend().isTrue()) {
         V3File::writeDepend(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"__ver.d");
     }
-    if (!v3Global.opt.lintOnly() && !v3Global.opt.cdc()
-        && (v3Global.opt.skipIdentical() || v3Global.opt.makeDepend())) {
+    if (v3Global.opt.skipIdentical().isTrue() || v3Global.opt.makeDepend().isTrue()) {
         V3File::writeTimes(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()
                            +"__verFiles.dat", argString);
     }
+    if (v3Global.opt.protectIds()) {
+        VIdProtect::writeMapFile(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"__idmap.xml");
+    }
 
     // Final writing shouldn't throw warnings, but...
     V3Error::abortIfWarnings();
