@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: verilator_coverage: Coverage points
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _VLCPOINT_H_
 #define _VLCPOINT_H_ 1
 
@@ -36,18 +36,18 @@
 class VlcPoint {
 private:
     // MEMBERS
-    string		m_name;		//< Name of the point
-    vluint64_t		m_pointNum;	//< Point number
-    vluint64_t		m_testsCovering;//< Number tests with non-zero coverage of this point
-    vluint64_t		m_count;	//< Count of hits across all tests
+    string m_name;  //< Name of the point
+    vluint64_t m_pointNum;  //< Point number
+    vluint64_t m_testsCovering;  //< Number tests with non-zero coverage of this point
+    vluint64_t m_count;  //< Count of hits across all tests
 
 public:
     // CONSTRUCTORS
     VlcPoint(const string& name, int pointNum) {
-	m_name = name;
-	m_pointNum = pointNum;
-	m_testsCovering = 0;
-	m_count = 0;
+        m_name = name;
+        m_pointNum = pointNum;
+        m_testsCovering = 0;
+        m_count = 0;
     }
     ~VlcPoint() {}
     // ACCESSORS
@@ -66,31 +66,31 @@ public:
     int column() const { return atoi(keyExtract(VL_CIK_COLUMN).c_str()); }
     // METHODS
     string keyExtract(const char* shortKey) const {
-	// Hot function
-	size_t shortLen = strlen(shortKey);
-	const string namestr = name();
-	for (const char* cp = namestr.c_str(); *cp; ++cp) {
-	    if (*cp == '\001') {
-		if (0==strncmp(cp+1, shortKey, shortLen)
-		    && cp[shortLen+1] == '\002') {
-		    cp += shortLen+2;  // Skip \001+short+\002
-		    const char* ep = cp;
-		    while (*ep && *ep != '\001') ++ep;
-		    return string(cp, ep-cp);
-		}
-	    }
-	}
-	return "";
+        // Hot function
+        size_t shortLen = strlen(shortKey);
+        const string namestr = name();
+        for (const char* cp = namestr.c_str(); *cp; ++cp) {
+            if (*cp == '\001') {
+                if (0==strncmp(cp+1, shortKey, shortLen)
+                    && cp[shortLen+1] == '\002') {
+                    cp += shortLen+2;  // Skip \001+short+\002
+                    const char* ep = cp;
+                    while (*ep && *ep != '\001') ++ep;
+                    return string(cp, ep-cp);
+                }
+            }
+        }
+        return "";
     }
     static void dumpHeader() {
-	cout<<"Points:\n";
-	cout<<"  Num,    TestsCover,    Count,  Name"<<endl;
+        cout<<"Points:\n";
+        cout<<"  Num,    TestsCover,    Count,  Name"<<endl;
     }
     void dump() const {
         cout<<"  "<<std::setw(8)<<std::setfill('0')<<pointNum()
             <<",  "<<std::setw(7)<<std::setfill(' ')<<testsCovering()
             <<",  "<<std::setw(7)<<std::setfill(' ')<<count()
-	    <<",  \""<<name()<<"\""<<endl;
+            <<",  \""<<name()<<"\""<<endl;
     }
 };
 
@@ -115,40 +115,40 @@ public:
 public:
     // CONSTRUCTORS
     VlcPoints() {
-	m_numPoints = 0;
+        m_numPoints = 0;
     }
     ~VlcPoints() {}
 
     // METHODS
     void dump() {
-	UINFO(2,"dumpPoints...\n");
-	VlcPoint::dumpHeader();
-	for (VlcPoints::ByName::iterator it=begin(); it!=end(); ++it) {
-	    const VlcPoint& point = pointNumber(it->second);
-	    point.dump();
-	}
+        UINFO(2,"dumpPoints...\n");
+        VlcPoint::dumpHeader();
+        for (VlcPoints::ByName::iterator it=begin(); it!=end(); ++it) {
+            const VlcPoint& point = pointNumber(it->second);
+            point.dump();
+        }
     }
     VlcPoint& pointNumber(vluint64_t num) {
-	return m_points[num];
+        return m_points[num];
     }
     vluint64_t findAddPoint(const string& name, vluint64_t count) {
-	vluint64_t pointnum;
-	NameMap::iterator iter = m_nameMap.find(name);
-	if (iter != m_nameMap.end()) {
-	    pointnum = iter->second;
-	    m_points[pointnum].countInc(count);
-	}
-	else {
-	    pointnum = m_numPoints++;
-	    VlcPoint point (name, pointnum);
-	    point.countInc(count);
-	    m_points.push_back(point);
-	    m_nameMap.insert(make_pair(point.name(), point.pointNum()));
-	}
-	return pointnum;
+        vluint64_t pointnum;
+        NameMap::iterator iter = m_nameMap.find(name);
+        if (iter != m_nameMap.end()) {
+            pointnum = iter->second;
+            m_points[pointnum].countInc(count);
+        }
+        else {
+            pointnum = m_numPoints++;
+            VlcPoint point (name, pointnum);
+            point.countInc(count);
+            m_points.push_back(point);
+            m_nameMap.insert(make_pair(point.name(), point.pointNum()));
+        }
+        return pointnum;
     }
 };
 
 //######################################################################
 
-#endif // guard
+#endif  // guard
