@@ -2,11 +2,11 @@
 //*************************************************************************
 // DESCRIPTION: verilator_coverage: Test/coverage file container
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
-
+
 #ifndef _VLCTEST_H_
 #define _VLCTEST_H_ 1
 
@@ -42,7 +42,7 @@ private:
     vluint64_t m_rank;  //< Execution rank suggestion
     vluint64_t m_rankPoints;  //< Ranked additional points
     vluint64_t m_user;  //< User data for algorithms (not persisted in .dat file)
-    VlcBuckets m_buckets; //< Coverage data for each coverage point
+    VlcBuckets m_buckets;  //< Coverage data for each coverage point
 
 public:
     // CONSTRUCTORS
@@ -76,9 +76,9 @@ public:
         cout<<"  Covered,     Rank,  RankPts,  Filename"<<endl;
     }
     void dump(bool bucketsToo) {
-        if (testrun() || computrons()!=0.0) {
-            cout<<"  "<<std::setw(8)<<std::setfill('0')<<testrun()
-                <<",  "<<std::setw(7)<<std::setfill(' ')<<computrons()<<",";
+        if (testrun() || computrons()!=0.0) {  // currently unused // LCOV_EXCL_LINE
+            cout<<"  "<<std::setw(8)<<std::setfill('0')<<testrun()  // LCOV_EXCL_LINE
+                <<",  "<<std::setw(7)<<std::setfill(' ')<<computrons()<<",";  // LCOV_EXCL_LINE
         }
         cout<<"  "<<std::setw(7)<<std::setfill(' ')<<bucketsCovered()
             <<",  "<<std::setw(7)<<std::setfill(' ')<<rank()
@@ -110,7 +110,7 @@ public:
     VlcTests() {}
     ~VlcTests() {
         for (VlcTests::ByName::iterator it=begin(); it!=end(); ++it) {
-            delete *it; *it=NULL;
+            VL_DO_CLEAR(delete *it, *it=NULL);
         }
     }
 
