@@ -1,7 +1,7 @@
-#!/usr/bin/perl -w
+#!/usr/bin/env perl
 ######################################################################
 #
-# Copyright 2005-2019 by Wilson Snyder.  Verilator is free software; you
+# Copyright 2005-2020 by Wilson Snyder.  Verilator is free software; you
 # can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
@@ -12,21 +12,27 @@
 # GNU General Public License for more details.
 #
 ######################################################################
-
 # DESCRIPTION: Query's subversion to get version number
 
+use warnings;
+
 my $dir = $ARGV[0]; defined $dir or die "%Error: No directory argument,";
 chdir $dir;
 
 my $rev = 'UNKNOWN_REV';
 my $data = `git describe`;
-if ($data =~ /(verilator.*)/i) {
+if ($data =~ /^(v[0-9].*)/i) {
     $rev = $1;
 }
+elsif ($data =~ /verilator_?(.*)/i) {
+    $rev = "v".$1;
+    $rev =~ s/_/./g;
+}
 
 $data = `git status`;
 if ($data =~ /Changed but not updated/i
-    || $data =~ /Changes to be committed/i) {
+    || $data =~ /Changes to be committed/i
+    || $data =~ /Changes not staged/i) {
     $rev .= " (mod)";
 }
 
