@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 # DESCRIPTION: Verilator: Verilog Test driver bootstrapper
 #
 # Copyright 2008 by Wilson Snyder. This program is free software; you can
@@ -19,4 +19,4 @@ $ENV{PWD} = Cwd::getcwd();  # Else chdir leaves the .. which confuses later comm
 @args = map { s!.*test_regress/!!; $_; } @args;
 
 exec("./driver.pl", @args);
-die;
+die "$!, in exec";
