@@ -7,16 +7,19 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-compile (
-    verilator_flags2 => ["--stats"],
+scenarios(simulator => 1);
+
+compile(
+    verilator_flags2 => ["--stats",
+                         $Self->wno_unopthreads_for_few_cores()]
     );
 
-if ($Self->{vlt}) {
-    file_grep ($Self->{stats}, qr/Optimizations, Split always\s+(\d+)/i, 0);
+if ($Self->{vlt_all}) {
+    file_grep($Self->{stats}, qr/Optimizations, Split always\s+(\d+)/i, 0);
 }
 
-execute (
-    check_finished=>1,
+execute(
+    check_finished => 1,
     );
 
 ok(1);
