@@ -9,8 +9,6 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(simulator => 1);
 
-$Self->{golden_out} ||= "t/$Self->{name}.out";
-
 compile(
     verilator_flags2 => ["--stats --O3 -x-assign fast"],
     );
@@ -19,6 +17,7 @@ execute(
     check_finished => 1,
     );
 
-ok(files_identical("$Self->{obj_dir}/$Self->{name}_logger.log", $Self->{golden_out}));
+files_identical("$Self->{obj_dir}/$Self->{name}_logger.log", $Self->{golden_filename});
 
+ok(1);
 1;
