@@ -11,14 +11,14 @@ scenarios(vlt => 1);
 
 compile(
     v_flags => ['--cdc'],
-    verilator_make_gcc => 0,
+    verilator_make_gmake => 0,
     make_top_shell => 0,
     make_main => 0,
     fails => 1,
     expect_filename => $Self->{golden_filename},
     );
 
-file_grep ("$Self->{obj_dir}/V$Self->{name}__cdc.txt", qr/CDC Report/);
+file_grep("$Self->{obj_dir}/V$Self->{name}__cdc.txt", qr/CDC Report/);
 
 ok(1);
 1;
