@@ -7,15 +7,18 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-compile (
-    verilator_flags2 => ["--stats"],
+scenarios(simulator => 1);
+
+compile(
+    verilator_flags2 => ["--stats",
+                         $Self->wno_unopthreads_for_few_cores()]
     );
 
-execute (
-	 check_finished=>1,
-     );
+execute(
+    check_finished => 1,
+    );
 
-if ($Self->{vlt}) {
+if ($Self->{vlt_all}) {
     #Optimization is disabled
     #file_grep ($Self->{stats}, qr/Optimizations, Gaters inserted\s+(\d+)/i, 3);
 }
