@@ -7,9 +7,7 @@
 Vt_clk_inp_init* topp;
 
 vluint64_t main_time;
-double sc_time_stamp() {
-    return main_time;
-}
+double sc_time_stamp() { return main_time; }
 
 void oneTest(int seed) {
     double sim_time = 1000;
@@ -44,20 +42,20 @@ void oneTest(int seed) {
     }
 
     if (!Verilated::gotFinish()) {
-       vl_fatal(__FILE__,__LINE__,"main", "%Error: Timeout; never got a $finish");
+        vl_fatal(__FILE__, __LINE__, "main", "%Error: Timeout; never got a $finish");
     }
 
     topp->final();
-    delete topp; topp=NULL;
+    VL_DO_DANGLING(delete topp, topp);
 }
 
-int main(int argc, char **argv, char **env) {
+int main(int argc, char** argv, char** env) {
     Verilated::commandArgs(argc, argv);
 #if VL_DEBUG
-    //Verilated::debug(1);
+    // Verilated::debug(1);
 #endif
 
-    for (int seed=123; seed<133; ++seed) {
+    for (int seed = 123; seed < 133; ++seed) {
         oneTest(seed);
     }
 
