@@ -9,10 +9,9 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(simulator => 1);
 
-$Self->{vl_time_multiplier} = 1000;
-
 compile(
     verilator_flags2 => ['-DVL_TIME_MULTIPLER=1000'],
+    make_flags => 'CPPFLAGS_ADD=-DVL_TIME_MULTIPLIER=1000',
     );
 
 execute(
