@@ -9,9 +9,8 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(simulator => 1);
 
-$Self->{vl_time_multiplier} = 1000;
-
 compile(
+    make_flags => 'CPPFLAGS_ADD=-DVL_TIME_MULTIPLIER=1000',
     );
 
 execute(
