@@ -9,25 +9,27 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 use IO::File;
 
+scenarios(dist => 1);
+
 my $root = "..";
 my $Debug;
 
 if (!-r "$root/.git") {
-    $Self->skip("Not in a git repository");
+    skip("Not in a git repository");
 } else {
     ### Must trim output before and after our file list
     my $files = `cd $root && git ls-files --exclude-standard`;
     print "ST $files\n" if $Debug;
     $files =~ s/\s+/ /g;
-    my $cmd = "cd $root && fgrep -n FIX"."ME $files | sort | grep -v t_dist_fixme";
+    my $cmd = "cd $root && grep -n -P '(FIX"."ME|BO"."ZO)' $files | sort";
     my $grep = `$cmd`;
     print "$grep\n";
     if ($grep ne "") {
-	my %names;
-	foreach my $line (split /\n/, $grep) {
-	    $names{$1} = 1 if $line =~ /^([^:]+)/;
-	}
-	$Self->error("Files with FIX"."MEs: ",join(' ',sort keys %names));
+        my %names;
+        foreach my $line (split /\n/, $grep) {
+            $names{$1} = 1 if $line =~ /^([^:]+)/;
+        }
+        error("Files with FIX"."MEs: ",join(' ',sort keys %names));
     }
 }
 
