@@ -73,17 +73,17 @@ extern "C" {
 
 #define CHECK_RESULT(type, got, exp)            \
     if ((got) != (exp)) {                       \
-        printf("%%Error: %s:%d:", __FILE__,__LINE__);   \
+        printf("%%Error: %s:%d:", __FILE__, __LINE__); \
         union { type a; long long l; } u;       \
-        u.l = 0; u.a = got;                     \
+        u.l = 0; u.a = got; if (u.a) {/*used*/} \
         printf(" GOT = %" T_PRI64 "x", u.l);    \
-        u.l = 0; u.a = exp;                     \
+        u.l = 0; u.a = exp; if (u.a) {/*used*/} \
         printf("  EXP = %" T_PRI64 "x\n", u.l); \
         return __LINE__; \
     }
 #define CHECK_RESULT_NNULL(got) \
     if (!(got)) { \
-        printf("%%Error: %s:%d: GOT = %p   EXP = !NULL\n", __FILE__,__LINE__, (got)); \
+        printf("%%Error: %s:%d: GOT = %p   EXP = !NULL\n", __FILE__, __LINE__, (got)); \
         return __LINE__; \
     }
 
@@ -98,8 +98,8 @@ static int check_sub(const char* name, int i) {
     CHECK_RESULT(svScope, sout, prev);
     CHECK_RESULT(svScope, svGetScope(), scope);
 #ifndef T_DPI_EXPORT_NOOPT
-    int out = dpix_sub_inst(100*i);
-    CHECK_RESULT(int, out, 100*i + i);
+    int out = dpix_sub_inst(100 * i);
+    CHECK_RESULT(int, out, 100 * i + i);
 #endif
     return 0;  // OK
 }
@@ -118,14 +118,14 @@ int dpix_run_tests() {
 #endif
 
 #ifndef CADENCE  // Unimplemented; how hard is it?
-    printf("svDpiVersion: %s\n",svDpiVersion());
+    printf("svDpiVersion: %s\n", svDpiVersion());
     CHECK_RESULT(bool,
                  strcmp(svDpiVersion(), "1800-2005")==0
                  || strcmp(svDpiVersion(), "P1800-2005")==0
                  , 1);
 #endif
 
-    CHECK_RESULT(int, dpix_int123(), 0x123 );
+    CHECK_RESULT(int, dpix_int123(), 0x123);
 
 #ifndef CADENCE  // No export calls from an import
     int o;
@@ -150,27 +150,27 @@ int dpix_run_tests() {
     CHECK_RESULT(void*, dpix_f_chandle((void*)(12345)), (void*)(12345));
 
     {
-        svBitVecVal i_vec48[2] = {0xab782a12,0x8a413bd9};
-        svBitVecVal o_vec48[2] = {0,0};
+        svBitVecVal i_vec48[2] = {0xab782a12, 0x8a413bd9};
+        svBitVecVal o_vec48[2] = {0, 0};
         dpix_t_bit48(i_vec48, o_vec48);
         CHECK_RESULT(int, o_vec48[0], ~i_vec48[0]);
 #ifdef VCS  // VCS has bug where doesn't clean input
         CHECK_RESULT(int, o_vec48[1], (~i_vec48[1]));
 #else
-        CHECK_RESULT(int, o_vec48[1], (~i_vec48[1])&0x0000ffffUL);
+        CHECK_RESULT(int, o_vec48[1], (~i_vec48[1]) & 0x0000ffffUL);
 #endif
     }
     {
-        svBitVecVal i_vec95[3] = {0x72912312,0xab782a12,0x8a413bd9};
-        svBitVecVal o_vec95[3] = {0,0,0};
+        svBitVecVal i_vec95[3] = {0x72912312, 0xab782a12, 0x8a413bd9};
+        svBitVecVal o_vec95[3] = {0, 0, 0};
         dpix_t_bit95(i_vec95, o_vec95);
         CHECK_RESULT(int, o_vec95[0], ~i_vec95[0]);
         CHECK_RESULT(int, o_vec95[1], ~i_vec95[1]);
-        CHECK_RESULT(int, o_vec95[2], (~i_vec95[2])&0x7fffffffUL);
+        CHECK_RESULT(int, o_vec95[2], (~i_vec95[2]) & 0x7fffffffUL);
     }
     {
-        svBitVecVal i_vec96[3] = {0xf2912312,0xab782a12,0x8a413bd9};
-        svBitVecVal o_vec96[3] = {0,0,0};
+        svBitVecVal i_vec96[3] = {0xf2912312, 0xab782a12, 0x8a413bd9};
+        svBitVecVal o_vec96[3] = {0, 0, 0};
         dpix_t_bit96(i_vec96, o_vec96);
         CHECK_RESULT(int, o_vec96[0], ~i_vec96[0]);
         CHECK_RESULT(int, o_vec96[1], ~i_vec96[1]);
@@ -203,7 +203,7 @@ int dpix_run_tests() {
         dpix_t_reg95(i, o);
         CHECK_RESULT(int, o[0].aval, ~i[0].aval);
         CHECK_RESULT(int, o[1].aval, ~i[1].aval);
-        CHECK_RESULT(int, o[2].aval, (~i[2].aval)&0x7fffffffUL);
+        CHECK_RESULT(int, o[2].aval, (~i[2].aval) & 0x7fffffffUL);
         CHECK_RESULT(int, o[0].bval, 0);
         CHECK_RESULT(int, o[1].bval, 0);
         CHECK_RESULT(int, o[2].bval, 0);
@@ -222,8 +222,8 @@ int dpix_run_tests() {
     }
 #endif
 
-    if (int bad=check_sub("top.t.a",1)) return bad;
-    if (int bad=check_sub("top.t.b",2)) return bad;
+    if (int bad = check_sub("top.t.a", 1)) return bad;
+    if (int bad = check_sub("top.t.b", 2)) return bad;
 
     return -1;  // OK status
 }
