@@ -33,13 +33,11 @@ void dpii_call(double in, double* outp) {
 
 unsigned int main_time = 0;
 
-double sc_time_stamp() {
-    return main_time;
-}
+double sc_time_stamp() { return main_time; }
 
 VM_PREFIX* topp = NULL;
 
-int main(int argc, char *argv[]) {
+int main(int argc, char* argv[]) {
     topp = new VM_PREFIX;
 
     Verilated::debug(0);
@@ -47,10 +45,10 @@ int main(int argc, char *argv[]) {
     topp->in = 1.1;
     topp->eval();
     if (topp->out != 1.2) {
-	VL_PRINTF("*-* All Finished *-*\n");
-	topp->final();
+        VL_PRINTF("*-* All Finished *-*\n");
+        topp->final();
     } else {
-	vl_fatal(__FILE__,__LINE__,"top", "Unexpected results\n");
+        vl_fatal(__FILE__, __LINE__, "top", "Unexpected results\n");
     }
     return 0;
 }
