@@ -7,17 +7,17 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-$Self->{vlt} or $Self->skip("Verilator only test");
+scenarios(vlt => 1);
 
-compile (
+compile(
     make_top_shell => 0,
     make_main => 0,
     v_flags2 => ["-FI $Self->{t_dir}/t_flag_fi_h.h",
-		 "--exe $Self->{t_dir}/$Self->{name}.cpp"],
+                 "--exe $Self->{t_dir}/$Self->{name}.cpp"],
     );
 
-execute (
-    check_finished=>1,
+execute(
+    check_finished => 1,
     );
 
 ok(1);
