@@ -16,7 +16,7 @@ compile(
     expect =>
 'gotit
 ',
-    verilator_make_gcc => 0,
+    verilator_make_gmake => 0,
     make_top_shell => 0,
     make_main => 0,
     );
