@@ -9,12 +9,9 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(vlt => 1);
 
-compile(
+lint(
     v_flags2 => ["--relative-includes",
                  "--lint-only $Self->{t_dir}/t_flag_relinc_dir/chip/t_flag_relinc_sub.v"],
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
     );
 
 ok(1);
