@@ -14,10 +14,7 @@ top_filename("t/t_flag_topmodule.v");
 compile(
     fails => 1,
     nc => 0,  # Need to get it not to give the prompt
-    expect =>
-'%Error-MULTITOP: t/t_flag_topmodule.v:\d+: Unsupported: Multiple top level modules: .*
-%Error-MULTITOP: t/t_flag_topmodule.v:\d+: Fix, or use --top-module option to select which you want.
-%Error: Exiting due to.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
