@@ -10,11 +10,18 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 scenarios(simulator => 1);
 
 top_filename("t/t_func_dotted.v");
+my $out_filename = "$Self->{obj_dir}/V$Self->{name}.xml";
 
 compile(
-    v_flags2 => ['+define+USE_INLINE',],
+    v_flags2 => ['+define+ATTRIBUTES', '+define+USE_INLINE',],
     );
 
+if ($Self->{vlt_all}) {
+    file_grep_not("$out_filename", qr/ma0/i);
+    file_grep_not("$out_filename", qr/mb0/i);
+    file_grep_not("$out_filename", qr/mc0/i);
+}
+
 execute(
     check_finished => 1,
     );
