@@ -7,18 +7,20 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-my $pubtask = ($Self->{v3} && verilator_version() =~ /\(public_tasks\)/);  # TBD
+scenarios(simulator => 1);
+
+my $pubtask = ($Self->{vlt_all} && verilator_version() =~ /\(public_tasks\)/);  # TBD
 
 top_filename("t/t_func_public.v");
 
-compile (
-	 verilator_flags2 => [($pubtask?'-DVERILATOR_PUBLIC_TASKS':''), "--trace"],
-	 fails => $fail,
-	 );
+compile(
+    verilator_flags2 => [($pubtask?'-DVERILATOR_PUBLIC_TASKS':''), "--trace"],
+    fails => $fail,
+    );
 
-execute (
-	 check_finished=>1,
-	 );
+execute(
+    check_finished => 1,
+    );
 
 ok(1);
 1;
