@@ -7,13 +7,14 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-$Self->unsupported("Verilator/commercial slice unsupported, bug711");
+scenarios(simulator => 1);
+unsupported("Verilator/commercial slice unsupported, bug711");
 
-compile (
+compile(
     );
 
-execute (
-    check_finished=>1,
+execute(
+    check_finished => 1,
     );
 
 ok(1);
