@@ -7,10 +7,10 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(simulator => 1);
+scenarios(linter => 1);
 
-compile(
-    v_flags2 => ["--lint-only --Wall -Wno-DECLFILENAME"],
+lint(
+    verilator_flags2 => ["--lint-only --Wall -Wno-DECLFILENAME"],
     fails => 1,
     expect_filename => $Self->{golden_filename},
     );
