@@ -7,6 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
+if ($Self->{vltmt} && exists $ENV{TRAVIS_DIST} &&
+    $ENV{TRAVIS_DIST} eq "trusty")
+{
+    skip("Multithreaded test does not work under Travis w/ Ubuntu Trusty");
+}
+
 scenarios(vlt_all => 1);
 
 compile(
