@@ -7,22 +7,15 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(vlt => 1);
 
 top_filename("t/t_lint_defparam.v");
 
-compile(
-    v_flags2 => ["--lint-only -Wwarn-style -Wno-DECLFILENAME"],
+lint(
+    verilator_flags2 => ["--lint-only -Wwarn-style -Wno-DECLFILENAME"],
     fails => 1,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
-    expect =>
-'%Warning-DEFPARAM: t/t_lint_defparam.v:\d+: Suggest replace defparam with Verilog 2001 #\(.P\(...etc...\)\)
-%Warning-DEFPARAM: Use .* to disable this message.
-%Error: Exiting due to.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
 1;
-
