@@ -7,16 +7,15 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(vlt => 1);
 
 top_filename("t/t_lint_implicit.v");
 
-compile(
-    v_flags2 => ["--lint-only -Wwarn-IMPLICIT"],
+lint(
+    verilator_flags2 => ["--lint-only -Wwarn-IMPLICIT"],
     fails => 1,
     expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
 1;
-
