@@ -9,15 +9,10 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(vlt => 1);
 
-compile(
+lint(
     verilator_flags2 => ["--lint-only -Wno-DECLFILENAME"],
     fails => 1,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
-    expect =>
-q{%Error: t/t_lint_mod_paren_bad.v:\d+: syntax error, unexpected '\(', expecting ';'
-%Error: Exiting due to .*},
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
