@@ -7,17 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(simulator => 1);
+scenarios(linter => 1);
 
-compile(
+lint(
     verilator_flags2 => ["--lint-only -Wno-DECLFILENAME"],
     fails => 1,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
-    expect =>
-'%Error: t/t_lint_modport_dir_bad.v:\d+: Attempt to drive input-only modport: signal
-%Error: Exiting due to .*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
