@@ -7,19 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(linter => 1);
 
-compile(
+lint(
     verilator_flags2 => ["--lint-only -Wwarn-UNUSED"],
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
     fails => 1,
-    expect =>
-'%Warning-UNUSED: t/t_lint_once_bad.v:\d+: Signal is not driven, nor used: unus1
-%Warning-UNUSED: Use .* to disable this message.
-%Warning-UNUSED: t/t_lint_once_bad.v:\d+: Signal is not driven, nor used: unus2
-%Error: Exiting due to.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
