@@ -11,8 +11,8 @@ scenarios(vlt => 1);
 
 lint();
 
-foreach my $file (glob("$Self->{obj_dir}/*t_lint_only*")) {
-    next if $file =~ /simx_compile.log/;  # Made by driver.pl, not Verilator
+foreach my $file (glob("$Self->{obj_dir}/*")) {
+    next if $file =~ /\.log/;  # Made by driver.pl, not Verilator
     next if $file =~ /\.status/;  # Made by driver.pl, not Verilator
     error("%Error: Created $file, but --lint-only shouldn't create files");
 }
