@@ -7,18 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(linter => 1);
 
-compile(
-    v_flags2 => ["--lint-only -Wwarn-REALCVT"],
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
+lint(
+    verilator_flags2 => ["--lint-only -Wwarn-REALCVT"],
     fails => 1,
-    expect =>
-'%Warning-REALCVT: t/t_lint_realcvt_bad.v:\d+: Implicit conversion of real to integer
-%Warning-REALCVT: Use .* to disable this message.
-%Error: Exiting due to.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
