@@ -7,19 +7,14 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(linter => 1);
 
 top_filename("t/t_lint_setout_bad.v");
 
-compile(
-    v_flags2 => ["--lint-only -Oi"],
+lint(
+    verilator_flags2 => ["--lint-only -Oi"],
     fails => 1,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
-    expect =>
-'%Error: t/t_lint_setout_bad.v:\d+: Output port is connected to a constant pin, electrical short
-.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
