@@ -7,14 +7,16 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-#!$Self->{vcs} or $Self->unsupported("VCS does ** wrong, fixed in 2014");
+scenarios(simulator => 1);
 
-compile (
-	 );
+#!$Self->{vcs} or unsupported("VCS does ** wrong, fixed in 2014");
 
-execute (
-	 check_finished=>1,
-     );
+compile(
+    );
+
+execute(
+    check_finished => 1,
+    );
 
 ok(1);
 1;
