@@ -7,15 +7,15 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
+scenarios(vlt_all => 1);
+
 top_filename("t/t_mem_multi_io3.v");
 
-$Self->{vlt} or $Self->skip("Verilator only test");
-
-compile (
-	 make_top_shell => 0,
-	 make_main => 0,
-	 verilator_flags2 => ["--exe $Self->{t_dir}/t_mem_multi_io3.cpp -Oi"],
-	 verilator_flags3 => [],
+compile(
+    make_top_shell => 0,
+    make_main => 0,
+    verilator_flags2 => ["--exe $Self->{t_dir}/t_mem_multi_io3.cpp -Oi"],
+    verilator_flags3 => [],
     );
 
 ok(1);
