@@ -7,13 +7,9 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(simulator => 1);
+scenarios(vlt => 1);
 
-compile(
-    verilator_flags2 => [qw(--lint-only)],
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
+lint(
     fails => $Self->{vlt_all},
     expect_filename => $Self->{golden_filename},
     );
