@@ -7,14 +7,10 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(linter => 1);
 
-compile(
-    v_flags2 => ["--lint-only -Wno-SELRANGE"],
-    fails => 0,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
+lint(
+    verilator_flags2 => ["--lint-only -Wno-SELRANGE"],
     );
 
 ok(1);
