@@ -13,7 +13,7 @@ my $stdout_filename = "$Self->{obj_dir}/$Self->{name}__test.vpp";
 
 compile(
     verilator_flags2 => ['-E --pipe-filter \'perl t/t_pipe_filter.pf\' '],
-    verilator_make_gcc => 0,
+    verilator_make_gmake => 0,
     make_top_shell => 0,
     make_main => 0,
     stdout_filename => $stdout_filename,
