@@ -11,12 +11,10 @@ scenarios(vlt => 1);
 
 top_filename("t/t_pp_dupdef.v");
 
-compile(
-    v_flags2 => ["--lint-only"],
+lint(
     fails => 1,
     expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
 1;
-
