@@ -7,21 +7,23 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-compile (
+scenarios(simulator => 1);
+
+compile(
     v_flags2 => ["--savable"],
     save_time => 500,
     );
 
-execute (
-    check_finished=>0,
+execute(
+    check_finished => 0,
     all_run_flags => ['+save_time=500'],
     );
 
--r "$Self->{obj_dir}/saved.vltsv" or $Self->error("Saved.vltsv not created\n");
+-r "$Self->{obj_dir}/saved.vltsv" or error("Saved.vltsv not created\n");
 
-execute (
+execute(
     all_run_flags => ['+save_restore=1'],
-    check_finished=>1,
+    check_finished => 1,
     );
 
 ok(1);
