@@ -14,8 +14,7 @@ unlink("$Self->{obj_dir}/t_sys_file_basic_test.log");
 compile(
     v_flags2 => ['+incdir+../include'],
     # Build without cached objects, see bug363
-    verilator_flags2 => ["--exe ../$Self->{main_filename}"],
-    make_flags => 'MAKE_MAIN=0 VM_PARALLEL_BUILDS=0',
+    make_flags => 'VM_PARALLEL_BUILDS=0',
     );
 
 execute(
