@@ -15,7 +15,7 @@ compile(
 
 execute(
     check_finished => 1,
-    all_run_flags => ['+PLUS +INT=1234 +STRSTR'],
+    all_run_flags => ['+PLUS +INT=1234 +STRSTR +REAL=1.2345'],
     );
 
 ok(1);
