@@ -7,14 +7,16 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-compile (
-	 );
+scenarios(simulator => 1);
 
-execute (
-	 fails=>$Self->{v3},
-	 expect=>
+compile(
+    );
+
+execute(
+    fails => $Self->{vlt_all},
+    expect =>
 '%Error: t/t_sys_readmem_bad_digit.mem:\d+: \$readmemb \(binary\) file contains hex characters',
-     );
+    );
 
 ok(1);
 1;
