@@ -16,8 +16,7 @@ compile(
     verilator_flags2 => ["-O0"],
     );
 
-if ($Self->cxx_version =~ /clang version ([0-9]+\.[0-9]+)/
-    && ($1 >= 3.8 && $1 <= 5.0)) {
+if ($Self->cxx_version =~ /clang/) {
     skip("Known clang bug");
     #Here:   if (VL_UNLIKELY(VL_NEQ_W(12, __Vtemp1, vlSymsp->TOP__t.__PVT__str)))
 } else{
