@@ -7,8 +7,7 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(simulator => 1);
-$Self->cfg_with_threaded or skip("No thread support");
+scenarios(vltmt => 1);
 
 top_filename("t/t_threads_counter.v");
 
