@@ -19,10 +19,11 @@ execute(
     check_finished => 1,
     );
 
-system("cat $Self->{obj_dir}/simpart*.vcd > $Self->{obj_dir}/simall.vcd");
+system("cat $Self->{obj_dir}/simpart_0000.vcd "
+       ." $Self->{obj_dir}/simpart_0000_cat*.vcd > $Self->{obj_dir}/simall.vcd");
 
 vcd_identical("$Self->{obj_dir}/simall.vcd",
-              "t/$Self->{name}.out");
+              $Self->{golden_filename});
 
 ok(1);
 1;
