@@ -9,7 +9,7 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(simulator => 1);
 
-top_filename("t_trace_complex.v");
+top_filename("t/t_trace_complex.v");
 
 compile(
     verilator_flags2 => ['--cc --trace --no-trace-structs --trace-params'],
