@@ -9,7 +9,7 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 
 scenarios(simulator => 1);
 
-top_filename("t_trace_complex.v");
+top_filename("t/t_trace_complex.v");
 
 compile(
     verilator_flags2 => ['--cc --trace --trace-structs --no-trace-params'],
@@ -29,7 +29,7 @@ file_grep     ("$Self->{obj_dir}/simx.vcd", qr/ v_arru_arru\(/);
 file_grep     ("$Self->{obj_dir}/simx.vcd", qr/ v_arru_arrp\(/);
 file_grep     ("$Self->{obj_dir}/simx.vcd", qr/ v_arru_strp\(/);
 
-vcd_identical ("$Self->{obj_dir}/simx.vcd", "t/$Self->{name}.out");
+vcd_identical ("$Self->{obj_dir}/simx.vcd", $Self->{golden_filename});
 
 ok(1);
 1;
