@@ -25,9 +25,9 @@ else {
 
     if ($Self->{vlt_all}) {
         # Note more checks in _cc.pl
-        file_grep     ("$Self->{obj_dir}/simx.vcd", qr/\$enddefinitions/x);
+        file_grep    ("$Self->{obj_dir}/simx.vcd", qr/\$enddefinitions/x);
 
-        vcd_identical("$Self->{obj_dir}/simx.vcd", "t/$Self->{name}.out");
+        vcd_identical("$Self->{obj_dir}/simx.vcd", $Self->{golden_filename});
     }
 }
 
