@@ -7,18 +7,20 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
+scenarios(simulator => 1);
+
 top_filename("t/t_trace_ena.v");
 
-compile (
-	 verilator_flags2 => ['-notrace -sc'],
-	 );
+compile(
+    verilator_flags2 => ['-notrace -sc'],
+    );
 
-execute (
-	 check_finished=>1,
-	 );
+execute(
+    check_finished => 1,
+    );
 
-if ($Self->{vlt}) {
-    !-r "$Self->{obj_dir}/simx.vcd" or $Self->error("Tracing should be off\n");
+if ($Self->{vlt_all}) {
+    !-r "$Self->{obj_dir}/simx.vcd" or error("Tracing should be off\n");
 }
 
 ok(1);
