@@ -5,11 +5,9 @@
 
 #include "Vt_tri_inout.h"
 
-Vt_tri_inout *tb = NULL;
+Vt_tri_inout* tb = NULL;
 
-double sc_time_stamp() {
-    return 0;
-}
+double sc_time_stamp() { return 0; }
 
 bool check() {
     bool pass;
@@ -40,22 +38,20 @@ int main() {
     tb = new Vt_tri_inout("tb");
 
     // loop through every possibility and check the result
-    for (tb->SEL=0; tb->SEL<2; tb->SEL++) {
-        for (tb->A=0; tb->A<2; tb->A++) {
-            for (tb->B=0; tb->B<2; tb->B++) {
+    for (tb->SEL = 0; tb->SEL < 2; tb->SEL++) {
+        for (tb->A = 0; tb->A < 2; tb->A++) {
+            for (tb->B = 0; tb->B < 2; tb->B++) {
                 tb->eval();
-                if (!check()) {
-                    pass = false;
-                }
+                if (!check()) { pass = false; }
             }
         }
     }
 
-    if(pass) {
+    if (pass) {
         VL_PRINTF("*-* All Finished *-*\n");
         tb->final();
     } else {
-        vl_fatal(__FILE__,__LINE__,"top", "Unexpected results from inout test\n");
+        vl_fatal(__FILE__, __LINE__, "top", "Unexpected results from inout test\n");
     }
     return 0;
 }
