@@ -5,11 +5,9 @@
 
 #include "Vt_tri_pullup.h"
 
-Vt_tri_pullup *tb = NULL;
+Vt_tri_pullup* tb = NULL;
 
-double sc_time_stamp() {
-    return 0;
-}
+double sc_time_stamp() { return 0; }
 
 bool check() {
     bool pass;
@@ -30,7 +28,7 @@ bool check() {
     bool verbose = false;
 #endif
 
-    if (tb->Z == Z  &&  tb->Y == Y  && tb->X == X) {
+    if (tb->Z == Z && tb->Y == Y && tb->X == X) {
         if (verbose) printf("PASS: ");
         pass = true;
     } else {
@@ -38,7 +36,9 @@ bool check() {
         verbose = true;
         pass = false;
     }
-    if (verbose) printf("OE=%d A=%d  X=%d xexp=%d  Y=%d yexp=%d  Z=%d zexp=%d\n", tb->OE, tb->A, tb->X,X, tb->Y,Y, tb->Z,Z);
+    if (verbose)
+        printf("OE=%d A=%d  X=%d xexp=%d  Y=%d yexp=%d  Z=%d zexp=%d\n", tb->OE, tb->A, tb->X, X,
+               tb->Y, Y, tb->Z, Z);
     return pass;
 }
 
@@ -46,15 +46,13 @@ int main() {
     bool pass = true;
 
     Verilated::debug(0);
-    tb  = new Vt_tri_pullup("tb");
+    tb = new Vt_tri_pullup("tb");
 
     // loop through every possibility and check the result
-    for (tb->OE=0; tb->OE<2; tb->OE++) {
-        for (tb->A=0; tb->A<2; tb->A++) {
+    for (tb->OE = 0; tb->OE < 2; tb->OE++) {
+        for (tb->A = 0; tb->A < 2; tb->A++) {
             tb->eval();
-            if (!check()) {
-                pass = false;
-            }
+            if (!check()) { pass = false; }
         }
     }
 
@@ -62,7 +60,7 @@ int main() {
         VL_PRINTF("*-* All Finished *-*\n");
         tb->final();
     } else {
-        vl_fatal(__FILE__,__LINE__,"top", "Unexpected results from pullup test\n");
+        vl_fatal(__FILE__, __LINE__, "top", "Unexpected results from pullup test\n");
     }
     return 0;
 }
