@@ -7,10 +7,9 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(vlt_all => 1);
+scenarios(vlt => 1);
 
-compile(
-    v_flags2 => ["--lint-only"],
+lint(
     fails => $Self->{vlt_all},
     expect_filename => $Self->{golden_filename},
     );
