@@ -13,9 +13,7 @@ top_filename("t/t_udp.v");
 
 compile(
     fails => $Self->{vlt_all},
-    expect =>
-'%Error: t/t_udp.v:\d+: Unsupported: Verilog 1995 UDP Tables.  Use --bbox-unsup to ignore tables.
-%Error: Exiting due to '
+    expect_filename => $Self->{golden_filename},
     );
 
 execute(
