@@ -7,18 +7,20 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
+scenarios(simulator => 1);
+
 top_filename("t/t_uniqueif.v");
 
-compile (
+compile(
     v_flags2 => ['+define+FAILING_ASSERTION3'],
     verilator_flags2 => ['--assert'],
     nc_flags2 => ['+assert'],
     fails => $Self->{nc},
     );
 
-execute (
-    fails => $Self->{vlt},
-    expect=>
+execute(
+    fails => $Self->{vlt_all},
+    expect =>
 '.*%Error: t_uniqueif.v:\d+: Assertion failed in top.t: \'unique if\' statement violated
 %Error: t/t_uniqueif.v:\d+: Verilog \$stop
 .*',
