@@ -7,16 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-scenarios(simulator => 1);
+scenarios(linter => 1);
 
-compile(
-    v_flags2 => ["--lint-only -Wwarn-VARHIDDEN"],
+lint(
+    verilator_flags2 => ["--lint-only -Wwarn-VARHIDDEN"],
     fails => $Self->{vlt_all},
-    expect =>
-'%Warning-VARHIDDEN: t/t_var_bad_hide2.v:\d+: Declaration of signal hides declaration in upper scope: t
-%Warning-VARHIDDEN: t/t_var_bad_hide2.v:\d+: ... Location of original declaration
-.*
-%Error: Exiting due to.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
