@@ -10,7 +10,7 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 scenarios(vlt => 1);
 
 lint(
-    verilator_flags2 => ["--lint-only t/t_vlt_warn.vlt"],
+    verilator_flags2 => ["--lint-only t/t_vlt_warn.vlt -Wall"],
     );
 
 ok(1);
