@@ -42,58 +42,52 @@ using namespace std;
 // __FILE__ is too long
 #define FILENM "t_vpi_memory.cpp"
 
-#define DEBUG if (0) printf
+#define DEBUG \
+    if (0) printf
 
 unsigned int main_time = false;
 
-#define STRINGIFY(x) STRINGIFY2(x)
-#define STRINGIFY2(x) #x
-
 //======================================================================
 
 #define CHECK_RESULT_VH(got, exp) \
     if ((got) != (exp)) { \
-        printf("%%Error: %s:%d: GOT = %p   EXP = %p\n", \
-               FILENM,__LINE__, (got), (exp)); \
+        printf("%%Error: %s:%d: GOT = %p   EXP = %p\n", FILENM, __LINE__, (got), (exp)); \
         return __LINE__; \
     }
 
 #define CHECK_RESULT_NZ(got) \
     if (!(got)) { \
-        printf("%%Error: %s:%d: GOT = NULL  EXP = !NULL\n", FILENM,__LINE__); \
+        printf("%%Error: %s:%d: GOT = NULL  EXP = !NULL\n", FILENM, __LINE__); \
         return __LINE__; \
     }
 
 // Use cout to avoid issues with %d/%lx etc
 #define CHECK_RESULT(got, exp) \
     if ((got) != (exp)) { \
-        cout<<dec<<"%Error: "<<FILENM<<":"<<__LINE__ \
-           <<": GOT = "<<(got)<<"   EXP = "<<(exp)<<endl;       \
+        cout << dec << "%Error: " << FILENM << ":" << __LINE__ << ": GOT = " << (got) \
+             << "   EXP = " << (exp) << endl; \
         return __LINE__; \
     }
 
 #define CHECK_RESULT_HEX(got, exp) \
     if ((got) != (exp)) { \
-        cout<<dec<<"%Error: "<<FILENM<<":"<<__LINE__<<hex \
-           <<": GOT = "<<(got)<<"   EXP = "<<(exp)<<endl;       \
+        cout << dec << "%Error: " << FILENM << ":" << __LINE__ << hex << ": GOT = " << (got) \
+             << "   EXP = " << (exp) << endl; \
         return __LINE__; \
     }
 
 #define CHECK_RESULT_CSTR(got, exp) \
-    if (strcmp((got),(exp))) { \
-        printf("%%Error: %s:%d: GOT = '%s'   EXP = '%s'\n", \
-               FILENM,__LINE__, (got)?(got):"<null>", (exp)?(exp):"<null>"); \
+    if (strcmp((got), (exp))) { \
+        printf("%%Error: %s:%d: GOT = '%s'   EXP = '%s'\n", FILENM, __LINE__, \
+               (got) ? (got) : "<null>", (exp) ? (exp) : "<null>"); \
         return __LINE__; \
     }
 
-#define CHECK_RESULT_CSTR_STRIP(got, exp) \
-    CHECK_RESULT_CSTR(got+strspn(got, " "), exp)
+#define CHECK_RESULT_CSTR_STRIP(got, exp) CHECK_RESULT_CSTR(got + strspn(got, " "), exp)
 
 int _mon_check_range(TestVpiHandle& handle, int size, int left, int right) {
     TestVpiHandle iter_h, left_h, right_h;
-    s_vpi_value value = {
-        vpiIntVal, .value = {.integer = 0}
-    };
+    s_vpi_value value = {vpiIntVal, .value = {.integer = 0}};
     // check size of object
     int vpisize = vpi_get(vpiSize, handle);
     CHECK_RESULT(vpisize, size);
@@ -122,9 +116,7 @@ int _mon_check_memory() {
     int cnt;
     TestVpiHandle mem_h, lcl_h;
     vpiHandle iter_h;  // Icarus does not like auto free of iterator handles
-    s_vpi_value value = {
-        vpiIntVal, .value = {.integer = 0}
-    };
+    s_vpi_value value = {vpiIntVal, .value = {.integer = 0}};
     vpi_printf((PLI_BYTE8*)"Check memory vpi ...\n");
     mem_h = vpi_handle_by_name((PLI_BYTE8*)TestSimulator::rooted("mem0"), NULL);
     CHECK_RESULT_NZ(mem_h);
@@ -146,15 +138,16 @@ int _mon_check_memory() {
     iter_h = vpi_iterate(vpiMemoryWord, mem_h);
     cnt = 0;
     while ((lcl_h = vpi_scan(iter_h))) {
-      ++cnt;
-      vpi_get_value(lcl_h, &value);
-      CHECK_RESULT(value.value.integer, cnt);
+        ++cnt;
+        vpi_get_value(lcl_h, &value);
+        CHECK_RESULT(value.value.integer, cnt);
     }
     CHECK_RESULT(cnt, 16);  // should be 16 addresses
     // don't care for non verilator
     // (crashes on Icarus)
     if (TestSimulator::is_icarus()) {
-        vpi_printf((PLI_BYTE8*)"Skipping property checks for simulator %s\n", TestSimulator::get_info().product);
+        vpi_printf((PLI_BYTE8*)"Skipping property checks for simulator %s\n",
+                   TestSimulator::get_info().product);
         return 0;  // Ok
     }
     // make sure trying to get properties that don't exist
@@ -183,40 +176,35 @@ int mon_check() {
 #ifdef IS_VPI
 
 static int mon_check_vpi() {
-  vpiHandle href = vpi_handle(vpiSysTfCall, 0);
-  s_vpi_value vpi_value;
+    vpiHandle href = vpi_handle(vpiSysTfCall, 0);
+    s_vpi_value vpi_value;
 
-  vpi_value.format = vpiIntVal;
-  vpi_value.value.integer = mon_check();
-  vpi_put_value(href, &vpi_value, NULL, vpiNoDelay);
+    vpi_value.format = vpiIntVal;
+    vpi_value.value.integer = mon_check();
+    vpi_put_value(href, &vpi_value, NULL, vpiNoDelay);
 
-  return 0;
+    return 0;
 }
 
-static s_vpi_systf_data vpi_systf_data[] = {
-  {vpiSysFunc, vpiIntFunc, (PLI_BYTE8*)"$mon_check", (PLI_INT32(*)(PLI_BYTE8*))mon_check_vpi, 0, 0, 0},
-  0
-};
+static s_vpi_systf_data vpi_systf_data[] = {{vpiSysFunc, vpiIntFunc, (PLI_BYTE8*)"$mon_check",
+                                             (PLI_INT32(*)(PLI_BYTE8*))mon_check_vpi, 0, 0, 0},
+                                            0};
 
 // cver entry
 void vpi_compat_bootstrap(void) {
-  p_vpi_systf_data systf_data_p;
-  systf_data_p = &(vpi_systf_data[0]);
-  while (systf_data_p->type != 0) vpi_register_systf(systf_data_p++);
+    p_vpi_systf_data systf_data_p;
+    systf_data_p = &(vpi_systf_data[0]);
+    while (systf_data_p->type != 0)
+        vpi_register_systf(systf_data_p++);
 }
 
 // icarus entry
-void (*vlog_startup_routines[])() = {
-      vpi_compat_bootstrap,
-      0
-};
+void (*vlog_startup_routines[])() = {vpi_compat_bootstrap, 0};
 
 #else
 
-double sc_time_stamp() {
-    return main_time;
-}
-int main(int argc, char **argv, char **env) {
+double sc_time_stamp() { return main_time; }
+int main(int argc, char** argv, char** env) {
     double sim_time = 1100;
     Verilated::commandArgs(argc, argv);
     Verilated::debug(0);
@@ -226,9 +214,9 @@ int main(int argc, char **argv, char **env) {
     VM_PREFIX* topp = new VM_PREFIX("");  // Note null name - we're flattening it out
 
 #ifdef VERILATOR
-# ifdef TEST_VERBOSE
+#ifdef TEST_VERBOSE
     Verilated::scopesDump();
-# endif
+#endif
 #endif
 
 #if VM_TRACE
@@ -236,7 +224,7 @@ int main(int argc, char **argv, char **env) {
     VL_PRINTF("Enabling waves...\n");
     VerilatedVcdC* tfp = new VerilatedVcdC;
     topp->trace(tfp, 99);
-    tfp->open(STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
+    tfp->open(VL_STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
 #endif
 
     topp->eval();
@@ -248,13 +236,13 @@ int main(int argc, char **argv, char **env) {
         topp->eval();
         VerilatedVpi::callValueCbs();
         topp->clk = !topp->clk;
-        //mon_do();
+        // mon_do();
 #if VM_TRACE
-        if (tfp) tfp->dump (main_time);
+        if (tfp) tfp->dump(main_time);
 #endif
     }
     if (!Verilated::gotFinish()) {
-        vl_fatal(FILENM,__LINE__,"main", "%Error: Timeout; never got a $finish");
+        vl_fatal(FILENM, __LINE__, "main", "%Error: Timeout; never got a $finish");
     }
     topp->final();
 
@@ -262,7 +250,7 @@ int main(int argc, char **argv, char **env) {
     if (tfp) tfp->close();
 #endif
 
-    delete topp; topp=NULL;
+    VL_DO_DANGLING(delete topp, topp);
     exit(0L);
 }
 
