@@ -7,10 +7,12 @@ if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); di
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
 
-$Self->skip("Known compiler limitation")
+scenarios(simulator => 1);
+
+skip("Known compiler limitation")
     if $Self->cxx_version =~ /\(GCC\) 4.4/;
 
-compile (
+compile(
     make_top_shell => 0,
     make_main => 0,
     make_pli => 1,
@@ -19,9 +21,9 @@ compile (
     verilator_flags2 => ["-CFLAGS '-DVL_DEBUG -ggdb' --exe --vpi --no-l2name $Self->{t_dir}/t_vpi_memory.cpp"],
     );
 
-execute (
+execute(
     iv_pli => 1,
-    check_finished=>1
+    check_finished => 1
     );
 
 ok(1);
