@@ -13,8 +13,12 @@ my $out_filename = "$Self->{obj_dir}/V$Self->{name}.xml";
 
 compile(
     verilator_flags2 => ['--xml-only'],
-    verilator_make_gcc => 0,
+    verilator_make_gmake => 0,
+    make_top_shell => 0,
+    make_main => 0,
     );
 
-ok(files_identical("$out_filename", "t/$Self->{name}.out"));
+files_identical("$out_filename", $Self->{golden_filename});
+
+ok(1);
 1;
